" Vim syntax file
" Language: C gail extension (for version 1.22.3)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py

syn keyword gailFunction gail_misc_add_attribute gail_misc_add_to_attr_set gail_misc_buffer_get_run_attributes gail_misc_get_default_attributes gail_misc_get_extents_from_pango_rectangle gail_misc_get_index_at_point_in_layout gail_misc_get_origins gail_misc_layout_get_run_attributes gail_text_util_buffer_setup gail_text_util_get_substring gail_text_util_get_text gail_text_util_get_type gail_text_util_new gail_text_util_text_setup
syn keyword gailConstant GAIL_AFTER_OFFSET GAIL_AT_OFFSET GAIL_BEFORE_OFFSET
syn keyword gailStruct GailTextUtil GailTextUtilClass
syn keyword gailMacro GAIL_IS_TEXT_UTIL GAIL_IS_TEXT_UTIL_CLASS GAIL_TEXT_UTIL GAIL_TEXT_UTIL_CLASS GAIL_TEXT_UTIL_GET_CLASS
syn keyword gailEnum GailOffsetType
syn keyword gailDefine GAIL_TYPE_TEXT_UTIL

" Default highlighting
if version >= 508 || !exists("did_gail_syntax_inits")
  if version < 508
    let did_gail_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink gailFunction Function
  HiLink gailConstant Constant
  HiLink gailStruct Type
  HiLink gailMacro Macro
  HiLink gailEnum Type
  HiLink gailDefine Constant

  delcommand HiLink
endif

