" Vim syntax file
" Language: C gio extension (for version 2.28.0)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let gio_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let gio_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword gioFunction g_action_activate g_action_get_enabled g_action_get_name g_action_get_parameter_type g_action_get_state g_action_get_state_hint g_action_get_state_type g_action_get_type g_action_group_action_added g_action_group_action_enabled_changed g_action_group_action_removed g_action_group_action_state_changed g_action_group_activate_action g_action_group_change_action_state g_action_group_get_action_enabled g_action_group_get_action_parameter_type g_action_group_get_action_state g_action_group_get_action_state_hint g_action_group_get_action_state_type g_action_group_get_type g_action_group_has_action g_action_group_list_actions g_action_set_state g_app_info_add_supports_type g_app_info_can_delete g_app_info_can_remove_supports_type g_app_info_create_from_commandline g_app_info_delete g_app_info_dup g_app_info_equal g_app_info_get_all g_app_info_get_all_for_type g_app_info_get_commandline g_app_info_get_default_for_type g_app_info_get_default_for_uri_scheme g_app_info_get_description g_app_info_get_display_name g_app_info_get_executable g_app_info_get_fallback_for_type g_app_info_get_icon g_app_info_get_id g_app_info_get_name g_app_info_get_recommended_for_type g_app_info_get_type g_app_info_launch g_app_info_launch_default_for_uri g_app_info_launch_uris g_app_info_remove_supports_type g_app_info_reset_type_associations g_app_info_set_as_default_for_extension g_app_info_set_as_default_for_type g_app_info_set_as_last_used_for_type g_app_info_should_show g_app_info_supports_files g_app_info_supports_uris g_app_launch_context_get_display g_app_launch_context_get_startup_notify_id g_app_launch_context_get_type g_app_launch_context_launch_failed g_app_launch_context_new g_application_activate g_application_command_line_get_arguments g_application_command_line_get_cwd g_application_command_line_get_exit_status g_application_command_line_get_is_remote g_application_command_line_get_platform_data g_application_command_line_get_type g_application_command_line_getenv g_application_command_line_print g_application_command_line_printerr g_application_command_line_set_exit_status g_application_get_application_id g_application_get_flags g_application_get_inactivity_timeout g_application_get_is_registered g_application_get_is_remote g_application_get_type g_application_hold g_application_id_is_valid g_application_new g_application_open g_application_register g_application_release g_application_run g_application_set_action_group g_application_set_application_id g_application_set_flags g_application_set_inactivity_timeout g_async_initable_get_type g_async_initable_init_async g_async_initable_init_finish g_async_initable_new_async g_async_initable_new_finish g_async_initable_new_valist_async g_async_initable_newv_async g_async_result_get_source_object g_async_result_get_type g_async_result_get_user_data g_buffered_input_stream_fill g_buffered_input_stream_fill_async g_buffered_input_stream_fill_finish g_buffered_input_stream_get_available g_buffered_input_stream_get_buffer_size g_buffered_input_stream_get_type g_buffered_input_stream_new g_buffered_input_stream_new_sized g_buffered_input_stream_peek g_buffered_input_stream_peek_buffer g_buffered_input_stream_read_byte g_buffered_input_stream_set_buffer_size g_buffered_output_stream_get_auto_grow g_buffered_output_stream_get_buffer_size g_buffered_output_stream_get_type g_buffered_output_stream_new g_buffered_output_stream_new_sized g_buffered_output_stream_set_auto_grow g_buffered_output_stream_set_buffer_size g_bus_get g_bus_get_finish g_bus_get_sync g_bus_own_name g_bus_own_name_on_connection g_bus_own_name_on_connection_with_closures g_bus_own_name_with_closures g_bus_unown_name g_bus_unwatch_name g_bus_watch_name g_bus_watch_name_on_connection g_bus_watch_name_on_connection_with_closures g_bus_watch_name_with_closures g_cancellable_cancel g_cancellable_connect g_cancellable_disconnect g_cancellable_get_current g_cancellable_get_fd g_cancellable_get_type g_cancellable_is_cancelled g_cancellable_make_pollfd g_cancellable_new g_cancellable_pop_current g_cancellable_push_current g_cancellable_release_fd g_cancellable_reset g_cancellable_set_error_if_cancelled g_cancellable_source_new g_charset_converter_get_num_fallbacks g_charset_converter_get_type g_charset_converter_get_use_fallback g_charset_converter_new g_charset_converter_set_use_fallback g_content_type_can_be_executable g_content_type_equals g_content_type_from_mime_type g_content_type_get_description g_content_type_get_icon g_content_type_get_mime_type g_content_type_guess g_content_type_guess_for_tree g_content_type_is_a g_content_type_is_unknown g_content_types_get_registered g_converter_convert g_converter_get_type g_converter_input_stream_get_converter g_converter_input_stream_get_type g_converter_input_stream_new g_converter_output_stream_get_converter g_converter_output_stream_get_type g_converter_output_stream_new g_converter_reset g_credentials_get_native g_credentials_get_type g_credentials_get_unix_user g_credentials_is_same_user g_credentials_new g_credentials_set_native g_credentials_set_unix_user g_credentials_to_string g_data_input_stream_get_byte_order g_data_input_stream_get_newline_type g_data_input_stream_get_type g_data_input_stream_new g_data_input_stream_read_byte g_data_input_stream_read_int16 g_data_input_stream_read_int32 g_data_input_stream_read_int64 g_data_input_stream_read_line g_data_input_stream_read_line_async g_data_input_stream_read_line_finish g_data_input_stream_read_uint16 g_data_input_stream_read_uint32 g_data_input_stream_read_uint64 g_data_input_stream_read_until g_data_input_stream_read_until_async g_data_input_stream_read_until_finish g_data_input_stream_read_upto g_data_input_stream_read_upto_async g_data_input_stream_read_upto_finish g_data_input_stream_set_byte_order g_data_input_stream_set_newline_type g_data_output_stream_get_byte_order g_data_output_stream_get_type g_data_output_stream_new g_data_output_stream_put_byte g_data_output_stream_put_int16 g_data_output_stream_put_int32 g_data_output_stream_put_int64 g_data_output_stream_put_string g_data_output_stream_put_uint16 g_data_output_stream_put_uint32 g_data_output_stream_put_uint64 g_data_output_stream_set_byte_order g_dbus_address_get_for_bus_sync g_dbus_address_get_stream g_dbus_address_get_stream_finish g_dbus_address_get_stream_sync g_dbus_annotation_info_get_type g_dbus_annotation_info_lookup g_dbus_annotation_info_ref g_dbus_annotation_info_unref g_dbus_arg_info_get_type g_dbus_arg_info_ref g_dbus_arg_info_unref g_dbus_auth_observer_authorize_authenticated_peer g_dbus_auth_observer_get_type g_dbus_auth_observer_new g_dbus_connection_add_filter g_dbus_connection_call g_dbus_connection_call_finish g_dbus_connection_call_sync g_dbus_connection_close g_dbus_connection_close_finish g_dbus_connection_close_sync g_dbus_connection_emit_signal g_dbus_connection_flush g_dbus_connection_flush_finish g_dbus_connection_flush_sync g_dbus_connection_get_capabilities g_dbus_connection_get_exit_on_close g_dbus_connection_get_guid g_dbus_connection_get_peer_credentials g_dbus_connection_get_stream g_dbus_connection_get_type g_dbus_connection_get_unique_name g_dbus_connection_is_closed g_dbus_connection_new g_dbus_connection_new_finish g_dbus_connection_new_for_address g_dbus_connection_new_for_address_finish g_dbus_connection_new_for_address_sync g_dbus_connection_new_sync g_dbus_connection_register_object g_dbus_connection_register_subtree g_dbus_connection_remove_filter g_dbus_connection_send_message g_dbus_connection_send_message_with_reply g_dbus_connection_send_message_with_reply_finish g_dbus_connection_send_message_with_reply_sync g_dbus_connection_set_exit_on_close g_dbus_connection_signal_subscribe g_dbus_connection_signal_unsubscribe g_dbus_connection_start_message_processing g_dbus_connection_unregister_object g_dbus_connection_unregister_subtree g_dbus_error_encode_gerror g_dbus_error_get_remote_error g_dbus_error_is_remote_error g_dbus_error_new_for_dbus_error g_dbus_error_quark g_dbus_error_register_error g_dbus_error_register_error_domain g_dbus_error_set_dbus_error g_dbus_error_set_dbus_error_valist g_dbus_error_strip_remote_error g_dbus_error_unregister_error g_dbus_generate_guid g_dbus_interface_info_generate_xml g_dbus_interface_info_get_type g_dbus_interface_info_lookup_method g_dbus_interface_info_lookup_property g_dbus_interface_info_lookup_signal g_dbus_interface_info_ref g_dbus_interface_info_unref g_dbus_is_address g_dbus_is_guid g_dbus_is_interface_name g_dbus_is_member_name g_dbus_is_name g_dbus_is_supported_address g_dbus_is_unique_name g_dbus_message_bytes_needed g_dbus_message_copy g_dbus_message_get_arg0 g_dbus_message_get_body g_dbus_message_get_byte_order g_dbus_message_get_destination g_dbus_message_get_error_name g_dbus_message_get_flags g_dbus_message_get_header g_dbus_message_get_header_fields g_dbus_message_get_interface g_dbus_message_get_locked g_dbus_message_get_member g_dbus_message_get_message_type g_dbus_message_get_num_unix_fds g_dbus_message_get_path g_dbus_message_get_reply_serial g_dbus_message_get_sender g_dbus_message_get_serial g_dbus_message_get_signature g_dbus_message_get_type g_dbus_message_get_unix_fd_list g_dbus_message_lock g_dbus_message_new g_dbus_message_new_from_blob g_dbus_message_new_method_call g_dbus_message_new_method_error g_dbus_message_new_method_error_literal g_dbus_message_new_method_error_valist g_dbus_message_new_method_reply g_dbus_message_new_signal g_dbus_message_print g_dbus_message_set_body g_dbus_message_set_byte_order g_dbus_message_set_destination g_dbus_message_set_error_name g_dbus_message_set_flags g_dbus_message_set_header g_dbus_message_set_interface g_dbus_message_set_member g_dbus_message_set_message_type g_dbus_message_set_num_unix_fds g_dbus_message_set_path g_dbus_message_set_reply_serial g_dbus_message_set_sender g_dbus_message_set_serial g_dbus_message_set_signature g_dbus_message_set_unix_fd_list g_dbus_message_to_blob g_dbus_message_to_gerror g_dbus_method_info_get_type g_dbus_method_info_ref g_dbus_method_info_unref g_dbus_method_invocation_get_connection g_dbus_method_invocation_get_interface_name g_dbus_method_invocation_get_message g_dbus_method_invocation_get_method_info g_dbus_method_invocation_get_method_name g_dbus_method_invocation_get_object_path g_dbus_method_invocation_get_parameters g_dbus_method_invocation_get_sender g_dbus_method_invocation_get_type g_dbus_method_invocation_get_user_data g_dbus_method_invocation_return_dbus_error g_dbus_method_invocation_return_error g_dbus_method_invocation_return_error_literal g_dbus_method_invocation_return_error_valist g_dbus_method_invocation_return_gerror g_dbus_method_invocation_return_value g_dbus_node_info_generate_xml g_dbus_node_info_get_type g_dbus_node_info_lookup_interface g_dbus_node_info_new_for_xml g_dbus_node_info_ref g_dbus_node_info_unref g_dbus_property_info_get_type g_dbus_property_info_ref g_dbus_property_info_unref g_dbus_proxy_call g_dbus_proxy_call_finish g_dbus_proxy_call_sync g_dbus_proxy_get_cached_property g_dbus_proxy_get_cached_property_names g_dbus_proxy_get_connection g_dbus_proxy_get_default_timeout g_dbus_proxy_get_flags g_dbus_proxy_get_interface_info g_dbus_proxy_get_interface_name g_dbus_proxy_get_name g_dbus_proxy_get_name_owner g_dbus_proxy_get_object_path g_dbus_proxy_get_type g_dbus_proxy_new g_dbus_proxy_new_finish g_dbus_proxy_new_for_bus g_dbus_proxy_new_for_bus_finish g_dbus_proxy_new_for_bus_sync g_dbus_proxy_new_sync g_dbus_proxy_set_cached_property g_dbus_proxy_set_default_timeout g_dbus_proxy_set_interface_info g_dbus_server_get_client_address g_dbus_server_get_flags g_dbus_server_get_guid g_dbus_server_get_type g_dbus_server_is_active g_dbus_server_new_sync g_dbus_server_start g_dbus_server_stop g_dbus_signal_info_get_type g_dbus_signal_info_ref g_dbus_signal_info_unref g_desktop_app_info_get_filename g_desktop_app_info_get_is_hidden g_desktop_app_info_get_type g_desktop_app_info_new g_desktop_app_info_new_from_filename g_desktop_app_info_new_from_keyfile g_desktop_app_info_set_desktop_env g_drive_can_eject g_drive_can_poll_for_media g_drive_can_start g_drive_can_start_degraded g_drive_can_stop g_drive_eject_with_operation g_drive_eject_with_operation_finish g_drive_enumerate_identifiers g_drive_get_icon g_drive_get_identifier g_drive_get_name g_drive_get_start_stop_type g_drive_get_type g_drive_get_volumes g_drive_has_media g_drive_has_volumes g_drive_is_media_check_automatic g_drive_is_media_removable g_drive_poll_for_media g_drive_poll_for_media_finish g_drive_start g_drive_start_finish g_drive_stop g_drive_stop_finish g_emblem_get_icon g_emblem_get_origin g_emblem_get_type g_emblem_new g_emblem_new_with_origin g_emblemed_icon_add_emblem g_emblemed_icon_clear_emblems g_emblemed_icon_get_emblems g_emblemed_icon_get_icon g_emblemed_icon_get_type g_emblemed_icon_new g_file_append_to g_file_append_to_async g_file_append_to_finish g_file_attribute_info_list_add g_file_attribute_info_list_dup g_file_attribute_info_list_get_type g_file_attribute_info_list_lookup g_file_attribute_info_list_new g_file_attribute_info_list_ref g_file_attribute_info_list_unref g_file_attribute_matcher_enumerate_namespace g_file_attribute_matcher_enumerate_next g_file_attribute_matcher_get_type g_file_attribute_matcher_matches g_file_attribute_matcher_matches_only g_file_attribute_matcher_new g_file_attribute_matcher_ref g_file_attribute_matcher_unref g_file_copy g_file_copy_async g_file_copy_attributes g_file_copy_finish g_file_create g_file_create_async g_file_create_finish g_file_create_readwrite g_file_create_readwrite_async g_file_create_readwrite_finish g_file_delete g_file_descriptor_based_get_fd g_file_descriptor_based_get_type g_file_dup g_file_eject_mountable_with_operation g_file_eject_mountable_with_operation_finish g_file_enumerate_children g_file_enumerate_children_async g_file_enumerate_children_finish g_file_enumerator_close g_file_enumerator_close_async g_file_enumerator_close_finish g_file_enumerator_get_container g_file_enumerator_get_type g_file_enumerator_has_pending g_file_enumerator_is_closed g_file_enumerator_next_file g_file_enumerator_next_files_async g_file_enumerator_next_files_finish g_file_enumerator_set_pending g_file_equal g_file_find_enclosing_mount g_file_find_enclosing_mount_async g_file_find_enclosing_mount_finish g_file_get_basename g_file_get_child g_file_get_child_for_display_name g_file_get_parent g_file_get_parse_name g_file_get_path g_file_get_relative_path g_file_get_type g_file_get_uri g_file_get_uri_scheme g_file_has_parent g_file_has_prefix g_file_has_uri_scheme g_file_hash g_file_icon_get_file g_file_icon_get_type g_file_icon_new g_file_info_clear_status g_file_info_copy_into g_file_info_dup g_file_info_get_attribute_as_string g_file_info_get_attribute_boolean g_file_info_get_attribute_byte_string g_file_info_get_attribute_data g_file_info_get_attribute_int32 g_file_info_get_attribute_int64 g_file_info_get_attribute_object g_file_info_get_attribute_status g_file_info_get_attribute_string g_file_info_get_attribute_stringv g_file_info_get_attribute_type g_file_info_get_attribute_uint32 g_file_info_get_attribute_uint64 g_file_info_get_content_type g_file_info_get_display_name g_file_info_get_edit_name g_file_info_get_etag g_file_info_get_file_type g_file_info_get_icon g_file_info_get_is_backup g_file_info_get_is_hidden g_file_info_get_is_symlink g_file_info_get_modification_time g_file_info_get_name g_file_info_get_size g_file_info_get_sort_order g_file_info_get_symlink_target g_file_info_get_type g_file_info_has_attribute g_file_info_has_namespace g_file_info_list_attributes g_file_info_new g_file_info_remove_attribute g_file_info_set_attribute g_file_info_set_attribute_boolean g_file_info_set_attribute_byte_string g_file_info_set_attribute_int32 g_file_info_set_attribute_int64 g_file_info_set_attribute_mask g_file_info_set_attribute_object g_file_info_set_attribute_status g_file_info_set_attribute_string g_file_info_set_attribute_stringv g_file_info_set_attribute_uint32 g_file_info_set_attribute_uint64 g_file_info_set_content_type g_file_info_set_display_name g_file_info_set_edit_name g_file_info_set_file_type g_file_info_set_icon g_file_info_set_is_hidden g_file_info_set_is_symlink g_file_info_set_modification_time g_file_info_set_name g_file_info_set_size g_file_info_set_sort_order g_file_info_set_symlink_target g_file_info_unset_attribute_mask g_file_input_stream_get_type g_file_input_stream_query_info g_file_input_stream_query_info_async g_file_input_stream_query_info_finish g_file_io_stream_get_etag g_file_io_stream_get_type g_file_io_stream_query_info g_file_io_stream_query_info_async g_file_io_stream_query_info_finish g_file_is_native g_file_load_contents g_file_load_contents_async g_file_load_contents_finish g_file_load_partial_contents_async g_file_load_partial_contents_finish g_file_make_directory g_file_make_directory_with_parents g_file_make_symbolic_link g_file_monitor g_file_monitor_cancel g_file_monitor_directory g_file_monitor_emit_event g_file_monitor_file g_file_monitor_get_type g_file_monitor_is_cancelled g_file_monitor_set_rate_limit g_file_mount_enclosing_volume g_file_mount_enclosing_volume_finish g_file_mount_mountable g_file_mount_mountable_finish g_file_move g_file_new_for_commandline_arg g_file_new_for_path g_file_new_for_uri g_file_open_readwrite g_file_open_readwrite_async g_file_open_readwrite_finish g_file_output_stream_get_etag g_file_output_stream_get_type g_file_output_stream_query_info g_file_output_stream_query_info_async g_file_output_stream_query_info_finish g_file_parse_name g_file_poll_mountable g_file_poll_mountable_finish g_file_query_default_handler g_file_query_exists g_file_query_file_type g_file_query_filesystem_info g_file_query_filesystem_info_async g_file_query_filesystem_info_finish g_file_query_info g_file_query_info_async g_file_query_info_finish g_file_query_settable_attributes g_file_query_writable_namespaces g_file_read g_file_read_async g_file_read_finish g_file_replace g_file_replace_async g_file_replace_contents g_file_replace_contents_async g_file_replace_contents_finish g_file_replace_finish g_file_replace_readwrite g_file_replace_readwrite_async g_file_replace_readwrite_finish g_file_resolve_relative_path g_file_set_attribute g_file_set_attribute_byte_string g_file_set_attribute_int32 g_file_set_attribute_int64 g_file_set_attribute_string g_file_set_attribute_uint32 g_file_set_attribute_uint64 g_file_set_attributes_async g_file_set_attributes_finish g_file_set_attributes_from_info g_file_set_display_name g_file_set_display_name_async g_file_set_display_name_finish g_file_start_mountable g_file_start_mountable_finish g_file_stop_mountable g_file_stop_mountable_finish g_file_supports_thread_contexts g_file_trash g_file_unmount_mountable_with_operation g_file_unmount_mountable_with_operation_finish g_filename_completer_get_completion_suffix g_filename_completer_get_completions g_filename_completer_get_type g_filename_completer_new g_filename_completer_set_dirs_only g_filter_input_stream_get_base_stream g_filter_input_stream_get_close_base_stream g_filter_input_stream_get_type g_filter_input_stream_set_close_base_stream g_filter_output_stream_get_base_stream g_filter_output_stream_get_close_base_stream g_filter_output_stream_get_type g_filter_output_stream_set_close_base_stream g_icon_equal g_icon_get_type g_icon_hash g_icon_new_for_string g_icon_to_string g_inet_address_get_family g_inet_address_get_is_any g_inet_address_get_is_link_local g_inet_address_get_is_loopback g_inet_address_get_is_mc_global g_inet_address_get_is_mc_link_local g_inet_address_get_is_mc_node_local g_inet_address_get_is_mc_org_local g_inet_address_get_is_mc_site_local g_inet_address_get_is_multicast g_inet_address_get_is_site_local g_inet_address_get_native_size g_inet_address_get_type g_inet_address_new_any g_inet_address_new_from_bytes g_inet_address_new_from_string g_inet_address_new_loopback g_inet_address_to_bytes g_inet_address_to_string g_inet_socket_address_get_address g_inet_socket_address_get_port g_inet_socket_address_get_type g_inet_socket_address_new g_initable_get_type g_initable_init g_initable_new g_initable_new_valist g_initable_newv g_input_stream_clear_pending g_input_stream_close g_input_stream_close_async g_input_stream_close_finish g_input_stream_get_type g_input_stream_has_pending g_input_stream_is_closed g_input_stream_read g_input_stream_read_all g_input_stream_read_async g_input_stream_read_finish g_input_stream_set_pending g_input_stream_skip g_input_stream_skip_async g_input_stream_skip_finish g_io_error_from_errno g_io_error_from_win32_error g_io_error_quark g_io_extension_get_name g_io_extension_get_priority g_io_extension_get_type g_io_extension_point_get_extension_by_name g_io_extension_point_get_extensions g_io_extension_point_get_required_type g_io_extension_point_implement g_io_extension_point_lookup g_io_extension_point_register g_io_extension_point_set_required_type g_io_extension_ref_class g_io_module_get_type g_io_module_load g_io_module_new g_io_module_query g_io_module_unload g_io_modules_load_all_in_directory g_io_modules_scan_all_in_directory g_io_scheduler_cancel_all_jobs g_io_scheduler_job_send_to_mainloop g_io_scheduler_job_send_to_mainloop_async g_io_scheduler_push_job g_io_stream_clear_pending g_io_stream_close g_io_stream_close_async g_io_stream_close_finish g_io_stream_get_input_stream g_io_stream_get_output_stream g_io_stream_get_type g_io_stream_has_pending g_io_stream_is_closed g_io_stream_set_pending g_io_stream_splice_async g_io_stream_splice_finish g_keyfile_settings_backend_new g_loadable_icon_get_type g_loadable_icon_load g_loadable_icon_load_async g_loadable_icon_load_finish g_memory_input_stream_add_data g_memory_input_stream_get_type g_memory_input_stream_new g_memory_input_stream_new_from_data g_memory_output_stream_get_data g_memory_output_stream_get_data_size g_memory_output_stream_get_size g_memory_output_stream_get_type g_memory_output_stream_new g_memory_output_stream_steal_data g_memory_settings_backend_new g_mount_can_eject g_mount_can_unmount g_mount_eject_with_operation g_mount_eject_with_operation_finish g_mount_get_default_location g_mount_get_drive g_mount_get_icon g_mount_get_name g_mount_get_root g_mount_get_type g_mount_get_uuid g_mount_get_volume g_mount_guess_content_type g_mount_guess_content_type_finish g_mount_guess_content_type_sync g_mount_is_shadowed g_mount_operation_get_anonymous g_mount_operation_get_choice g_mount_operation_get_domain g_mount_operation_get_password g_mount_operation_get_password_save g_mount_operation_get_type g_mount_operation_get_username g_mount_operation_new g_mount_operation_reply g_mount_operation_set_anonymous g_mount_operation_set_choice g_mount_operation_set_domain g_mount_operation_set_password g_mount_operation_set_password_save g_mount_operation_set_username g_mount_remount g_mount_remount_finish g_mount_shadow g_mount_unmount_with_operation g_mount_unmount_with_operation_finish g_mount_unshadow g_network_address_get_hostname g_network_address_get_port g_network_address_get_scheme g_network_address_get_type g_network_address_new g_network_address_parse g_network_address_parse_uri g_network_service_get_domain g_network_service_get_protocol g_network_service_get_scheme g_network_service_get_service g_network_service_get_type g_network_service_new g_network_service_set_scheme g_null_settings_backend_new g_output_stream_clear_pending g_output_stream_close g_output_stream_close_async g_output_stream_close_finish g_output_stream_flush g_output_stream_flush_async g_output_stream_flush_finish g_output_stream_get_type g_output_stream_has_pending g_output_stream_is_closed g_output_stream_is_closing g_output_stream_set_pending g_output_stream_splice g_output_stream_splice_async g_output_stream_splice_finish g_output_stream_write g_output_stream_write_all g_output_stream_write_async g_output_stream_write_finish g_permission_acquire g_permission_acquire_async g_permission_acquire_finish g_permission_get_allowed g_permission_get_can_acquire g_permission_get_can_release g_permission_get_type g_permission_impl_update g_permission_release g_permission_release_async g_permission_release_finish g_pollable_input_stream_can_poll g_pollable_input_stream_create_source g_pollable_input_stream_get_type g_pollable_input_stream_is_readable g_pollable_input_stream_read_nonblocking g_pollable_output_stream_can_poll g_pollable_output_stream_create_source g_pollable_output_stream_get_type g_pollable_output_stream_is_writable g_pollable_output_stream_write_nonblocking g_pollable_source_new g_proxy_address_enumerator_get_type g_proxy_address_get_destination_hostname g_proxy_address_get_destination_port g_proxy_address_get_password g_proxy_address_get_protocol g_proxy_address_get_type g_proxy_address_get_username g_proxy_address_new g_proxy_connect g_proxy_connect_async g_proxy_connect_finish g_proxy_get_default_for_protocol g_proxy_get_type g_proxy_resolver_get_default g_proxy_resolver_get_type g_proxy_resolver_is_supported g_proxy_resolver_lookup g_proxy_resolver_lookup_async g_proxy_resolver_lookup_finish g_proxy_supports_hostname g_resolver_error_quark g_resolver_free_addresses g_resolver_free_targets g_resolver_get_default g_resolver_get_type g_resolver_lookup_by_address g_resolver_lookup_by_address_async g_resolver_lookup_by_address_finish g_resolver_lookup_by_name g_resolver_lookup_by_name_async g_resolver_lookup_by_name_finish g_resolver_lookup_service g_resolver_lookup_service_async g_resolver_lookup_service_finish g_resolver_set_default g_seekable_can_seek g_seekable_can_truncate g_seekable_get_type g_seekable_seek g_seekable_tell g_seekable_truncate g_settings_apply g_settings_backend_changed g_settings_backend_changed_tree g_settings_backend_flatten_tree g_settings_backend_get_default g_settings_backend_get_type g_settings_backend_keys_changed g_settings_backend_path_changed g_settings_backend_path_writable_changed g_settings_backend_writable_changed g_settings_bind g_settings_bind_with_mapping g_settings_bind_writable g_settings_delay g_settings_get g_settings_get_boolean g_settings_get_child g_settings_get_double g_settings_get_enum g_settings_get_flags g_settings_get_has_unapplied g_settings_get_int g_settings_get_mapped g_settings_get_range g_settings_get_string g_settings_get_strv g_settings_get_type g_settings_get_value g_settings_is_writable g_settings_list_children g_settings_list_keys g_settings_new g_settings_new_with_backend g_settings_new_with_backend_and_path g_settings_new_with_path g_settings_range_check g_settings_reset g_settings_revert g_settings_set g_settings_set_boolean g_settings_set_double g_settings_set_enum g_settings_set_flags g_settings_set_int g_settings_set_string g_settings_set_strv g_settings_set_value g_settings_sync g_settings_unbind g_simple_action_get_type g_simple_action_group_get_type g_simple_action_group_insert g_simple_action_group_lookup g_simple_action_group_new g_simple_action_group_remove g_simple_action_new g_simple_action_new_stateful g_simple_action_set_enabled g_simple_async_report_error_in_idle g_simple_async_report_gerror_in_idle g_simple_async_report_take_gerror_in_idle g_simple_async_result_complete g_simple_async_result_complete_in_idle g_simple_async_result_get_op_res_gboolean g_simple_async_result_get_op_res_gpointer g_simple_async_result_get_op_res_gssize g_simple_async_result_get_source_tag g_simple_async_result_get_type g_simple_async_result_is_valid g_simple_async_result_new g_simple_async_result_new_error g_simple_async_result_new_from_error g_simple_async_result_new_take_error g_simple_async_result_propagate_error g_simple_async_result_run_in_thread g_simple_async_result_set_error g_simple_async_result_set_error_va g_simple_async_result_set_from_error g_simple_async_result_set_handle_cancellation g_simple_async_result_set_op_res_gboolean g_simple_async_result_set_op_res_gpointer g_simple_async_result_set_op_res_gssize g_simple_async_result_take_error g_simple_permission_get_type g_simple_permission_new g_socket_accept g_socket_address_enumerator_get_type g_socket_address_enumerator_next g_socket_address_enumerator_next_async g_socket_address_enumerator_next_finish g_socket_address_get_family g_socket_address_get_native_size g_socket_address_get_type g_socket_address_new_from_native g_socket_address_to_native g_socket_bind g_socket_check_connect_result g_socket_client_add_application_proxy g_socket_client_connect g_socket_client_connect_async g_socket_client_connect_finish g_socket_client_connect_to_host g_socket_client_connect_to_host_async g_socket_client_connect_to_host_finish g_socket_client_connect_to_service g_socket_client_connect_to_service_async g_socket_client_connect_to_service_finish g_socket_client_connect_to_uri g_socket_client_connect_to_uri_async g_socket_client_connect_to_uri_finish g_socket_client_get_enable_proxy g_socket_client_get_family g_socket_client_get_local_address g_socket_client_get_protocol g_socket_client_get_socket_type g_socket_client_get_timeout g_socket_client_get_tls g_socket_client_get_tls_validation_flags g_socket_client_get_type g_socket_client_new g_socket_client_set_enable_proxy g_socket_client_set_family g_socket_client_set_local_address g_socket_client_set_protocol g_socket_client_set_socket_type g_socket_client_set_timeout g_socket_client_set_tls g_socket_client_set_tls_validation_flags g_socket_close g_socket_condition_check g_socket_condition_wait g_socket_connect g_socket_connectable_enumerate g_socket_connectable_get_type g_socket_connectable_proxy_enumerate g_socket_connection_factory_create_connection g_socket_connection_factory_lookup_type g_socket_connection_factory_register_type g_socket_connection_get_local_address g_socket_connection_get_remote_address g_socket_connection_get_socket g_socket_connection_get_type g_socket_control_message_deserialize g_socket_control_message_get_level g_socket_control_message_get_msg_type g_socket_control_message_get_size g_socket_control_message_get_type g_socket_control_message_serialize g_socket_create_source g_socket_get_blocking g_socket_get_credentials g_socket_get_family g_socket_get_fd g_socket_get_keepalive g_socket_get_listen_backlog g_socket_get_local_address g_socket_get_protocol g_socket_get_remote_address g_socket_get_socket_type g_socket_get_timeout g_socket_get_type g_socket_is_closed g_socket_is_connected g_socket_listen g_socket_listener_accept g_socket_listener_accept_async g_socket_listener_accept_finish g_socket_listener_accept_socket g_socket_listener_accept_socket_async g_socket_listener_accept_socket_finish g_socket_listener_add_address g_socket_listener_add_any_inet_port g_socket_listener_add_inet_port g_socket_listener_add_socket g_socket_listener_close g_socket_listener_get_type g_socket_listener_new g_socket_listener_set_backlog g_socket_new g_socket_new_from_fd g_socket_receive g_socket_receive_from g_socket_receive_message g_socket_receive_with_blocking g_socket_send g_socket_send_message g_socket_send_to g_socket_send_with_blocking g_socket_service_get_type g_socket_service_is_active g_socket_service_new g_socket_service_start g_socket_service_stop g_socket_set_blocking g_socket_set_keepalive g_socket_set_listen_backlog g_socket_set_timeout g_socket_shutdown g_socket_speaks_ipv4 g_srv_target_copy g_srv_target_free g_srv_target_get_hostname g_srv_target_get_port g_srv_target_get_priority g_srv_target_get_type g_srv_target_get_weight g_srv_target_list_sort g_srv_target_new g_tcp_connection_get_graceful_disconnect g_tcp_connection_get_type g_tcp_connection_set_graceful_disconnect g_tcp_wrapper_connection_get_base_io_stream g_tcp_wrapper_connection_get_type g_tcp_wrapper_connection_new g_themed_icon_append_name g_themed_icon_get_names g_themed_icon_get_type g_themed_icon_new g_themed_icon_new_from_names g_themed_icon_new_with_default_fallbacks g_themed_icon_prepend_name g_threaded_socket_service_get_type g_threaded_socket_service_new g_tls_backend_get_certificate_type g_tls_backend_get_client_connection_type g_tls_backend_get_default g_tls_backend_get_server_connection_type g_tls_backend_get_type g_tls_backend_supports_tls g_tls_certificate_get_issuer g_tls_certificate_get_type g_tls_certificate_list_new_from_file g_tls_certificate_new_from_file g_tls_certificate_new_from_files g_tls_certificate_new_from_pem g_tls_certificate_verify g_tls_client_connection_get_accepted_cas g_tls_client_connection_get_server_identity g_tls_client_connection_get_type g_tls_client_connection_get_use_ssl3 g_tls_client_connection_get_validation_flags g_tls_client_connection_new g_tls_client_connection_set_server_identity g_tls_client_connection_set_use_ssl3 g_tls_client_connection_set_validation_flags g_tls_connection_emit_accept_certificate g_tls_connection_get_certificate g_tls_connection_get_peer_certificate g_tls_connection_get_peer_certificate_errors g_tls_connection_get_rehandshake_mode g_tls_connection_get_require_close_notify g_tls_connection_get_type g_tls_connection_get_use_system_certdb g_tls_connection_handshake g_tls_connection_handshake_async g_tls_connection_handshake_finish g_tls_connection_set_certificate g_tls_connection_set_rehandshake_mode g_tls_connection_set_require_close_notify g_tls_connection_set_use_system_certdb g_tls_error_quark g_tls_server_connection_get_type g_tls_server_connection_new g_unix_connection_get_type g_unix_connection_receive_credentials g_unix_connection_receive_fd g_unix_connection_send_credentials g_unix_connection_send_fd g_unix_credentials_message_get_credentials g_unix_credentials_message_get_type g_unix_credentials_message_is_supported g_unix_credentials_message_new g_unix_credentials_message_new_with_credentials g_unix_fd_list_append g_unix_fd_list_get g_unix_fd_list_get_length g_unix_fd_list_get_type g_unix_fd_list_new g_unix_fd_list_new_from_array g_unix_fd_list_peek_fds g_unix_fd_list_steal_fds g_unix_fd_message_append_fd g_unix_fd_message_get_fd_list g_unix_fd_message_get_type g_unix_fd_message_new g_unix_fd_message_new_with_fd_list g_unix_fd_message_steal_fds g_unix_input_stream_get_close_fd g_unix_input_stream_get_fd g_unix_input_stream_get_type g_unix_input_stream_new g_unix_input_stream_set_close_fd g_unix_is_mount_path_system_internal g_unix_mount_at g_unix_mount_compare g_unix_mount_free g_unix_mount_get_device_path g_unix_mount_get_fs_type g_unix_mount_get_mount_path g_unix_mount_guess_can_eject g_unix_mount_guess_icon g_unix_mount_guess_name g_unix_mount_guess_should_display g_unix_mount_is_readonly g_unix_mount_is_system_internal g_unix_mount_monitor_get_type g_unix_mount_monitor_new g_unix_mount_monitor_set_rate_limit g_unix_mount_point_compare g_unix_mount_point_free g_unix_mount_point_get_device_path g_unix_mount_point_get_fs_type g_unix_mount_point_get_mount_path g_unix_mount_point_guess_can_eject g_unix_mount_point_guess_icon g_unix_mount_point_guess_name g_unix_mount_point_is_loopback g_unix_mount_point_is_readonly g_unix_mount_point_is_user_mountable g_unix_mount_points_changed_since g_unix_mount_points_get g_unix_mounts_changed_since g_unix_mounts_get g_unix_output_stream_get_close_fd g_unix_output_stream_get_fd g_unix_output_stream_get_type g_unix_output_stream_new g_unix_output_stream_set_close_fd g_unix_socket_address_abstract_names_supported g_unix_socket_address_get_address_type g_unix_socket_address_get_path g_unix_socket_address_get_path_len g_unix_socket_address_get_type g_unix_socket_address_new g_unix_socket_address_new_with_type g_vfs_get_default g_vfs_get_file_for_path g_vfs_get_file_for_uri g_vfs_get_local g_vfs_get_supported_uri_schemes g_vfs_get_type g_vfs_is_active g_vfs_parse_name g_volume_can_eject g_volume_can_mount g_volume_eject_with_operation g_volume_eject_with_operation_finish g_volume_enumerate_identifiers g_volume_get_activation_root g_volume_get_drive g_volume_get_icon g_volume_get_identifier g_volume_get_mount g_volume_get_name g_volume_get_type g_volume_get_uuid g_volume_monitor_get g_volume_monitor_get_connected_drives g_volume_monitor_get_mount_for_uuid g_volume_monitor_get_mounts g_volume_monitor_get_type g_volume_monitor_get_volume_for_uuid g_volume_monitor_get_volumes g_volume_mount g_volume_mount_finish g_volume_should_automount g_zlib_compressor_get_file_info g_zlib_compressor_get_type g_zlib_compressor_new g_zlib_compressor_set_file_info g_zlib_decompressor_get_file_info g_zlib_decompressor_get_type g_zlib_decompressor_new
syn keyword gioConstant G_APPLICATION_FLAGS_NONE G_APPLICATION_HANDLES_COMMAND_LINE G_APPLICATION_HANDLES_OPEN G_APPLICATION_IS_LAUNCHER G_APPLICATION_IS_SERVICE G_APPLICATION_SEND_ENVIRONMENT G_APP_INFO_CREATE_NEEDS_TERMINAL G_APP_INFO_CREATE_NONE G_APP_INFO_CREATE_SUPPORTS_STARTUP_NOTIFICATION G_APP_INFO_CREATE_SUPPORTS_URIS G_ASK_PASSWORD_ANONYMOUS_SUPPORTED G_ASK_PASSWORD_NEED_DOMAIN G_ASK_PASSWORD_NEED_PASSWORD G_ASK_PASSWORD_NEED_USERNAME G_ASK_PASSWORD_SAVING_SUPPORTED G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT G_BUS_NAME_OWNER_FLAGS_NONE G_BUS_NAME_OWNER_FLAGS_REPLACE G_BUS_NAME_WATCHER_FLAGS_AUTO_START G_BUS_NAME_WATCHER_FLAGS_NONE G_BUS_TYPE_NONE G_BUS_TYPE_SESSION G_BUS_TYPE_STARTER G_BUS_TYPE_SYSTEM G_CONVERTER_CONVERTED G_CONVERTER_ERROR G_CONVERTER_FINISHED G_CONVERTER_FLUSH G_CONVERTER_FLUSHED G_CONVERTER_INPUT_AT_END G_CONVERTER_NO_FLAGS G_CREDENTIALS_TYPE_FREEBSD_CMSGCRED G_CREDENTIALS_TYPE_INVALID G_CREDENTIALS_TYPE_LINUX_UCRED G_DATA_STREAM_BYTE_ORDER_BIG_ENDIAN G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN G_DATA_STREAM_BYTE_ORDER_LITTLE_ENDIAN G_DATA_STREAM_NEWLINE_TYPE_ANY G_DATA_STREAM_NEWLINE_TYPE_CR G_DATA_STREAM_NEWLINE_TYPE_CR_LF G_DATA_STREAM_NEWLINE_TYPE_LF G_DBUS_CALL_FLAGS_NONE G_DBUS_CALL_FLAGS_NO_AUTO_START G_DBUS_CAPABILITY_FLAGS_NONE G_DBUS_CAPABILITY_FLAGS_UNIX_FD_PASSING G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_ALLOW_ANONYMOUS G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_SERVER G_DBUS_CONNECTION_FLAGS_DELAY_MESSAGE_PROCESSING G_DBUS_CONNECTION_FLAGS_MESSAGE_BUS_CONNECTION G_DBUS_CONNECTION_FLAGS_NONE G_DBUS_ERROR_ACCESS_DENIED G_DBUS_ERROR_ADDRESS_IN_USE G_DBUS_ERROR_ADT_AUDIT_DATA_UNKNOWN G_DBUS_ERROR_AUTH_FAILED G_DBUS_ERROR_BAD_ADDRESS G_DBUS_ERROR_DISCONNECTED G_DBUS_ERROR_FAILED G_DBUS_ERROR_FILE_EXISTS G_DBUS_ERROR_FILE_NOT_FOUND G_DBUS_ERROR_INVALID_ARGS G_DBUS_ERROR_INVALID_FILE_CONTENT G_DBUS_ERROR_INVALID_SIGNATURE G_DBUS_ERROR_IO_ERROR G_DBUS_ERROR_LIMITS_EXCEEDED G_DBUS_ERROR_MATCH_RULE_INVALID G_DBUS_ERROR_MATCH_RULE_NOT_FOUND G_DBUS_ERROR_NAME_HAS_NO_OWNER G_DBUS_ERROR_NOT_SUPPORTED G_DBUS_ERROR_NO_MEMORY G_DBUS_ERROR_NO_NETWORK G_DBUS_ERROR_NO_REPLY G_DBUS_ERROR_NO_SERVER G_DBUS_ERROR_OBJECT_PATH_IN_USE G_DBUS_ERROR_SELINUX_SECURITY_CONTEXT_UNKNOWN G_DBUS_ERROR_SERVICE_UNKNOWN G_DBUS_ERROR_SPAWN_CHILD_EXITED G_DBUS_ERROR_SPAWN_CHILD_SIGNALED G_DBUS_ERROR_SPAWN_CONFIG_INVALID G_DBUS_ERROR_SPAWN_EXEC_FAILED G_DBUS_ERROR_SPAWN_FAILED G_DBUS_ERROR_SPAWN_FILE_INVALID G_DBUS_ERROR_SPAWN_FORK_FAILED G_DBUS_ERROR_SPAWN_NO_MEMORY G_DBUS_ERROR_SPAWN_PERMISSIONS_INVALID G_DBUS_ERROR_SPAWN_SERVICE_INVALID G_DBUS_ERROR_SPAWN_SERVICE_NOT_FOUND G_DBUS_ERROR_SPAWN_SETUP_FAILED G_DBUS_ERROR_TIMED_OUT G_DBUS_ERROR_TIMEOUT G_DBUS_ERROR_UNIX_PROCESS_ID_UNKNOWN G_DBUS_ERROR_UNKNOWN_METHOD G_DBUS_MESSAGE_BYTE_ORDER_BIG_ENDIAN G_DBUS_MESSAGE_BYTE_ORDER_LITTLE_ENDIAN G_DBUS_MESSAGE_FLAGS_NONE G_DBUS_MESSAGE_FLAGS_NO_AUTO_START G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED G_DBUS_MESSAGE_HEADER_FIELD_DESTINATION G_DBUS_MESSAGE_HEADER_FIELD_ERROR_NAME G_DBUS_MESSAGE_HEADER_FIELD_INTERFACE G_DBUS_MESSAGE_HEADER_FIELD_INVALID G_DBUS_MESSAGE_HEADER_FIELD_MEMBER G_DBUS_MESSAGE_HEADER_FIELD_NUM_UNIX_FDS G_DBUS_MESSAGE_HEADER_FIELD_PATH G_DBUS_MESSAGE_HEADER_FIELD_REPLY_SERIAL G_DBUS_MESSAGE_HEADER_FIELD_SENDER G_DBUS_MESSAGE_HEADER_FIELD_SIGNATURE G_DBUS_MESSAGE_TYPE_ERROR G_DBUS_MESSAGE_TYPE_INVALID G_DBUS_MESSAGE_TYPE_METHOD_CALL G_DBUS_MESSAGE_TYPE_METHOD_RETURN G_DBUS_MESSAGE_TYPE_SIGNAL G_DBUS_PROPERTY_INFO_FLAGS_NONE G_DBUS_PROPERTY_INFO_FLAGS_READABLE G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES G_DBUS_PROXY_FLAGS_NONE G_DBUS_SEND_MESSAGE_FLAGS_NONE G_DBUS_SEND_MESSAGE_FLAGS_PRESERVE_SERIAL G_DBUS_SERVER_FLAGS_AUTHENTICATION_ALLOW_ANONYMOUS G_DBUS_SERVER_FLAGS_NONE G_DBUS_SERVER_FLAGS_RUN_IN_THREAD G_DBUS_SIGNAL_FLAGS_NONE G_DBUS_SIGNAL_FLAGS_NO_MATCH_RULE G_DBUS_SUBTREE_FLAGS_DISPATCH_TO_UNENUMERATED_NODES G_DBUS_SUBTREE_FLAGS_NONE G_DRIVE_START_NONE G_DRIVE_START_STOP_TYPE_MULTIDISK G_DRIVE_START_STOP_TYPE_NETWORK G_DRIVE_START_STOP_TYPE_PASSWORD G_DRIVE_START_STOP_TYPE_SHUTDOWN G_DRIVE_START_STOP_TYPE_UNKNOWN G_EMBLEM_ORIGIN_DEVICE G_EMBLEM_ORIGIN_LIVEMETADATA G_EMBLEM_ORIGIN_TAG G_EMBLEM_ORIGIN_UNKNOWN G_FILESYSTEM_PREVIEW_TYPE_IF_ALWAYS G_FILESYSTEM_PREVIEW_TYPE_IF_LOCAL G_FILESYSTEM_PREVIEW_TYPE_NEVER G_FILE_ATTRIBUTE_INFO_COPY_WHEN_MOVED G_FILE_ATTRIBUTE_INFO_COPY_WITH_FILE G_FILE_ATTRIBUTE_INFO_NONE G_FILE_ATTRIBUTE_STATUS_ERROR_SETTING G_FILE_ATTRIBUTE_STATUS_SET G_FILE_ATTRIBUTE_STATUS_UNSET G_FILE_ATTRIBUTE_TYPE_BOOLEAN G_FILE_ATTRIBUTE_TYPE_BYTE_STRING G_FILE_ATTRIBUTE_TYPE_INT32 G_FILE_ATTRIBUTE_TYPE_INT64 G_FILE_ATTRIBUTE_TYPE_INVALID G_FILE_ATTRIBUTE_TYPE_OBJECT G_FILE_ATTRIBUTE_TYPE_STRING G_FILE_ATTRIBUTE_TYPE_STRINGV G_FILE_ATTRIBUTE_TYPE_UINT32 G_FILE_ATTRIBUTE_TYPE_UINT64 G_FILE_COPY_ALL_METADATA G_FILE_COPY_BACKUP G_FILE_COPY_NOFOLLOW_SYMLINKS G_FILE_COPY_NONE G_FILE_COPY_NO_FALLBACK_FOR_MOVE G_FILE_COPY_OVERWRITE G_FILE_COPY_TARGET_DEFAULT_PERMS G_FILE_CREATE_NONE G_FILE_CREATE_PRIVATE G_FILE_CREATE_REPLACE_DESTINATION G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED G_FILE_MONITOR_EVENT_CHANGED G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT G_FILE_MONITOR_EVENT_CREATED G_FILE_MONITOR_EVENT_DELETED G_FILE_MONITOR_EVENT_MOVED G_FILE_MONITOR_EVENT_PRE_UNMOUNT G_FILE_MONITOR_EVENT_UNMOUNTED G_FILE_MONITOR_NONE G_FILE_MONITOR_SEND_MOVED G_FILE_MONITOR_WATCH_MOUNTS G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS G_FILE_QUERY_INFO_NONE G_FILE_TYPE_DIRECTORY G_FILE_TYPE_MOUNTABLE G_FILE_TYPE_REGULAR G_FILE_TYPE_SHORTCUT G_FILE_TYPE_SPECIAL G_FILE_TYPE_SYMBOLIC_LINK G_FILE_TYPE_UNKNOWN G_IO_ERROR_ADDRESS_IN_USE G_IO_ERROR_ALREADY_MOUNTED G_IO_ERROR_BUSY G_IO_ERROR_CANCELLED G_IO_ERROR_CANT_CREATE_BACKUP G_IO_ERROR_CLOSED G_IO_ERROR_CONNECTION_REFUSED G_IO_ERROR_DBUS_ERROR G_IO_ERROR_EXISTS G_IO_ERROR_FAILED G_IO_ERROR_FAILED_HANDLED G_IO_ERROR_FILENAME_TOO_LONG G_IO_ERROR_HOST_NOT_FOUND G_IO_ERROR_HOST_UNREACHABLE G_IO_ERROR_INVALID_ARGUMENT G_IO_ERROR_INVALID_DATA G_IO_ERROR_INVALID_FILENAME G_IO_ERROR_IS_DIRECTORY G_IO_ERROR_NETWORK_UNREACHABLE G_IO_ERROR_NOT_DIRECTORY G_IO_ERROR_NOT_EMPTY G_IO_ERROR_NOT_FOUND G_IO_ERROR_NOT_INITIALIZED G_IO_ERROR_NOT_MOUNTABLE_FILE G_IO_ERROR_NOT_MOUNTED G_IO_ERROR_NOT_REGULAR_FILE G_IO_ERROR_NOT_SUPPORTED G_IO_ERROR_NOT_SYMBOLIC_LINK G_IO_ERROR_NO_SPACE G_IO_ERROR_PARTIAL_INPUT G_IO_ERROR_PENDING G_IO_ERROR_PERMISSION_DENIED G_IO_ERROR_PROXY_AUTH_FAILED G_IO_ERROR_PROXY_FAILED G_IO_ERROR_PROXY_NEED_AUTH G_IO_ERROR_PROXY_NOT_ALLOWED G_IO_ERROR_READ_ONLY G_IO_ERROR_TIMED_OUT G_IO_ERROR_TOO_MANY_LINKS G_IO_ERROR_TOO_MANY_OPEN_FILES G_IO_ERROR_WOULD_BLOCK G_IO_ERROR_WOULD_MERGE G_IO_ERROR_WOULD_RECURSE G_IO_ERROR_WRONG_ETAG G_IO_STREAM_SPLICE_CLOSE_STREAM1 G_IO_STREAM_SPLICE_CLOSE_STREAM2 G_IO_STREAM_SPLICE_NONE G_IO_STREAM_SPLICE_WAIT_FOR_BOTH G_MOUNT_MOUNT_NONE G_MOUNT_OPERATION_ABORTED G_MOUNT_OPERATION_HANDLED G_MOUNT_OPERATION_UNHANDLED G_MOUNT_UNMOUNT_FORCE G_MOUNT_UNMOUNT_NONE G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE G_OUTPUT_STREAM_SPLICE_CLOSE_TARGET G_OUTPUT_STREAM_SPLICE_NONE G_PASSWORD_SAVE_FOR_SESSION G_PASSWORD_SAVE_NEVER G_PASSWORD_SAVE_PERMANENTLY G_RESOLVER_ERROR_INTERNAL G_RESOLVER_ERROR_NOT_FOUND G_RESOLVER_ERROR_TEMPORARY_FAILURE G_SETTINGS_BIND_DEFAULT G_SETTINGS_BIND_GET G_SETTINGS_BIND_GET_NO_CHANGES G_SETTINGS_BIND_INVERT_BOOLEAN G_SETTINGS_BIND_NO_SENSITIVITY G_SETTINGS_BIND_SET G_SOCKET_FAMILY_INVALID G_SOCKET_FAMILY_IPV4 G_SOCKET_FAMILY_IPV6 G_SOCKET_FAMILY_UNIX G_SOCKET_MSG_DONTROUTE G_SOCKET_MSG_NONE G_SOCKET_MSG_OOB G_SOCKET_MSG_PEEK G_SOCKET_PROTOCOL_DEFAULT G_SOCKET_PROTOCOL_SCTP G_SOCKET_PROTOCOL_TCP G_SOCKET_PROTOCOL_UDP G_SOCKET_PROTOCOL_UNKNOWN G_SOCKET_TYPE_DATAGRAM G_SOCKET_TYPE_INVALID G_SOCKET_TYPE_SEQPACKET G_SOCKET_TYPE_STREAM G_TLS_AUTHENTICATION_NONE G_TLS_AUTHENTICATION_REQUESTED G_TLS_AUTHENTICATION_REQUIRED G_TLS_CERTIFICATE_BAD_IDENTITY G_TLS_CERTIFICATE_EXPIRED G_TLS_CERTIFICATE_GENERIC_ERROR G_TLS_CERTIFICATE_INSECURE G_TLS_CERTIFICATE_NOT_ACTIVATED G_TLS_CERTIFICATE_REVOKED G_TLS_CERTIFICATE_UNKNOWN_CA G_TLS_CERTIFICATE_VALIDATE_ALL G_TLS_ERROR_BAD_CERTIFICATE G_TLS_ERROR_CERTIFICATE_REQUIRED G_TLS_ERROR_EOF G_TLS_ERROR_HANDSHAKE G_TLS_ERROR_MISC G_TLS_ERROR_NOT_TLS G_TLS_ERROR_UNAVAILABLE G_TLS_REHANDSHAKE_NEVER G_TLS_REHANDSHAKE_SAFELY G_TLS_REHANDSHAKE_UNSAFELY G_UNIX_SOCKET_ADDRESS_ABSTRACT G_UNIX_SOCKET_ADDRESS_ABSTRACT_PADDED G_UNIX_SOCKET_ADDRESS_ANONYMOUS G_UNIX_SOCKET_ADDRESS_INVALID G_UNIX_SOCKET_ADDRESS_PATH G_ZLIB_COMPRESSOR_FORMAT_GZIP G_ZLIB_COMPRESSOR_FORMAT_RAW G_ZLIB_COMPRESSOR_FORMAT_ZLIB
syn keyword gioStruct GAction GActionGroup GActionGroupInterface GActionInterface GAppInfo GAppInfoIface GAppLaunchContext GAppLaunchContextClass GAppLaunchContextPrivate GApplication GApplicationClass GApplicationCommandLine GApplicationCommandLineClass GApplicationCommandLinePrivate GApplicationPrivate GAsyncInitable GAsyncInitableIface GAsyncResult GAsyncResultIface GBufferedInputStream GBufferedInputStreamClass GBufferedInputStreamPrivate GBufferedOutputStream GBufferedOutputStreamClass GBufferedOutputStreamPrivate GCancellable GCancellableClass GCancellablePrivate GCharsetConverter GCharsetConverterClass GConverter GConverterIface GConverterInputStream GConverterInputStreamClass GConverterInputStreamPrivate GConverterOutputStream GConverterOutputStreamClass GConverterOutputStreamPrivate GCredentials GCredentialsClass GDBusAnnotationInfo GDBusArgInfo GDBusAuthObserver GDBusConnection GDBusErrorEntry GDBusInterfaceInfo GDBusInterfaceVTable GDBusMessage GDBusMethodInfo GDBusMethodInvocation GDBusNodeInfo GDBusPropertyInfo GDBusProxy GDBusProxyClass GDBusProxyPrivate GDBusServer GDBusSignalInfo GDBusSubtreeVTable GDataInputStream GDataInputStreamClass GDataInputStreamPrivate GDataOutputStream GDataOutputStreamClass GDataOutputStreamPrivate GDesktopAppInfo GDesktopAppInfoClass GDrive GDriveIface GDummyTlsBackend GDummyTlsBackendClass GEmblem GEmblemClass GEmblemedIcon GEmblemedIconClass GEmblemedIconPrivate GFile GFileAttributeInfo GFileAttributeInfoList GFileAttributeMatcher GFileDescriptorBased GFileDescriptorBasedIface GFileEnumerator GFileEnumeratorClass GFileEnumeratorPrivate GFileIOStream GFileIOStreamClass GFileIOStreamPrivate GFileIcon GFileIconClass GFileIface GFileInfo GFileInfoClass GFileInputStream GFileInputStreamClass GFileInputStreamPrivate GFileMonitor GFileMonitorClass GFileMonitorPrivate GFileOutputStream GFileOutputStreamClass GFileOutputStreamPrivate GFilenameCompleter GFilenameCompleterClass GFilterInputStream GFilterInputStreamClass GFilterOutputStream GFilterOutputStreamClass GIOExtension GIOExtensionPoint GIOModule GIOModuleClass GIOSchedulerJob GIOStream GIOStreamAdapter GIOStreamClass GIOStreamPrivate GIcon GIconIface GInetAddress GInetAddressClass GInetAddressPrivate GInetSocketAddress GInetSocketAddressClass GInetSocketAddressPrivate GInitable GInitableIface GInputStream GInputStreamClass GInputStreamPrivate GInputVector GLoadableIcon GLoadableIconIface GMemoryInputStream GMemoryInputStreamClass GMemoryInputStreamPrivate GMemoryOutputStream GMemoryOutputStreamClass GMemoryOutputStreamPrivate GMount GMountIface GMountOperation GMountOperationClass GMountOperationPrivate GNetworkAddress GNetworkAddressClass GNetworkAddressPrivate GNetworkService GNetworkServiceClass GNetworkServicePrivate GOutputStream GOutputStreamClass GOutputStreamPrivate GOutputVector GPermission GPermissionClass GPermissionPrivate GPollableInputStream GPollableInputStreamInterface GPollableOutputStream GPollableOutputStreamInterface GProxy GProxyAddress GProxyAddressClass GProxyAddressEnumerator GProxyAddressEnumeratorClass GProxyAddressEnumeratorPrivate GProxyAddressPrivate GProxyInterface GProxyResolver GProxyResolverInterface GResolver GResolverClass GResolverPrivate GSeekable GSeekableIface GSettings GSettingsBackend GSettingsBackendClass GSettingsBackendPrivate GSettingsClass GSettingsPrivate GSimpleAction GSimpleActionClass GSimpleActionGroup GSimpleActionGroupClass GSimpleActionGroupPrivate GSimpleActionPrivate GSimpleAsyncResult GSimpleAsyncResultClass GSimplePermission GSocket GSocketAddress GSocketAddressClass GSocketAddressEnumerator GSocketAddressEnumeratorClass GSocketClass GSocketClient GSocketClientClass GSocketClientPrivate GSocketConnectable GSocketConnectableIface GSocketConnection GSocketConnectionClass GSocketConnectionPrivate GSocketControlMessage GSocketControlMessageClass GSocketControlMessagePrivate GSocketListener GSocketListenerClass GSocketListenerPrivate GSocketPrivate GSocketService GSocketServiceClass GSocketServicePrivate GSocks4Proxy GSocks4ProxyClass GSocks4aProxy GSocks4aProxyClass GSocks5Proxy GSocks5ProxyClass GSrvTarget GTcpConnection GTcpConnectionClass GTcpConnectionPrivate GTcpWrapperConnection GTcpWrapperConnectionClass GTcpWrapperConnectionPrivate GThemedIcon GThemedIconClass GThreadedSocketService GThreadedSocketServiceClass GThreadedSocketServicePrivate GTlsBackend GTlsBackendInterface GTlsCertificate GTlsCertificateClass GTlsCertificatePrivate GTlsClientConnection GTlsClientConnectionInterface GTlsClientContext GTlsConnection GTlsConnectionClass GTlsConnectionPrivate GTlsContext GTlsServerConnection GTlsServerConnectionInterface GTlsServerContext GUnixConnection GUnixConnectionClass GUnixConnectionPrivate GUnixCredentialsMessage GUnixCredentialsMessageClass GUnixCredentialsMessagePrivate GUnixFDList GUnixFDListClass GUnixFDListPrivate GUnixFDMessage GUnixFDMessageClass GUnixFDMessagePrivate GUnixInputStream GUnixInputStreamClass GUnixInputStreamPrivate GUnixMountEntry GUnixMountMonitor GUnixMountMonitorClass GUnixMountPoint GUnixOutputStream GUnixOutputStreamClass GUnixOutputStreamPrivate GUnixSocketAddress GUnixSocketAddressClass GUnixSocketAddressPrivate GVfs GVfsClass GVolume GVolumeIface GVolumeMonitor GVolumeMonitorClass GZlibCompressor GZlibCompressorClass GZlibDecompressor GZlibDecompressorClass
syn keyword gioMacro G_ACTION G_ACTION_GET_IFACE G_ACTION_GROUP G_ACTION_GROUP_GET_IFACE G_APPLICATION G_APPLICATION_CLASS G_APPLICATION_COMMAND_LINE G_APPLICATION_COMMAND_LINE_CLASS G_APPLICATION_COMMAND_LINE_GET_CLASS G_APPLICATION_GET_CLASS G_APP_INFO G_APP_INFO_GET_IFACE G_APP_LAUNCH_CONTEXT G_APP_LAUNCH_CONTEXT_CLASS G_APP_LAUNCH_CONTEXT_GET_CLASS G_ASYNC_INITABLE G_ASYNC_INITABLE_GET_IFACE G_ASYNC_RESULT G_ASYNC_RESULT_GET_IFACE G_BUFFERED_INPUT_STREAM G_BUFFERED_INPUT_STREAM_CLASS G_BUFFERED_INPUT_STREAM_GET_CLASS G_BUFFERED_OUTPUT_STREAM G_BUFFERED_OUTPUT_STREAM_CLASS G_BUFFERED_OUTPUT_STREAM_GET_CLASS G_CANCELLABLE G_CANCELLABLE_CLASS G_CANCELLABLE_GET_CLASS G_CHARSET_CONVERTER G_CHARSET_CONVERTER_CLASS G_CHARSET_CONVERTER_GET_CLASS G_CONVERTER G_CONVERTER_GET_IFACE G_CONVERTER_INPUT_STREAM G_CONVERTER_INPUT_STREAM_CLASS G_CONVERTER_INPUT_STREAM_GET_CLASS G_CONVERTER_OUTPUT_STREAM G_CONVERTER_OUTPUT_STREAM_CLASS G_CONVERTER_OUTPUT_STREAM_GET_CLASS G_CREDENTIALS G_CREDENTIALS_CLASS G_CREDENTIALS_GET_CLASS G_DATA_INPUT_STREAM G_DATA_INPUT_STREAM_CLASS G_DATA_INPUT_STREAM_GET_CLASS G_DATA_OUTPUT_STREAM G_DATA_OUTPUT_STREAM_CLASS G_DATA_OUTPUT_STREAM_GET_CLASS G_DBUS_AUTH_OBSERVER G_DBUS_CONNECTION G_DBUS_MESSAGE G_DBUS_METHOD_INVOCATION G_DBUS_PROXY G_DBUS_PROXY_CLASS G_DBUS_PROXY_GET_CLASS G_DBUS_SERVER G_DESKTOP_APP_INFO G_DESKTOP_APP_INFO_CLASS G_DESKTOP_APP_INFO_GET_CLASS G_DRIVE G_DRIVE_GET_IFACE G_DUMMY_TLS_BACKEND G_DUMMY_TLS_BACKEND_CLASS G_DUMMY_TLS_BACKEND_GET_CLASS G_EMBLEM G_EMBLEMED_ICON G_EMBLEMED_ICON_CLASS G_EMBLEMED_ICON_GET_CLASS G_EMBLEM_CLASS G_EMBLEM_GET_CLASS G_FILE G_FILENAME_COMPLETER G_FILENAME_COMPLETER_CLASS G_FILENAME_COMPLETER_GET_CLASS G_FILE_DESCRIPTOR_BASED G_FILE_DESCRIPTOR_BASED_GET_IFACE G_FILE_ENUMERATOR G_FILE_ENUMERATOR_CLASS G_FILE_ENUMERATOR_GET_CLASS G_FILE_GET_IFACE G_FILE_ICON G_FILE_ICON_CLASS G_FILE_ICON_GET_CLASS G_FILE_INFO G_FILE_INFO_CLASS G_FILE_INFO_GET_CLASS G_FILE_INPUT_STREAM G_FILE_INPUT_STREAM_CLASS G_FILE_INPUT_STREAM_GET_CLASS G_FILE_IO_STREAM G_FILE_IO_STREAM_CLASS G_FILE_IO_STREAM_GET_CLASS G_FILE_MONITOR G_FILE_MONITOR_CLASS G_FILE_MONITOR_GET_CLASS G_FILE_OUTPUT_STREAM G_FILE_OUTPUT_STREAM_CLASS G_FILE_OUTPUT_STREAM_GET_CLASS G_FILTER_INPUT_STREAM G_FILTER_INPUT_STREAM_CLASS G_FILTER_INPUT_STREAM_GET_CLASS G_FILTER_OUTPUT_STREAM G_FILTER_OUTPUT_STREAM_CLASS G_FILTER_OUTPUT_STREAM_GET_CLASS G_ICON G_ICON_GET_IFACE G_INET_ADDRESS G_INET_ADDRESS_CLASS G_INET_ADDRESS_GET_CLASS G_INET_SOCKET_ADDRESS G_INET_SOCKET_ADDRESS_CLASS G_INET_SOCKET_ADDRESS_GET_CLASS G_INITABLE G_INITABLE_GET_IFACE G_INPUT_STREAM G_INPUT_STREAM_CLASS G_INPUT_STREAM_GET_CLASS G_IO_IS_MODULE G_IO_IS_MODULE_CLASS G_IO_MODULE G_IO_MODULE_CLASS G_IO_MODULE_GET_CLASS G_IO_STREAM G_IO_STREAM_CLASS G_IO_STREAM_GET_CLASS G_IS_ACTION G_IS_ACTION_GROUP G_IS_APPLICATION G_IS_APPLICATION_CLASS G_IS_APPLICATION_COMMAND_LINE G_IS_APPLICATION_COMMAND_LINE_CLASS G_IS_APP_INFO G_IS_APP_LAUNCH_CONTEXT G_IS_APP_LAUNCH_CONTEXT_CLASS G_IS_ASYNC_INITABLE G_IS_ASYNC_RESULT G_IS_BUFFERED_INPUT_STREAM G_IS_BUFFERED_INPUT_STREAM_CLASS G_IS_BUFFERED_OUTPUT_STREAM G_IS_BUFFERED_OUTPUT_STREAM_CLASS G_IS_CANCELLABLE G_IS_CANCELLABLE_CLASS G_IS_CHARSET_CONVERTER G_IS_CHARSET_CONVERTER_CLASS G_IS_CONVERTER G_IS_CONVERTER_INPUT_STREAM G_IS_CONVERTER_INPUT_STREAM_CLASS G_IS_CONVERTER_OUTPUT_STREAM G_IS_CONVERTER_OUTPUT_STREAM_CLASS G_IS_CREDENTIALS G_IS_CREDENTIALS_CLASS G_IS_DATA_INPUT_STREAM G_IS_DATA_INPUT_STREAM_CLASS G_IS_DATA_OUTPUT_STREAM G_IS_DATA_OUTPUT_STREAM_CLASS G_IS_DBUS_AUTH_OBSERVER G_IS_DBUS_CONNECTION G_IS_DBUS_MESSAGE G_IS_DBUS_METHOD_INVOCATION G_IS_DBUS_PROXY G_IS_DBUS_PROXY_CLASS G_IS_DBUS_SERVER G_IS_DESKTOP_APP_INFO G_IS_DESKTOP_APP_INFO_CLASS G_IS_DRIVE G_IS_DUMMY_TLS_BACKEND G_IS_DUMMY_TLS_BACKEND_CLASS G_IS_EMBLEM G_IS_EMBLEMED_ICON G_IS_EMBLEMED_ICON_CLASS G_IS_EMBLEM_CLASS G_IS_FILE G_IS_FILENAME_COMPLETER G_IS_FILENAME_COMPLETER_CLASS G_IS_FILE_DESCRIPTOR_BASED G_IS_FILE_ENUMERATOR G_IS_FILE_ENUMERATOR_CLASS G_IS_FILE_ICON G_IS_FILE_ICON_CLASS G_IS_FILE_INFO G_IS_FILE_INFO_CLASS G_IS_FILE_INPUT_STREAM G_IS_FILE_INPUT_STREAM_CLASS G_IS_FILE_IO_STREAM G_IS_FILE_IO_STREAM_CLASS G_IS_FILE_MONITOR G_IS_FILE_MONITOR_CLASS G_IS_FILE_OUTPUT_STREAM G_IS_FILE_OUTPUT_STREAM_CLASS G_IS_FILTER_INPUT_STREAM G_IS_FILTER_INPUT_STREAM_CLASS G_IS_FILTER_OUTPUT_STREAM G_IS_FILTER_OUTPUT_STREAM_CLASS G_IS_ICON G_IS_INET_ADDRESS G_IS_INET_ADDRESS_CLASS G_IS_INET_SOCKET_ADDRESS G_IS_INET_SOCKET_ADDRESS_CLASS G_IS_INITABLE G_IS_INPUT_STREAM G_IS_INPUT_STREAM_CLASS G_IS_IO_STREAM G_IS_IO_STREAM_CLASS G_IS_LOADABLE_ICON G_IS_MEMORY_INPUT_STREAM G_IS_MEMORY_INPUT_STREAM_CLASS G_IS_MEMORY_OUTPUT_STREAM G_IS_MEMORY_OUTPUT_STREAM_CLASS G_IS_MOUNT G_IS_MOUNT_OPERATION G_IS_MOUNT_OPERATION_CLASS G_IS_NETWORK_ADDRESS G_IS_NETWORK_ADDRESS_CLASS G_IS_NETWORK_SERVICE G_IS_NETWORK_SERVICE_CLASS G_IS_OUTPUT_STREAM G_IS_OUTPUT_STREAM_CLASS G_IS_PERMISSION G_IS_PERMISSION_CLASS G_IS_POLLABLE_INPUT_STREAM G_IS_POLLABLE_OUTPUT_STREAM G_IS_PROXY G_IS_PROXY_ADDRESS G_IS_PROXY_ADDRESS_CLASS G_IS_PROXY_ADDRESS_ENUMERATOR G_IS_PROXY_ADDRESS_ENUMERATOR_CLASS G_IS_PROXY_RESOLVER G_IS_RESOLVER G_IS_RESOLVER_CLASS G_IS_SEEKABLE G_IS_SETTINGS G_IS_SETTINGS_BACKEND G_IS_SETTINGS_BACKEND_CLASS G_IS_SETTINGS_CLASS G_IS_SIMPLE_ACTION G_IS_SIMPLE_ACTION_CLASS G_IS_SIMPLE_ACTION_GROUP G_IS_SIMPLE_ACTION_GROUP_CLASS G_IS_SIMPLE_ASYNC_RESULT G_IS_SIMPLE_ASYNC_RESULT_CLASS G_IS_SIMPLE_PERMISSION G_IS_SOCKET G_IS_SOCKET_ADDRESS G_IS_SOCKET_ADDRESS_CLASS G_IS_SOCKET_ADDRESS_ENUMERATOR G_IS_SOCKET_ADDRESS_ENUMERATOR_CLASS G_IS_SOCKET_CLASS G_IS_SOCKET_CLIENT G_IS_SOCKET_CLIENT_CLASS G_IS_SOCKET_CONNECTABLE G_IS_SOCKET_CONNECTION G_IS_SOCKET_CONNECTION_CLASS G_IS_SOCKET_CONTROL_MESSAGE G_IS_SOCKET_CONTROL_MESSAGE_CLASS G_IS_SOCKET_LISTENER G_IS_SOCKET_LISTENER_CLASS G_IS_SOCKET_SERVICE G_IS_SOCKET_SERVICE_CLASS G_IS_SOCKS4A_PROXY G_IS_SOCKS4A_PROXY_CLASS G_IS_SOCKS4_PROXY G_IS_SOCKS4_PROXY_CLASS G_IS_SOCKS5_PROXY G_IS_SOCKS5_PROXY_CLASS G_IS_TCP_CONNECTION G_IS_TCP_CONNECTION_CLASS G_IS_TCP_WRAPPER_CONNECTION G_IS_TCP_WRAPPER_CONNECTION_CLASS G_IS_THEMED_ICON G_IS_THEMED_ICON_CLASS G_IS_THREADED_SOCKET_SERVICE G_IS_THREADED_SOCKET_SERVICE_CLASS G_IS_TLS_BACKEND G_IS_TLS_CERTIFICATE G_IS_TLS_CERTIFICATE_CLASS G_IS_TLS_CLIENT_CONNECTION G_IS_TLS_CONNECTION G_IS_TLS_CONNECTION_CLASS G_IS_TLS_SERVER_CONNECTION G_IS_UNIX_CONNECTION G_IS_UNIX_CONNECTION_CLASS G_IS_UNIX_CREDENTIALS_MESSAGE G_IS_UNIX_CREDENTIALS_MESSAGE_CLASS G_IS_UNIX_FD_LIST G_IS_UNIX_FD_LIST_CLASS G_IS_UNIX_FD_MESSAGE G_IS_UNIX_FD_MESSAGE_CLASS G_IS_UNIX_INPUT_STREAM G_IS_UNIX_INPUT_STREAM_CLASS G_IS_UNIX_MOUNT_MONITOR G_IS_UNIX_MOUNT_MONITOR_CLASS G_IS_UNIX_OUTPUT_STREAM G_IS_UNIX_OUTPUT_STREAM_CLASS G_IS_UNIX_SOCKET_ADDRESS G_IS_UNIX_SOCKET_ADDRESS_CLASS G_IS_VFS G_IS_VFS_CLASS G_IS_VOLUME G_IS_VOLUME_MONITOR G_IS_VOLUME_MONITOR_CLASS G_IS_ZLIB_COMPRESSOR G_IS_ZLIB_COMPRESSOR_CLASS G_IS_ZLIB_DECOMPRESSOR G_IS_ZLIB_DECOMPRESSOR_CLASS G_LOADABLE_ICON G_LOADABLE_ICON_GET_IFACE G_MEMORY_INPUT_STREAM G_MEMORY_INPUT_STREAM_CLASS G_MEMORY_INPUT_STREAM_GET_CLASS G_MEMORY_OUTPUT_STREAM G_MEMORY_OUTPUT_STREAM_CLASS G_MEMORY_OUTPUT_STREAM_GET_CLASS G_MOUNT G_MOUNT_GET_IFACE G_MOUNT_OPERATION G_MOUNT_OPERATION_CLASS G_MOUNT_OPERATION_GET_CLASS G_NETWORK_ADDRESS G_NETWORK_ADDRESS_CLASS G_NETWORK_ADDRESS_GET_CLASS G_NETWORK_SERVICE G_NETWORK_SERVICE_CLASS G_NETWORK_SERVICE_GET_CLASS G_OUTPUT_STREAM G_OUTPUT_STREAM_CLASS G_OUTPUT_STREAM_GET_CLASS G_PERMISSION G_PERMISSION_CLASS G_PERMISSION_GET_CLASS G_POLLABLE_INPUT_STREAM G_POLLABLE_INPUT_STREAM_GET_INTERFACE G_POLLABLE_OUTPUT_STREAM G_POLLABLE_OUTPUT_STREAM_GET_INTERFACE G_PROXY G_PROXY_ADDRESS G_PROXY_ADDRESS_CLASS G_PROXY_ADDRESS_ENUMERATOR G_PROXY_ADDRESS_ENUMERATOR_CLASS G_PROXY_ADDRESS_ENUMERATOR_GET_CLASS G_PROXY_ADDRESS_GET_CLASS G_PROXY_GET_IFACE G_PROXY_RESOLVER G_PROXY_RESOLVER_GET_IFACE G_RESOLVER G_RESOLVER_CLASS G_RESOLVER_GET_CLASS G_SEEKABLE G_SEEKABLE_GET_IFACE G_SETTINGS G_SETTINGS_BACKEND G_SETTINGS_BACKEND_CLASS G_SETTINGS_BACKEND_GET_CLASS G_SETTINGS_CLASS G_SETTINGS_GET_CLASS G_SIMPLE_ACTION G_SIMPLE_ACTION_CLASS G_SIMPLE_ACTION_GET_CLASS G_SIMPLE_ACTION_GROUP G_SIMPLE_ACTION_GROUP_CLASS G_SIMPLE_ACTION_GROUP_GET_CLASS G_SIMPLE_ASYNC_RESULT G_SIMPLE_ASYNC_RESULT_CLASS G_SIMPLE_ASYNC_RESULT_GET_CLASS G_SIMPLE_PERMISSION G_SOCKET G_SOCKET_ADDRESS G_SOCKET_ADDRESS_CLASS G_SOCKET_ADDRESS_ENUMERATOR G_SOCKET_ADDRESS_ENUMERATOR_CLASS G_SOCKET_ADDRESS_ENUMERATOR_GET_CLASS G_SOCKET_ADDRESS_GET_CLASS G_SOCKET_CLASS G_SOCKET_CLIENT G_SOCKET_CLIENT_CLASS G_SOCKET_CLIENT_GET_CLASS G_SOCKET_CONNECTABLE G_SOCKET_CONNECTABLE_GET_IFACE G_SOCKET_CONNECTION G_SOCKET_CONNECTION_CLASS G_SOCKET_CONNECTION_GET_CLASS G_SOCKET_CONTROL_MESSAGE G_SOCKET_CONTROL_MESSAGE_CLASS G_SOCKET_CONTROL_MESSAGE_GET_CLASS G_SOCKET_GET_CLASS G_SOCKET_LISTENER G_SOCKET_LISTENER_CLASS G_SOCKET_LISTENER_GET_CLASS G_SOCKET_SERVICE G_SOCKET_SERVICE_CLASS G_SOCKET_SERVICE_GET_CLASS G_SOCKS4A_PROXY G_SOCKS4A_PROXY_CLASS G_SOCKS4A_PROXY_GET_CLASS G_SOCKS4_PROXY G_SOCKS4_PROXY_CLASS G_SOCKS4_PROXY_GET_CLASS G_SOCKS5_PROXY G_SOCKS5_PROXY_CLASS G_SOCKS5_PROXY_GET_CLASS G_TCP_CONNECTION G_TCP_CONNECTION_CLASS G_TCP_CONNECTION_GET_CLASS G_TCP_WRAPPER_CONNECTION G_TCP_WRAPPER_CONNECTION_CLASS G_TCP_WRAPPER_CONNECTION_GET_CLASS G_THEMED_ICON G_THEMED_ICON_CLASS G_THEMED_ICON_GET_CLASS G_THREADED_SOCKET_SERVICE G_THREADED_SOCKET_SERVICE_CLASS G_THREADED_SOCKET_SERVICE_GET_CLASS G_TLS_BACKEND G_TLS_BACKEND_GET_INTERFACE G_TLS_CERTIFICATE G_TLS_CERTIFICATE_CLASS G_TLS_CERTIFICATE_GET_CLASS G_TLS_CLIENT_CONNECTION G_TLS_CLIENT_CONNECTION_GET_INTERFACE G_TLS_CONNECTION G_TLS_CONNECTION_CLASS G_TLS_CONNECTION_GET_CLASS G_TLS_SERVER_CONNECTION G_TLS_SERVER_CONNECTION_GET_INTERFACE G_TYPE_IS_ASYNC_INITABLE G_TYPE_IS_INITABLE G_UNIX_CONNECTION G_UNIX_CONNECTION_CLASS G_UNIX_CONNECTION_GET_CLASS G_UNIX_CREDENTIALS_MESSAGE G_UNIX_CREDENTIALS_MESSAGE_CLASS G_UNIX_CREDENTIALS_MESSAGE_GET_CLASS G_UNIX_FD_LIST G_UNIX_FD_LIST_CLASS G_UNIX_FD_LIST_GET_CLASS G_UNIX_FD_MESSAGE G_UNIX_FD_MESSAGE_CLASS G_UNIX_FD_MESSAGE_GET_CLASS G_UNIX_INPUT_STREAM G_UNIX_INPUT_STREAM_CLASS G_UNIX_INPUT_STREAM_GET_CLASS G_UNIX_MOUNT_MONITOR G_UNIX_MOUNT_MONITOR_CLASS G_UNIX_OUTPUT_STREAM G_UNIX_OUTPUT_STREAM_CLASS G_UNIX_OUTPUT_STREAM_GET_CLASS G_UNIX_SOCKET_ADDRESS G_UNIX_SOCKET_ADDRESS_CLASS G_UNIX_SOCKET_ADDRESS_GET_CLASS G_VFS G_VFS_CLASS G_VFS_GET_CLASS G_VOLUME G_VOLUME_GET_IFACE G_VOLUME_MONITOR G_VOLUME_MONITOR_CLASS G_VOLUME_MONITOR_GET_CLASS G_ZLIB_COMPRESSOR G_ZLIB_COMPRESSOR_CLASS G_ZLIB_COMPRESSOR_GET_CLASS G_ZLIB_DECOMPRESSOR G_ZLIB_DECOMPRESSOR_CLASS G_ZLIB_DECOMPRESSOR_GET_CLASS
syn keyword gioEnum GAppInfoCreateFlags GApplicationFlags GAskPasswordFlags GBusNameOwnerFlags GBusNameWatcherFlags GBusType GConverterFlags GConverterResult GCredentialsType GDBusCallFlags GDBusCapabilityFlags GDBusConnectionFlags GDBusError GDBusMessageByteOrder GDBusMessageFlags GDBusMessageHeaderField GDBusMessageType GDBusPropertyInfoFlags GDBusProxyFlags GDBusSendMessageFlags GDBusServerFlags GDBusSignalFlags GDBusSubtreeFlags GDataStreamByteOrder GDataStreamNewlineType GDriveStartFlags GDriveStartStopType GEmblemOrigin GFileAttributeInfoFlags GFileAttributeStatus GFileAttributeType GFileCopyFlags GFileCreateFlags GFileMonitorEvent GFileMonitorFlags GFileQueryInfoFlags GFileType GFilesystemPreviewType GIOErrorEnum GIOStreamSpliceFlags GMountMountFlags GMountOperationResult GMountUnmountFlags GOutputStreamSpliceFlags GPasswordSave GResolverError GSettingsBindFlags GSocketFamily GSocketMsgFlags GSocketProtocol GSocketType GTlsAuthenticationMode GTlsCertificateFlags GTlsError GTlsRehandshakeMode GUnixSocketAddressType GZlibCompressorFormat
syn keyword gioUserFunction GAsyncReadyCallback GBusAcquiredCallback GBusNameAcquiredCallback GBusNameAppearedCallback GBusNameLostCallback GBusNameVanishedCallback GCancellableSourceFunc GDBusInterfaceGetPropertyFunc GDBusInterfaceMethodCallFunc GDBusInterfaceSetPropertyFunc GDBusMessageFilterFunction GDBusSignalCallback GDBusSubtreeDispatchFunc GDBusSubtreeEnumerateFunc GDBusSubtreeIntrospectFunc GFileProgressCallback GFileReadMoreCallback GIOSchedulerJobFunc GPollableSourceFunc GReallocFunc GSettingsBindGetMapping GSettingsBindSetMapping GSettingsGetMapping GSimpleAsyncThreadFunc GSocketSourceFunc
syn keyword gioDefine G_DBUS_ERROR G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE G_FILE_ATTRIBUTE_ACCESS_CAN_READ G_FILE_ATTRIBUTE_ACCESS_CAN_RENAME G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE G_FILE_ATTRIBUTE_DOS_IS_ARCHIVE G_FILE_ATTRIBUTE_DOS_IS_SYSTEM G_FILE_ATTRIBUTE_ETAG_VALUE G_FILE_ATTRIBUTE_FILESYSTEM_FREE G_FILE_ATTRIBUTE_FILESYSTEM_READONLY G_FILE_ATTRIBUTE_FILESYSTEM_SIZE G_FILE_ATTRIBUTE_FILESYSTEM_TYPE G_FILE_ATTRIBUTE_FILESYSTEM_USE_PREVIEW G_FILE_ATTRIBUTE_GVFS_BACKEND G_FILE_ATTRIBUTE_ID_FILE G_FILE_ATTRIBUTE_ID_FILESYSTEM G_FILE_ATTRIBUTE_MOUNTABLE_CAN_EJECT G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT G_FILE_ATTRIBUTE_MOUNTABLE_CAN_POLL G_FILE_ATTRIBUTE_MOUNTABLE_CAN_START G_FILE_ATTRIBUTE_MOUNTABLE_CAN_START_DEGRADED G_FILE_ATTRIBUTE_MOUNTABLE_CAN_STOP G_FILE_ATTRIBUTE_MOUNTABLE_CAN_UNMOUNT G_FILE_ATTRIBUTE_MOUNTABLE_HAL_UDI G_FILE_ATTRIBUTE_MOUNTABLE_IS_MEDIA_CHECK_AUTOMATIC G_FILE_ATTRIBUTE_MOUNTABLE_START_STOP_TYPE G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE_FILE G_FILE_ATTRIBUTE_OWNER_GROUP G_FILE_ATTRIBUTE_OWNER_USER G_FILE_ATTRIBUTE_OWNER_USER_REAL G_FILE_ATTRIBUTE_PREVIEW_ICON G_FILE_ATTRIBUTE_SELINUX_CONTEXT G_FILE_ATTRIBUTE_STANDARD_ALLOCATED_SIZE G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE G_FILE_ATTRIBUTE_STANDARD_COPY_NAME G_FILE_ATTRIBUTE_STANDARD_DESCRIPTION G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME G_FILE_ATTRIBUTE_STANDARD_EDIT_NAME G_FILE_ATTRIBUTE_STANDARD_FAST_CONTENT_TYPE G_FILE_ATTRIBUTE_STANDARD_ICON G_FILE_ATTRIBUTE_STANDARD_IS_BACKUP G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK G_FILE_ATTRIBUTE_STANDARD_IS_VIRTUAL G_FILE_ATTRIBUTE_STANDARD_NAME G_FILE_ATTRIBUTE_STANDARD_SIZE G_FILE_ATTRIBUTE_STANDARD_SORT_ORDER G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET G_FILE_ATTRIBUTE_STANDARD_TARGET_URI G_FILE_ATTRIBUTE_STANDARD_TYPE G_FILE_ATTRIBUTE_THUMBNAILING_FAILED G_FILE_ATTRIBUTE_THUMBNAIL_PATH G_FILE_ATTRIBUTE_TIME_ACCESS G_FILE_ATTRIBUTE_TIME_ACCESS_USEC G_FILE_ATTRIBUTE_TIME_CHANGED G_FILE_ATTRIBUTE_TIME_CHANGED_USEC G_FILE_ATTRIBUTE_TIME_CREATED G_FILE_ATTRIBUTE_TIME_CREATED_USEC G_FILE_ATTRIBUTE_TIME_MODIFIED G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC G_FILE_ATTRIBUTE_TRASH_DELETION_DATE G_FILE_ATTRIBUTE_TRASH_ITEM_COUNT G_FILE_ATTRIBUTE_TRASH_ORIG_PATH G_FILE_ATTRIBUTE_UNIX_BLOCKS G_FILE_ATTRIBUTE_UNIX_BLOCK_SIZE G_FILE_ATTRIBUTE_UNIX_DEVICE G_FILE_ATTRIBUTE_UNIX_GID G_FILE_ATTRIBUTE_UNIX_INODE G_FILE_ATTRIBUTE_UNIX_IS_MOUNTPOINT G_FILE_ATTRIBUTE_UNIX_MODE G_FILE_ATTRIBUTE_UNIX_NLINK G_FILE_ATTRIBUTE_UNIX_RDEV G_FILE_ATTRIBUTE_UNIX_UID G_IO_ERROR G_IO_TYPE_MODULE G_PROXY_EXTENSION_POINT_NAME G_PROXY_RESOLVER_EXTENSION_POINT_NAME G_RESOLVER_ERROR G_SETTINGS_BACKEND_EXTENSION_POINT_NAME G_TLS_BACKEND_EXTENSION_POINT_NAME G_TLS_ERROR G_TYPE_ACTION G_TYPE_ACTION_GROUP G_TYPE_APPLICATION G_TYPE_APPLICATION_COMMAND_LINE G_TYPE_APP_INFO G_TYPE_APP_LAUNCH_CONTEXT G_TYPE_ASYNC_INITABLE G_TYPE_ASYNC_RESULT G_TYPE_BUFFERED_INPUT_STREAM G_TYPE_BUFFERED_OUTPUT_STREAM G_TYPE_CANCELLABLE G_TYPE_CHARSET_CONVERTER G_TYPE_CONVERTER G_TYPE_CONVERTER_INPUT_STREAM G_TYPE_CONVERTER_OUTPUT_STREAM G_TYPE_CREDENTIALS G_TYPE_DATA_INPUT_STREAM G_TYPE_DATA_OUTPUT_STREAM G_TYPE_DBUS_ANNOTATION_INFO G_TYPE_DBUS_ARG_INFO G_TYPE_DBUS_AUTH_OBSERVER G_TYPE_DBUS_CONNECTION G_TYPE_DBUS_INTERFACE_INFO G_TYPE_DBUS_MESSAGE G_TYPE_DBUS_METHOD_INFO G_TYPE_DBUS_METHOD_INVOCATION G_TYPE_DBUS_NODE_INFO G_TYPE_DBUS_PROPERTY_INFO G_TYPE_DBUS_PROXY G_TYPE_DBUS_SERVER G_TYPE_DBUS_SIGNAL_INFO G_TYPE_DESKTOP_APP_INFO G_TYPE_DRIVE G_TYPE_DUMMY_TLS_BACKEND G_TYPE_EMBLEM G_TYPE_EMBLEMED_ICON G_TYPE_FILE G_TYPE_FILENAME_COMPLETER G_TYPE_FILE_DESCRIPTOR_BASED G_TYPE_FILE_ENUMERATOR G_TYPE_FILE_ICON G_TYPE_FILE_INFO G_TYPE_FILE_INPUT_STREAM G_TYPE_FILE_IO_STREAM G_TYPE_FILE_MONITOR G_TYPE_FILE_OUTPUT_STREAM G_TYPE_FILTER_INPUT_STREAM G_TYPE_FILTER_OUTPUT_STREAM G_TYPE_ICON G_TYPE_INET_ADDRESS G_TYPE_INET_SOCKET_ADDRESS G_TYPE_INITABLE G_TYPE_INPUT_STREAM G_TYPE_IO_STREAM G_TYPE_LOADABLE_ICON G_TYPE_MEMORY_INPUT_STREAM G_TYPE_MEMORY_OUTPUT_STREAM G_TYPE_MOUNT G_TYPE_MOUNT_OPERATION G_TYPE_NETWORK_ADDRESS G_TYPE_NETWORK_SERVICE G_TYPE_OUTPUT_STREAM G_TYPE_PERMISSION G_TYPE_POLLABLE_INPUT_STREAM G_TYPE_POLLABLE_OUTPUT_STREAM G_TYPE_PROXY G_TYPE_PROXY_ADDRESS G_TYPE_PROXY_ADDRESS_ENUMERATOR G_TYPE_PROXY_RESOLVER G_TYPE_RESOLVER G_TYPE_SEEKABLE G_TYPE_SETTINGS G_TYPE_SETTINGS_BACKEND G_TYPE_SIMPLE_ACTION G_TYPE_SIMPLE_ACTION_GROUP G_TYPE_SIMPLE_ASYNC_RESULT G_TYPE_SIMPLE_PERMISSION G_TYPE_SOCKET G_TYPE_SOCKET_ADDRESS G_TYPE_SOCKET_ADDRESS_ENUMERATOR G_TYPE_SOCKET_CLIENT G_TYPE_SOCKET_CONNECTABLE G_TYPE_SOCKET_CONNECTION G_TYPE_SOCKET_CONTROL_MESSAGE G_TYPE_SOCKET_LISTENER G_TYPE_SOCKET_SERVICE G_TYPE_SOCKS4A_PROXY G_TYPE_SOCKS4_PROXY G_TYPE_SOCKS5_PROXY G_TYPE_SRV_TARGET G_TYPE_TCP_CONNECTION G_TYPE_TCP_WRAPPER_CONNECTION G_TYPE_THEMED_ICON G_TYPE_THREADED_SOCKET_SERVICE G_TYPE_TLS_BACKEND G_TYPE_TLS_CERTIFICATE G_TYPE_TLS_CLIENT_CONNECTION G_TYPE_TLS_CONNECTION G_TYPE_TLS_SERVER_CONNECTION G_TYPE_UNIX_CONNECTION G_TYPE_UNIX_CREDENTIALS_MESSAGE G_TYPE_UNIX_FD_LIST G_TYPE_UNIX_FD_MESSAGE G_TYPE_UNIX_INPUT_STREAM G_TYPE_UNIX_MOUNT_MONITOR G_TYPE_UNIX_OUTPUT_STREAM G_TYPE_UNIX_SOCKET_ADDRESS G_TYPE_VFS G_TYPE_VOLUME G_TYPE_VOLUME_MONITOR G_TYPE_ZLIB_COMPRESSOR G_TYPE_ZLIB_DECOMPRESSOR G_VFS_EXTENSION_POINT_NAME G_VOLUME_IDENTIFIER_KIND_HAL_UDI G_VOLUME_IDENTIFIER_KIND_LABEL G_VOLUME_IDENTIFIER_KIND_NFS_MOUNT G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE G_VOLUME_IDENTIFIER_KIND_UUID G_VOLUME_MONITOR_EXTENSION_POINT_NAME
syn keyword gioDeprecatedFunction g_desktop_app_info_launch_uris_as_manager g_desktop_app_info_lookup_get_default_for_uri_scheme g_desktop_app_info_lookup_get_type g_drive_eject g_drive_eject_finish g_file_eject_mountable g_file_eject_mountable_finish g_file_unmount_mountable g_file_unmount_mountable_finish g_mount_eject g_mount_eject_finish g_mount_unmount g_mount_unmount_finish g_unix_socket_address_get_is_abstract g_unix_socket_address_new_abstract g_volume_eject g_volume_eject_finish g_volume_monitor_adopt_orphan_mount
syn keyword gioDeprecatedStruct GDesktopAppInfoLookup GDesktopAppInfoLookupIface
syn keyword gioDeprecatedMacro G_DESKTOP_APP_INFO_LOOKUP G_DESKTOP_APP_INFO_LOOKUP_GET_IFACE G_IS_DESKTOP_APP_INFO_LOOKUP
syn keyword gioDeprecatedUserFunction GDesktopAppLaunchCallback
syn keyword gioDeprecatedDefine G_DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME G_TYPE_DESKTOP_APP_INFO_LOOKUP

" Default highlighting
if version >= 508 || !exists("did_gio_syntax_inits")
  if version < 508
    let did_gio_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink gioFunction Function
  HiLink gioConstant Constant
  HiLink gioStruct Type
  HiLink gioMacro Macro
  HiLink gioEnum Type
  HiLink gioUserFunction Type
  HiLink gioDefine Constant
  if exists("gio_deprecated_errors")
    HiLink gioDeprecatedFunction Error
    HiLink gioDeprecatedMacro Error
    HiLink gioDeprecatedDefine Error
    HiLink gioDeprecatedStruct Error
    HiLink gioDeprecatedUserFunction Error
  elseif exists("gio_enable_deprecated")
    HiLink gioDeprecatedFunction Function
    HiLink gioDeprecatedMacro Macro
    HiLink gioDeprecatedDefine Constant
    HiLink gioDeprecatedStruct Type
    HiLink gioDeprecatedUserFunction Type
  endif

  delcommand HiLink
endif

