" Vim syntax file
" Language: C clutter extension (for version 1.6.2)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let clutter_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let clutter_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword clutterFunction cally_accessibility_init cally_actor_add_action cally_actor_add_action_full cally_actor_get_type cally_actor_new cally_actor_remove_action cally_actor_remove_action_by_name cally_clone_get_type cally_clone_new cally_get_cally_initialized cally_group_get_type cally_group_new cally_rectangle_get_type cally_rectangle_new cally_root_get_type cally_root_new cally_stage_get_type cally_stage_new cally_text_get_type cally_text_new cally_texture_get_type cally_texture_new cally_util_get_type clutter_action_get_type clutter_actor_add_action clutter_actor_add_action_with_name clutter_actor_add_constraint clutter_actor_add_constraint_with_name clutter_actor_add_effect clutter_actor_add_effect_with_name clutter_actor_allocate clutter_actor_allocate_align_fill clutter_actor_allocate_available_size clutter_actor_allocate_preferred_size clutter_actor_animate clutter_actor_animate_with_alpha clutter_actor_animate_with_alphav clutter_actor_animate_with_timeline clutter_actor_animate_with_timelinev clutter_actor_animatev clutter_actor_apply_relative_transform_to_point clutter_actor_apply_transform_to_point clutter_actor_box_clamp_to_pixel clutter_actor_box_contains clutter_actor_box_copy clutter_actor_box_equal clutter_actor_box_free clutter_actor_box_from_vertices clutter_actor_box_get_area clutter_actor_box_get_height clutter_actor_box_get_origin clutter_actor_box_get_size clutter_actor_box_get_type clutter_actor_box_get_width clutter_actor_box_get_x clutter_actor_box_get_y clutter_actor_box_interpolate clutter_actor_box_new clutter_actor_box_set_origin clutter_actor_box_set_size clutter_actor_box_union clutter_actor_clear_actions clutter_actor_clear_constraints clutter_actor_clear_effects clutter_actor_contains clutter_actor_create_pango_context clutter_actor_create_pango_layout clutter_actor_destroy clutter_actor_detach_animation clutter_actor_event clutter_actor_get_abs_allocation_vertices clutter_actor_get_accessible clutter_actor_get_action clutter_actor_get_actions clutter_actor_get_allocation_box clutter_actor_get_allocation_geometry clutter_actor_get_allocation_vertices clutter_actor_get_anchor_point clutter_actor_get_anchor_point_gravity clutter_actor_get_animation clutter_actor_get_clip clutter_actor_get_clip_to_allocation clutter_actor_get_constraint clutter_actor_get_constraints clutter_actor_get_depth clutter_actor_get_effect clutter_actor_get_effects clutter_actor_get_fixed_position_set clutter_actor_get_flags clutter_actor_get_geometry clutter_actor_get_gid clutter_actor_get_height clutter_actor_get_name clutter_actor_get_opacity clutter_actor_get_paint_box clutter_actor_get_paint_opacity clutter_actor_get_paint_visibility clutter_actor_get_paint_volume clutter_actor_get_pango_context clutter_actor_get_parent clutter_actor_get_position clutter_actor_get_preferred_height clutter_actor_get_preferred_size clutter_actor_get_preferred_width clutter_actor_get_reactive clutter_actor_get_request_mode clutter_actor_get_rotation clutter_actor_get_scale clutter_actor_get_scale_center clutter_actor_get_scale_gravity clutter_actor_get_shader clutter_actor_get_size clutter_actor_get_stage clutter_actor_get_text_direction clutter_actor_get_transformation_matrix clutter_actor_get_transformed_paint_volume clutter_actor_get_transformed_position clutter_actor_get_transformed_size clutter_actor_get_type clutter_actor_get_width clutter_actor_get_x clutter_actor_get_y clutter_actor_get_z_rotation_gravity clutter_actor_grab_key_focus clutter_actor_has_allocation clutter_actor_has_clip clutter_actor_has_key_focus clutter_actor_has_pointer clutter_actor_hide clutter_actor_hide_all clutter_actor_is_in_clone_paint clutter_actor_is_rotated clutter_actor_is_scaled clutter_actor_lower clutter_actor_lower_bottom clutter_actor_map clutter_actor_meta_get_actor clutter_actor_meta_get_enabled clutter_actor_meta_get_name clutter_actor_meta_get_type clutter_actor_meta_set_enabled clutter_actor_meta_set_name clutter_actor_move_anchor_point clutter_actor_move_anchor_point_from_gravity clutter_actor_move_by clutter_actor_paint clutter_actor_pop_internal clutter_actor_push_internal clutter_actor_queue_redraw clutter_actor_queue_relayout clutter_actor_raise clutter_actor_raise_top clutter_actor_realize clutter_actor_remove_action clutter_actor_remove_action_by_name clutter_actor_remove_clip clutter_actor_remove_constraint clutter_actor_remove_constraint_by_name clutter_actor_remove_effect clutter_actor_remove_effect_by_name clutter_actor_reparent clutter_actor_set_anchor_point clutter_actor_set_anchor_point_from_gravity clutter_actor_set_clip clutter_actor_set_clip_to_allocation clutter_actor_set_depth clutter_actor_set_fixed_position_set clutter_actor_set_flags clutter_actor_set_geometry clutter_actor_set_height clutter_actor_set_name clutter_actor_set_opacity clutter_actor_set_parent clutter_actor_set_position clutter_actor_set_reactive clutter_actor_set_request_mode clutter_actor_set_rotation clutter_actor_set_scale clutter_actor_set_scale_full clutter_actor_set_scale_with_gravity clutter_actor_set_shader clutter_actor_set_shader_param clutter_actor_set_shader_param_float clutter_actor_set_shader_param_int clutter_actor_set_size clutter_actor_set_text_direction clutter_actor_set_width clutter_actor_set_x clutter_actor_set_y clutter_actor_set_z_rotation_from_gravity clutter_actor_should_pick_paint clutter_actor_show clutter_actor_show_all clutter_actor_transform_stage_point clutter_actor_unmap clutter_actor_unparent clutter_actor_unrealize clutter_actor_unset_flags clutter_align_constraint_get_align_axis clutter_align_constraint_get_factor clutter_align_constraint_get_source clutter_align_constraint_get_type clutter_align_constraint_new clutter_align_constraint_set_align_axis clutter_align_constraint_set_factor clutter_align_constraint_set_source clutter_alpha_get_alpha clutter_alpha_get_mode clutter_alpha_get_timeline clutter_alpha_get_type clutter_alpha_new clutter_alpha_new_full clutter_alpha_new_with_func clutter_alpha_register_closure clutter_alpha_register_func clutter_alpha_set_closure clutter_alpha_set_func clutter_alpha_set_mode clutter_alpha_set_timeline clutter_animatable_animate_property clutter_animatable_find_property clutter_animatable_get_initial_state clutter_animatable_get_type clutter_animatable_set_final_state clutter_animation_bind clutter_animation_bind_interval clutter_animation_completed clutter_animation_get_alpha clutter_animation_get_duration clutter_animation_get_interval clutter_animation_get_loop clutter_animation_get_mode clutter_animation_get_object clutter_animation_get_timeline clutter_animation_get_type clutter_animation_has_property clutter_animation_new clutter_animation_set_alpha clutter_animation_set_duration clutter_animation_set_loop clutter_animation_set_mode clutter_animation_set_object clutter_animation_set_timeline clutter_animation_unbind_property clutter_animation_update clutter_animation_update_interval clutter_animator_compute_value clutter_animator_get_duration clutter_animator_get_keys clutter_animator_get_timeline clutter_animator_get_type clutter_animator_key_get_mode clutter_animator_key_get_object clutter_animator_key_get_progress clutter_animator_key_get_property_name clutter_animator_key_get_property_type clutter_animator_key_get_type clutter_animator_key_get_value clutter_animator_new clutter_animator_property_get_ease_in clutter_animator_property_get_interpolation clutter_animator_property_set_ease_in clutter_animator_property_set_interpolation clutter_animator_remove_key clutter_animator_set clutter_animator_set_duration clutter_animator_set_key clutter_animator_set_timeline clutter_animator_start clutter_backend_get_font_options clutter_backend_get_resolution clutter_backend_get_type clutter_backend_set_font_options clutter_base_init clutter_bin_layout_add clutter_bin_layout_get_alignment clutter_bin_layout_get_type clutter_bin_layout_new clutter_bin_layout_set_alignment clutter_bind_constraint_get_coordinate clutter_bind_constraint_get_offset clutter_bind_constraint_get_source clutter_bind_constraint_get_type clutter_bind_constraint_new clutter_bind_constraint_set_coordinate clutter_bind_constraint_set_offset clutter_bind_constraint_set_source clutter_binding_pool_activate clutter_binding_pool_block_action clutter_binding_pool_find clutter_binding_pool_find_action clutter_binding_pool_get_for_class clutter_binding_pool_get_type clutter_binding_pool_install_action clutter_binding_pool_install_closure clutter_binding_pool_new clutter_binding_pool_override_action clutter_binding_pool_override_closure clutter_binding_pool_remove_action clutter_binding_pool_unblock_action clutter_blur_effect_get_type clutter_blur_effect_new clutter_box_get_color clutter_box_get_layout_manager clutter_box_get_type clutter_box_layout_get_alignment clutter_box_layout_get_easing_duration clutter_box_layout_get_easing_mode clutter_box_layout_get_expand clutter_box_layout_get_fill clutter_box_layout_get_homogeneous clutter_box_layout_get_pack_start clutter_box_layout_get_spacing clutter_box_layout_get_type clutter_box_layout_get_use_animations clutter_box_layout_get_vertical clutter_box_layout_new clutter_box_layout_pack clutter_box_layout_set_alignment clutter_box_layout_set_easing_duration clutter_box_layout_set_easing_mode clutter_box_layout_set_expand clutter_box_layout_set_fill clutter_box_layout_set_homogeneous clutter_box_layout_set_pack_start clutter_box_layout_set_spacing clutter_box_layout_set_use_animations clutter_box_layout_set_vertical clutter_box_new clutter_box_pack clutter_box_pack_after clutter_box_pack_at clutter_box_pack_before clutter_box_packv clutter_box_set_color clutter_box_set_layout_manager clutter_cairo_set_source_color clutter_cairo_texture_clear clutter_cairo_texture_create clutter_cairo_texture_create_region clutter_cairo_texture_get_surface_size clutter_cairo_texture_get_type clutter_cairo_texture_new clutter_cairo_texture_set_surface_size clutter_cex100_set_buffering_mode clutter_cex100_set_plane clutter_check_version clutter_child_meta_get_actor clutter_child_meta_get_container clutter_child_meta_get_type clutter_clear_glyph_cache clutter_click_action_get_button clutter_click_action_get_state clutter_click_action_get_type clutter_click_action_new clutter_click_action_release clutter_clone_get_source clutter_clone_get_type clutter_clone_new clutter_clone_set_source clutter_color_add clutter_color_copy clutter_color_darken clutter_color_equal clutter_color_free clutter_color_from_hls clutter_color_from_pixel clutter_color_from_string clutter_color_get_static clutter_color_get_type clutter_color_hash clutter_color_interpolate clutter_color_lighten clutter_color_new clutter_color_shade clutter_color_subtract clutter_color_to_hls clutter_color_to_pixel clutter_color_to_string clutter_colorize_effect_get_tint clutter_colorize_effect_get_type clutter_colorize_effect_new clutter_colorize_effect_set_tint clutter_constraint_get_type clutter_container_add clutter_container_add_actor clutter_container_add_valist clutter_container_child_get clutter_container_child_get_property clutter_container_child_notify clutter_container_child_set clutter_container_child_set_property clutter_container_class_find_child_property clutter_container_class_list_child_properties clutter_container_create_child_meta clutter_container_destroy_child_meta clutter_container_find_child_by_name clutter_container_foreach clutter_container_foreach_with_internals clutter_container_get_child_meta clutter_container_get_children clutter_container_get_type clutter_container_lower_child clutter_container_raise_child clutter_container_remove clutter_container_remove_actor clutter_container_remove_valist clutter_container_sort_depth_order clutter_deform_effect_get_back_material clutter_deform_effect_get_n_tiles clutter_deform_effect_get_type clutter_deform_effect_invalidate clutter_deform_effect_set_back_material clutter_deform_effect_set_n_tiles clutter_desaturate_effect_get_factor clutter_desaturate_effect_get_type clutter_desaturate_effect_new clutter_desaturate_effect_set_factor clutter_device_manager_get_core_device clutter_device_manager_get_default clutter_device_manager_get_device clutter_device_manager_get_type clutter_device_manager_list_devices clutter_device_manager_peek_devices clutter_do_event clutter_drag_action_get_drag_axis clutter_drag_action_get_drag_handle clutter_drag_action_get_drag_threshold clutter_drag_action_get_motion_coords clutter_drag_action_get_press_coords clutter_drag_action_get_type clutter_drag_action_new clutter_drag_action_set_drag_axis clutter_drag_action_set_drag_handle clutter_drag_action_set_drag_threshold clutter_effect_get_type clutter_egl_get_egl_display clutter_event_copy clutter_event_free clutter_event_get clutter_event_get_axes clutter_event_get_button clutter_event_get_click_count clutter_event_get_coords clutter_event_get_device clutter_event_get_device_id clutter_event_get_device_type clutter_event_get_flags clutter_event_get_key_code clutter_event_get_key_symbol clutter_event_get_key_unicode clutter_event_get_related clutter_event_get_scroll_direction clutter_event_get_source clutter_event_get_source_device clutter_event_get_stage clutter_event_get_state clutter_event_get_time clutter_event_get_type clutter_event_new clutter_event_peek clutter_event_put clutter_event_set_device clutter_event_type clutter_events_pending clutter_feature_available clutter_feature_get_all clutter_fixed_layout_get_type clutter_fixed_layout_new clutter_flow_layout_get_column_spacing clutter_flow_layout_get_column_width clutter_flow_layout_get_homogeneous clutter_flow_layout_get_orientation clutter_flow_layout_get_row_height clutter_flow_layout_get_row_spacing clutter_flow_layout_get_type clutter_flow_layout_new clutter_flow_layout_set_column_spacing clutter_flow_layout_set_column_width clutter_flow_layout_set_homogeneous clutter_flow_layout_set_orientation clutter_flow_layout_set_row_height clutter_flow_layout_set_row_spacing clutter_fog_get_type clutter_geometry_get_type clutter_geometry_intersects clutter_geometry_union clutter_get_accessibility_enabled clutter_get_actor_by_gid clutter_get_current_event clutter_get_current_event_time clutter_get_debug_enabled clutter_get_default_backend clutter_get_default_frame_rate clutter_get_default_text_direction clutter_get_font_flags clutter_get_font_map clutter_get_input_device_for_id clutter_get_keyboard_grab clutter_get_motion_events_enabled clutter_get_option_group clutter_get_option_group_without_init clutter_get_pointer_grab clutter_get_script_id clutter_get_show_fps clutter_get_timestamp clutter_glx_texture_pixmap_get_type clutter_glx_texture_pixmap_new clutter_glx_texture_pixmap_new_with_pixmap clutter_glx_texture_pixmap_new_with_window clutter_glx_texture_pixmap_using_extension clutter_grab_keyboard clutter_grab_pointer clutter_grab_pointer_for_device clutter_group_get_n_children clutter_group_get_nth_child clutter_group_get_type clutter_group_new clutter_group_remove_all clutter_init clutter_init_error_quark clutter_init_with_args clutter_input_device_get_associated_device clutter_input_device_get_axis clutter_input_device_get_axis_value clutter_input_device_get_device_coords clutter_input_device_get_device_id clutter_input_device_get_device_mode clutter_input_device_get_device_name clutter_input_device_get_device_type clutter_input_device_get_enabled clutter_input_device_get_has_cursor clutter_input_device_get_key clutter_input_device_get_n_axes clutter_input_device_get_n_keys clutter_input_device_get_pointer_actor clutter_input_device_get_pointer_stage clutter_input_device_get_slave_devices clutter_input_device_get_type clutter_input_device_set_enabled clutter_input_device_set_key clutter_input_device_update_from_event clutter_interval_clone clutter_interval_compute clutter_interval_compute_value clutter_interval_get_final_value clutter_interval_get_initial_value clutter_interval_get_interval clutter_interval_get_type clutter_interval_get_value_type clutter_interval_new clutter_interval_new_with_values clutter_interval_peek_final_value clutter_interval_peek_initial_value clutter_interval_register_progress_func clutter_interval_set_final_value clutter_interval_set_initial_value clutter_interval_set_interval clutter_interval_validate clutter_keysym_to_unicode clutter_knot_copy clutter_knot_equal clutter_knot_free clutter_knot_get_type clutter_layout_manager_allocate clutter_layout_manager_begin_animation clutter_layout_manager_child_get clutter_layout_manager_child_get_property clutter_layout_manager_child_set clutter_layout_manager_child_set_property clutter_layout_manager_end_animation clutter_layout_manager_find_child_property clutter_layout_manager_get_animation_progress clutter_layout_manager_get_child_meta clutter_layout_manager_get_preferred_height clutter_layout_manager_get_preferred_width clutter_layout_manager_get_type clutter_layout_manager_layout_changed clutter_layout_manager_list_child_properties clutter_layout_manager_set_container clutter_layout_meta_get_manager clutter_layout_meta_get_type clutter_list_model_get_type clutter_list_model_new clutter_list_model_newv clutter_main clutter_main_level clutter_main_quit clutter_media_get_audio_volume clutter_media_get_buffer_fill clutter_media_get_can_seek clutter_media_get_duration clutter_media_get_playing clutter_media_get_progress clutter_media_get_subtitle_font_name clutter_media_get_subtitle_uri clutter_media_get_type clutter_media_get_uri clutter_media_set_audio_volume clutter_media_set_filename clutter_media_set_playing clutter_media_set_progress clutter_media_set_subtitle_font_name clutter_media_set_subtitle_uri clutter_media_set_uri clutter_model_append clutter_model_appendv clutter_model_filter_iter clutter_model_filter_row clutter_model_foreach clutter_model_get_column_name clutter_model_get_column_type clutter_model_get_filter_set clutter_model_get_first_iter clutter_model_get_iter_at_row clutter_model_get_last_iter clutter_model_get_n_columns clutter_model_get_n_rows clutter_model_get_sorting_column clutter_model_get_type clutter_model_insert clutter_model_insert_value clutter_model_insertv clutter_model_iter_copy clutter_model_iter_get clutter_model_iter_get_model clutter_model_iter_get_row clutter_model_iter_get_type clutter_model_iter_get_valist clutter_model_iter_get_value clutter_model_iter_is_first clutter_model_iter_is_last clutter_model_iter_next clutter_model_iter_prev clutter_model_iter_set clutter_model_iter_set_valist clutter_model_iter_set_value clutter_model_prepend clutter_model_prependv clutter_model_remove clutter_model_resort clutter_model_set_filter clutter_model_set_names clutter_model_set_sort clutter_model_set_sorting_column clutter_model_set_types clutter_offscreen_effect_create_texture clutter_offscreen_effect_get_target clutter_offscreen_effect_get_type clutter_offscreen_effect_paint_target clutter_page_turn_effect_get_angle clutter_page_turn_effect_get_period clutter_page_turn_effect_get_radius clutter_page_turn_effect_get_type clutter_page_turn_effect_new clutter_page_turn_effect_set_angle clutter_page_turn_effect_set_period clutter_page_turn_effect_set_radius clutter_paint_volume_copy clutter_paint_volume_free clutter_paint_volume_get_depth clutter_paint_volume_get_height clutter_paint_volume_get_origin clutter_paint_volume_get_type clutter_paint_volume_get_width clutter_paint_volume_set_depth clutter_paint_volume_set_from_allocation clutter_paint_volume_set_height clutter_paint_volume_set_origin clutter_paint_volume_set_width clutter_paint_volume_union clutter_param_color_get_type clutter_param_fixed_get_type clutter_param_spec_color clutter_param_spec_fixed clutter_param_spec_units clutter_param_units_get_type clutter_path_add_cairo_path clutter_path_add_close clutter_path_add_curve_to clutter_path_add_line_to clutter_path_add_move_to clutter_path_add_node clutter_path_add_rel_curve_to clutter_path_add_rel_line_to clutter_path_add_rel_move_to clutter_path_add_string clutter_path_clear clutter_path_constraint_get_offset clutter_path_constraint_get_path clutter_path_constraint_get_type clutter_path_constraint_new clutter_path_constraint_set_offset clutter_path_constraint_set_path clutter_path_foreach clutter_path_get_description clutter_path_get_length clutter_path_get_n_nodes clutter_path_get_node clutter_path_get_nodes clutter_path_get_position clutter_path_get_type clutter_path_insert_node clutter_path_new clutter_path_new_with_description clutter_path_node_copy clutter_path_node_equal clutter_path_node_free clutter_path_node_get_type clutter_path_remove_node clutter_path_replace_node clutter_path_set_description clutter_path_to_cairo_path clutter_perspective_get_type clutter_rectangle_get_border_color clutter_rectangle_get_border_width clutter_rectangle_get_color clutter_rectangle_get_type clutter_rectangle_new clutter_rectangle_new_with_color clutter_rectangle_set_border_color clutter_rectangle_set_border_width clutter_rectangle_set_color clutter_redraw clutter_score_append clutter_score_append_at_marker clutter_score_get_loop clutter_score_get_timeline clutter_score_get_type clutter_score_is_playing clutter_score_list_timelines clutter_score_new clutter_score_pause clutter_score_remove clutter_score_remove_all clutter_score_rewind clutter_score_set_loop clutter_score_start clutter_score_stop clutter_script_add_search_paths clutter_script_connect_signals clutter_script_connect_signals_full clutter_script_ensure_objects clutter_script_error_quark clutter_script_get_object clutter_script_get_objects clutter_script_get_type clutter_script_get_type_from_name clutter_script_list_objects clutter_script_load_from_data clutter_script_load_from_file clutter_script_lookup_filename clutter_script_new clutter_script_unmerge_objects clutter_scriptable_get_id clutter_scriptable_get_type clutter_scriptable_parse_custom_node clutter_scriptable_set_custom_property clutter_scriptable_set_id clutter_set_default_frame_rate clutter_set_font_flags clutter_set_motion_events_enabled clutter_settings_get_default clutter_settings_get_type clutter_shader_compile clutter_shader_effect_get_program clutter_shader_effect_get_shader clutter_shader_effect_get_type clutter_shader_effect_set_shader_source clutter_shader_effect_set_uniform clutter_shader_effect_set_uniform_value clutter_shader_error_quark clutter_shader_float_get_type clutter_shader_get_cogl_fragment_shader clutter_shader_get_cogl_program clutter_shader_get_cogl_vertex_shader clutter_shader_get_fragment_source clutter_shader_get_is_enabled clutter_shader_get_type clutter_shader_get_vertex_source clutter_shader_int_get_type clutter_shader_is_compiled clutter_shader_matrix_get_type clutter_shader_new clutter_shader_release clutter_shader_set_fragment_source clutter_shader_set_is_enabled clutter_shader_set_uniform clutter_shader_set_vertex_source clutter_snap_constraint_get_edges clutter_snap_constraint_get_offset clutter_snap_constraint_get_source clutter_snap_constraint_get_type clutter_snap_constraint_new clutter_snap_constraint_set_edges clutter_snap_constraint_set_offset clutter_snap_constraint_set_source clutter_stage_ensure_current clutter_stage_ensure_redraw clutter_stage_ensure_viewport clutter_stage_event clutter_stage_get_accept_focus clutter_stage_get_actor_at_pos clutter_stage_get_color clutter_stage_get_default clutter_stage_get_fog clutter_stage_get_fullscreen clutter_stage_get_key_focus clutter_stage_get_minimum_size clutter_stage_get_no_clear_hint clutter_stage_get_perspective clutter_stage_get_throttle_motion_events clutter_stage_get_title clutter_stage_get_type clutter_stage_get_use_alpha clutter_stage_get_use_fog clutter_stage_get_user_resizable clutter_stage_hide_cursor clutter_stage_is_default clutter_stage_manager_get_default clutter_stage_manager_get_default_stage clutter_stage_manager_get_type clutter_stage_manager_list_stages clutter_stage_manager_peek_stages clutter_stage_new clutter_stage_queue_redraw clutter_stage_read_pixels clutter_stage_set_accept_focus clutter_stage_set_color clutter_stage_set_fog clutter_stage_set_fullscreen clutter_stage_set_key_focus clutter_stage_set_minimum_size clutter_stage_set_no_clear_hint clutter_stage_set_perspective clutter_stage_set_throttle_motion_events clutter_stage_set_title clutter_stage_set_use_alpha clutter_stage_set_use_fog clutter_stage_set_user_resizable clutter_stage_show_cursor clutter_state_get_animator clutter_state_get_duration clutter_state_get_keys clutter_state_get_state clutter_state_get_states clutter_state_get_timeline clutter_state_get_type clutter_state_key_get_mode clutter_state_key_get_object clutter_state_key_get_post_delay clutter_state_key_get_pre_delay clutter_state_key_get_property_name clutter_state_key_get_property_type clutter_state_key_get_source_state_name clutter_state_key_get_target_state_name clutter_state_key_get_type clutter_state_key_get_value clutter_state_new clutter_state_remove_key clutter_state_set clutter_state_set_animator clutter_state_set_duration clutter_state_set_key clutter_state_set_state clutter_state_warp_to_state clutter_table_layout_get_alignment clutter_table_layout_get_column_count clutter_table_layout_get_column_spacing clutter_table_layout_get_easing_duration clutter_table_layout_get_easing_mode clutter_table_layout_get_expand clutter_table_layout_get_fill clutter_table_layout_get_row_count clutter_table_layout_get_row_spacing clutter_table_layout_get_span clutter_table_layout_get_type clutter_table_layout_get_use_animations clutter_table_layout_new clutter_table_layout_pack clutter_table_layout_set_alignment clutter_table_layout_set_column_spacing clutter_table_layout_set_easing_duration clutter_table_layout_set_easing_mode clutter_table_layout_set_expand clutter_table_layout_set_fill clutter_table_layout_set_row_spacing clutter_table_layout_set_span clutter_table_layout_set_use_animations clutter_text_activate clutter_text_delete_chars clutter_text_delete_selection clutter_text_delete_text clutter_text_get_activatable clutter_text_get_attributes clutter_text_get_chars clutter_text_get_color clutter_text_get_cursor_color clutter_text_get_cursor_position clutter_text_get_cursor_size clutter_text_get_cursor_visible clutter_text_get_editable clutter_text_get_ellipsize clutter_text_get_font_description clutter_text_get_font_name clutter_text_get_justify clutter_text_get_layout clutter_text_get_line_alignment clutter_text_get_line_wrap clutter_text_get_line_wrap_mode clutter_text_get_max_length clutter_text_get_password_char clutter_text_get_selectable clutter_text_get_selection clutter_text_get_selection_bound clutter_text_get_selection_color clutter_text_get_single_line_mode clutter_text_get_text clutter_text_get_type clutter_text_get_use_markup clutter_text_insert_text clutter_text_insert_unichar clutter_text_new clutter_text_new_full clutter_text_new_with_text clutter_text_position_to_coords clutter_text_set_activatable clutter_text_set_attributes clutter_text_set_color clutter_text_set_cursor_color clutter_text_set_cursor_position clutter_text_set_cursor_size clutter_text_set_cursor_visible clutter_text_set_editable clutter_text_set_ellipsize clutter_text_set_font_description clutter_text_set_font_name clutter_text_set_justify clutter_text_set_line_alignment clutter_text_set_line_wrap clutter_text_set_line_wrap_mode clutter_text_set_markup clutter_text_set_max_length clutter_text_set_password_char clutter_text_set_preedit_string clutter_text_set_selectable clutter_text_set_selection clutter_text_set_selection_bound clutter_text_set_selection_color clutter_text_set_single_line_mode clutter_text_set_text clutter_text_set_use_markup clutter_texture_error_quark clutter_texture_get_base_size clutter_texture_get_cogl_material clutter_texture_get_cogl_texture clutter_texture_get_filter_quality clutter_texture_get_keep_aspect_ratio clutter_texture_get_load_async clutter_texture_get_load_data_async clutter_texture_get_max_tile_waste clutter_texture_get_pick_with_alpha clutter_texture_get_pixel_format clutter_texture_get_repeat clutter_texture_get_sync_size clutter_texture_get_type clutter_texture_new clutter_texture_new_from_actor clutter_texture_new_from_file clutter_texture_set_area_from_rgb_data clutter_texture_set_cogl_material clutter_texture_set_cogl_texture clutter_texture_set_filter_quality clutter_texture_set_from_file clutter_texture_set_from_rgb_data clutter_texture_set_from_yuv_data clutter_texture_set_keep_aspect_ratio clutter_texture_set_load_async clutter_texture_set_load_data_async clutter_texture_set_pick_with_alpha clutter_texture_set_repeat clutter_texture_set_sync_size clutter_threads_add_idle clutter_threads_add_idle_full clutter_threads_add_repaint_func clutter_threads_add_timeout clutter_threads_add_timeout_full clutter_threads_enter clutter_threads_init clutter_threads_leave clutter_threads_remove_repaint_func clutter_threads_set_lock_functions clutter_timeline_add_marker_at_time clutter_timeline_advance clutter_timeline_advance_to_marker clutter_timeline_clone clutter_timeline_get_auto_reverse clutter_timeline_get_delay clutter_timeline_get_delta clutter_timeline_get_direction clutter_timeline_get_duration clutter_timeline_get_elapsed_time clutter_timeline_get_loop clutter_timeline_get_progress clutter_timeline_get_type clutter_timeline_has_marker clutter_timeline_is_playing clutter_timeline_list_markers clutter_timeline_new clutter_timeline_pause clutter_timeline_remove_marker clutter_timeline_rewind clutter_timeline_set_auto_reverse clutter_timeline_set_delay clutter_timeline_set_direction clutter_timeline_set_duration clutter_timeline_set_loop clutter_timeline_skip clutter_timeline_start clutter_timeline_stop clutter_ungrab_keyboard clutter_ungrab_pointer clutter_ungrab_pointer_for_device clutter_units_copy clutter_units_free clutter_units_from_cm clutter_units_from_em clutter_units_from_em_for_font clutter_units_from_mm clutter_units_from_pixels clutter_units_from_pt clutter_units_from_string clutter_units_get_type clutter_units_get_unit_type clutter_units_get_unit_value clutter_units_to_pixels clutter_units_to_string clutter_value_get_color clutter_value_get_fixed clutter_value_get_shader_float clutter_value_get_shader_int clutter_value_get_shader_matrix clutter_value_get_units clutter_value_set_color clutter_value_set_fixed clutter_value_set_shader_float clutter_value_set_shader_int clutter_value_set_shader_matrix clutter_value_set_units clutter_vertex_copy clutter_vertex_equal clutter_vertex_free clutter_vertex_get_type clutter_vertex_new clutter_wayland_get_egl_display clutter_win32_disable_event_retrieval clutter_win32_get_stage_from_window clutter_win32_get_stage_window clutter_win32_handle_event clutter_win32_set_stage_foreign clutter_x11_add_filter clutter_x11_disable_event_retrieval clutter_x11_enable_xinput clutter_x11_event_get_key_group clutter_x11_get_current_event_time clutter_x11_get_default_display clutter_x11_get_default_screen clutter_x11_get_root_window clutter_x11_get_stage_from_window clutter_x11_get_stage_window clutter_x11_get_use_argb_visual clutter_x11_get_visual_info clutter_x11_handle_event clutter_x11_has_composite_extension clutter_x11_has_event_retrieval clutter_x11_has_xinput clutter_x11_remove_filter clutter_x11_set_display clutter_x11_set_stage_foreign clutter_x11_set_use_argb_visual clutter_x11_texture_pixmap_get_type clutter_x11_texture_pixmap_new clutter_x11_texture_pixmap_new_with_pixmap clutter_x11_texture_pixmap_new_with_window clutter_x11_texture_pixmap_set_automatic clutter_x11_texture_pixmap_set_pixmap clutter_x11_texture_pixmap_set_window clutter_x11_texture_pixmap_sync_window clutter_x11_texture_pixmap_update_area clutter_x11_trap_x_errors clutter_x11_untrap_x_errors cogl_attribute_new cogl_attribute_type_get_type cogl_begin_gl cogl_bitmap_error_get_type cogl_bitmap_error_quark cogl_bitmap_get_size_from_file cogl_bitmap_new_from_file cogl_blend_string_error_get_type cogl_blend_string_error_quark cogl_buffer_access_get_type cogl_buffer_bit_get_type cogl_buffer_get_size cogl_buffer_get_update_hint cogl_buffer_map cogl_buffer_map_hint_get_type cogl_buffer_set_data cogl_buffer_set_update_hint cogl_buffer_target_get_type cogl_buffer_unmap cogl_buffer_update_hint_get_type cogl_clear cogl_clip_pop cogl_clip_push_from_path cogl_clip_push_from_path_preserve cogl_clip_push_rectangle cogl_clip_push_window_rectangle cogl_color_copy cogl_color_equal cogl_color_free cogl_color_get_alpha cogl_color_get_alpha_byte cogl_color_get_alpha_float cogl_color_get_blue cogl_color_get_blue_byte cogl_color_get_blue_float cogl_color_get_green cogl_color_get_green_byte cogl_color_get_green_float cogl_color_get_red cogl_color_get_red_byte cogl_color_get_red_float cogl_color_init_from_4f cogl_color_init_from_4fv cogl_color_init_from_4ub cogl_color_new cogl_color_premultiply cogl_color_set_alpha cogl_color_set_alpha_byte cogl_color_set_alpha_float cogl_color_set_blue cogl_color_set_blue_byte cogl_color_set_blue_float cogl_color_set_from_4f cogl_color_set_from_4ub cogl_color_set_green cogl_color_set_green_byte cogl_color_set_green_float cogl_color_set_red cogl_color_set_red_byte cogl_color_set_red_float cogl_color_unpremultiply cogl_create_program cogl_create_shader cogl_depth_test_function_get_type cogl_disable_fog cogl_double_to_int cogl_double_to_uint cogl_draw_attributes cogl_draw_attributes_array cogl_draw_indexed_attributes cogl_draw_indexed_attributes_array cogl_driver_error_get_type cogl_end_gl cogl_error_get_type cogl_feature_flags_get_type cogl_features_available cogl_fixed_atan cogl_fixed_atan2 cogl_fixed_cos cogl_fixed_get_type cogl_fixed_mul cogl_fixed_mul_div cogl_fixed_sin cogl_fixed_tan cogl_flush cogl_fog_mode_get_type cogl_frustum cogl_get_backface_culling_enabled cogl_get_bitmasks cogl_get_depth_test_enabled cogl_get_features cogl_get_modelview_matrix cogl_get_option_group cogl_get_path cogl_get_proc_address cogl_get_projection_matrix cogl_get_rectangle_indices cogl_get_source cogl_get_viewport cogl_gtype_matrix_get_type cogl_handle_get_type cogl_handle_ref cogl_handle_unref cogl_index_array_new cogl_indices_get_array cogl_indices_get_offset cogl_indices_get_type cogl_indices_new cogl_indices_new_for_array cogl_indices_set_offset cogl_indices_type_get_type cogl_is_attribute cogl_is_bitmap cogl_is_buffer cogl_is_indices_array cogl_is_material cogl_is_offscreen cogl_is_path cogl_is_pipeline cogl_is_pixel_array cogl_is_primitive cogl_is_program cogl_is_shader cogl_is_texture cogl_is_texture_3d cogl_is_vertex_array cogl_is_vertex_buffer cogl_is_vertex_buffer_indices cogl_material_alpha_func_get_type cogl_material_copy cogl_material_filter_get_type cogl_material_foreach_layer cogl_material_get_ambient cogl_material_get_color cogl_material_get_depth_range cogl_material_get_depth_test_enabled cogl_material_get_depth_test_function cogl_material_get_depth_writing_enabled cogl_material_get_diffuse cogl_material_get_emission cogl_material_get_layer_point_sprite_coords_enabled cogl_material_get_layer_wrap_mode_p cogl_material_get_layer_wrap_mode_s cogl_material_get_layer_wrap_mode_t cogl_material_get_layers cogl_material_get_n_layers cogl_material_get_point_size cogl_material_get_shininess cogl_material_get_specular cogl_material_get_user_program cogl_material_layer_get_mag_filter cogl_material_layer_get_min_filter cogl_material_layer_get_texture cogl_material_layer_get_type cogl_material_layer_get_wrap_mode_p cogl_material_layer_get_wrap_mode_s cogl_material_layer_get_wrap_mode_t cogl_material_layer_type_get_type cogl_material_new cogl_material_remove_layer cogl_material_set_alpha_test_function cogl_material_set_ambient cogl_material_set_ambient_and_diffuse cogl_material_set_blend cogl_material_set_blend_constant cogl_material_set_color cogl_material_set_color4f cogl_material_set_color4ub cogl_material_set_depth_range cogl_material_set_depth_test_enabled cogl_material_set_depth_test_function cogl_material_set_depth_writing_enabled cogl_material_set_diffuse cogl_material_set_emission cogl_material_set_layer cogl_material_set_layer_combine cogl_material_set_layer_combine_constant cogl_material_set_layer_filters cogl_material_set_layer_matrix cogl_material_set_layer_point_sprite_coords_enabled cogl_material_set_layer_wrap_mode cogl_material_set_layer_wrap_mode_p cogl_material_set_layer_wrap_mode_s cogl_material_set_layer_wrap_mode_t cogl_material_set_point_size cogl_material_set_shininess cogl_material_set_specular cogl_material_set_user_program cogl_material_wrap_mode_get_type cogl_matrix_copy cogl_matrix_equal cogl_matrix_free cogl_matrix_frustum cogl_matrix_get_array cogl_matrix_get_inverse cogl_matrix_init_from_array cogl_matrix_init_identity cogl_matrix_multiply cogl_matrix_ortho cogl_matrix_perspective cogl_matrix_project_points cogl_matrix_rotate cogl_matrix_scale cogl_matrix_transform_point cogl_matrix_transform_points cogl_matrix_translate cogl_object_get_user_data cogl_object_ref cogl_object_set_user_data cogl_object_unref cogl_offscreen_new_to_texture cogl_ortho cogl_path_arc cogl_path_close cogl_path_copy cogl_path_curve_to cogl_path_ellipse cogl_path_fill cogl_path_fill_preserve cogl_path_fill_rule_get_type cogl_path_get_fill_rule cogl_path_line cogl_path_line_to cogl_path_move_to cogl_path_new cogl_path_polygon cogl_path_polyline cogl_path_rectangle cogl_path_rel_curve_to cogl_path_rel_line_to cogl_path_rel_move_to cogl_path_round_rectangle cogl_path_set_fill_rule cogl_path_stroke cogl_path_stroke_preserve cogl_perspective cogl_pipeline_alpha_func_get_type cogl_pipeline_copy cogl_pipeline_filter_get_type cogl_pipeline_foreach_layer cogl_pipeline_get_alpha_test_function cogl_pipeline_get_alpha_test_reference cogl_pipeline_get_ambient cogl_pipeline_get_color cogl_pipeline_get_depth_range cogl_pipeline_get_depth_test_enabled cogl_pipeline_get_depth_test_function cogl_pipeline_get_depth_writing_enabled cogl_pipeline_get_diffuse cogl_pipeline_get_emission cogl_pipeline_get_layer_point_sprite_coords_enabled cogl_pipeline_get_layer_wrap_mode_p cogl_pipeline_get_layer_wrap_mode_s cogl_pipeline_get_layer_wrap_mode_t cogl_pipeline_get_n_layers cogl_pipeline_get_point_size cogl_pipeline_get_shininess cogl_pipeline_get_specular cogl_pipeline_get_user_program cogl_pipeline_new cogl_pipeline_remove_layer cogl_pipeline_set_alpha_test_function cogl_pipeline_set_ambient cogl_pipeline_set_ambient_and_diffuse cogl_pipeline_set_blend cogl_pipeline_set_blend_constant cogl_pipeline_set_color cogl_pipeline_set_color4f cogl_pipeline_set_color4ub cogl_pipeline_set_depth_range cogl_pipeline_set_depth_test_enabled cogl_pipeline_set_depth_test_function cogl_pipeline_set_depth_writing_enabled cogl_pipeline_set_diffuse cogl_pipeline_set_emission cogl_pipeline_set_layer_combine cogl_pipeline_set_layer_combine_constant cogl_pipeline_set_layer_filters cogl_pipeline_set_layer_matrix cogl_pipeline_set_layer_point_sprite_coords_enabled cogl_pipeline_set_layer_texture cogl_pipeline_set_layer_wrap_mode cogl_pipeline_set_layer_wrap_mode_p cogl_pipeline_set_layer_wrap_mode_s cogl_pipeline_set_layer_wrap_mode_t cogl_pipeline_set_point_size cogl_pipeline_set_shininess cogl_pipeline_set_specular cogl_pipeline_set_user_program cogl_pipeline_wrap_mode_get_type cogl_pixel_array_new_with_size cogl_pixel_array_set_region cogl_pixel_format_get_type cogl_polygon cogl_pop_framebuffer cogl_pop_matrix cogl_pop_source cogl_primitive_draw cogl_primitive_get_first_vertex cogl_primitive_get_mode cogl_primitive_get_n_vertices cogl_primitive_new cogl_primitive_new_p2 cogl_primitive_new_p2c4 cogl_primitive_new_p2t2 cogl_primitive_new_p2t2c4 cogl_primitive_new_p3 cogl_primitive_new_p3c4 cogl_primitive_new_p3t2 cogl_primitive_new_p3t2c4 cogl_primitive_new_with_attributes_array cogl_primitive_set_attributes cogl_primitive_set_first_vertex cogl_primitive_set_indices cogl_primitive_set_mode cogl_primitive_set_n_vertices cogl_program_attach_shader cogl_program_get_uniform_location cogl_program_link cogl_program_ref cogl_program_set_uniform_1f cogl_program_set_uniform_1i cogl_program_set_uniform_float cogl_program_set_uniform_int cogl_program_set_uniform_matrix cogl_program_unref cogl_program_use cogl_push_framebuffer cogl_push_matrix cogl_push_source cogl_read_pixels cogl_read_pixels_flags_get_type cogl_rectangle cogl_rectangle_with_multitexture_coords cogl_rectangle_with_texture_coords cogl_rectangles cogl_rectangles_with_texture_coords cogl_rotate cogl_scale cogl_set_backface_culling_enabled cogl_set_depth_test_enabled cogl_set_fog cogl_set_framebuffer cogl_set_modelview_matrix cogl_set_path cogl_set_projection_matrix cogl_set_source cogl_set_source_color cogl_set_source_color4f cogl_set_source_color4ub cogl_set_source_texture cogl_set_viewport cogl_shader_compile cogl_shader_get_info_log cogl_shader_get_type cogl_shader_is_compiled cogl_shader_source cogl_shader_type_get_type cogl_texture_3d_new_from_data cogl_texture_3d_new_with_size cogl_texture_flags_get_type cogl_texture_get_data cogl_texture_get_format cogl_texture_get_gl_texture cogl_texture_get_height cogl_texture_get_max_waste cogl_texture_get_rowstride cogl_texture_get_width cogl_texture_is_sliced cogl_texture_new_from_bitmap cogl_texture_new_from_buffer cogl_texture_new_from_buffer_EXP cogl_texture_new_from_data cogl_texture_new_from_file cogl_texture_new_from_foreign cogl_texture_new_from_sub_texture cogl_texture_new_with_size cogl_texture_set_region cogl_transform cogl_translate cogl_vector3_add cogl_vector3_copy cogl_vector3_cross_product cogl_vector3_distance cogl_vector3_divide_scalar cogl_vector3_dot_product cogl_vector3_equal cogl_vector3_equal_with_epsilon cogl_vector3_free cogl_vector3_init cogl_vector3_init_zero cogl_vector3_invert cogl_vector3_magnitude cogl_vector3_multiply_scalar cogl_vector3_normalize cogl_vector3_subtract cogl_vertex_array_new cogl_vertex_buffer_add cogl_vertex_buffer_delete cogl_vertex_buffer_disable cogl_vertex_buffer_draw cogl_vertex_buffer_draw_elements cogl_vertex_buffer_enable cogl_vertex_buffer_get_n_vertices cogl_vertex_buffer_indices_get_for_quads cogl_vertex_buffer_indices_get_type cogl_vertex_buffer_indices_new cogl_vertex_buffer_new cogl_vertex_buffer_submit cogl_vertices_mode_get_type
syn keyword clutterTypedef CoglAngle CoglBitmask CoglFixed CoglHandle
syn keyword clutterConstant CLUTTER_ABSOLUTE_ORIGIN_CHANGED CLUTTER_ACTOR_MAPPED CLUTTER_ACTOR_NO_LAYOUT CLUTTER_ACTOR_REACTIVE CLUTTER_ACTOR_REALIZED CLUTTER_ACTOR_VISIBLE CLUTTER_ALIGN_X_AXIS CLUTTER_ALIGN_Y_AXIS CLUTTER_ALLOCATION_NONE CLUTTER_ANIMATION_LAST CLUTTER_BIND_HEIGHT CLUTTER_BIND_POSITION CLUTTER_BIND_SIZE CLUTTER_BIND_WIDTH CLUTTER_BIND_X CLUTTER_BIND_Y CLUTTER_BIN_ALIGNMENT_CENTER CLUTTER_BIN_ALIGNMENT_END CLUTTER_BIN_ALIGNMENT_FILL CLUTTER_BIN_ALIGNMENT_FIXED CLUTTER_BIN_ALIGNMENT_START CLUTTER_BOX_ALIGNMENT_CENTER CLUTTER_BOX_ALIGNMENT_END CLUTTER_BOX_ALIGNMENT_START CLUTTER_BUTTON1_MASK CLUTTER_BUTTON2_MASK CLUTTER_BUTTON3_MASK CLUTTER_BUTTON4_MASK CLUTTER_BUTTON5_MASK CLUTTER_BUTTON_PRESS CLUTTER_BUTTON_RELEASE CLUTTER_CEX100_DOUBLE_BUFFERING CLUTTER_CEX100_TRIPLE_BUFFERING CLUTTER_CLIENT_MESSAGE CLUTTER_COLOR_ALUMINIUM_1 CLUTTER_COLOR_ALUMINIUM_2 CLUTTER_COLOR_ALUMINIUM_3 CLUTTER_COLOR_ALUMINIUM_4 CLUTTER_COLOR_ALUMINIUM_5 CLUTTER_COLOR_ALUMINIUM_6 CLUTTER_COLOR_BLACK CLUTTER_COLOR_BLUE CLUTTER_COLOR_BUTTER CLUTTER_COLOR_BUTTER_DARK CLUTTER_COLOR_BUTTER_LIGHT CLUTTER_COLOR_CHAMELEON CLUTTER_COLOR_CHAMELEON_DARK CLUTTER_COLOR_CHAMELEON_LIGHT CLUTTER_COLOR_CHOCOLATE CLUTTER_COLOR_CHOCOLATE_DARK CLUTTER_COLOR_CHOCOLATE_LIGHT CLUTTER_COLOR_CYAN CLUTTER_COLOR_DARK_BLUE CLUTTER_COLOR_DARK_CYAN CLUTTER_COLOR_DARK_GRAY CLUTTER_COLOR_DARK_GREEN CLUTTER_COLOR_DARK_MAGENTA CLUTTER_COLOR_DARK_RED CLUTTER_COLOR_DARK_YELLOW CLUTTER_COLOR_GRAY CLUTTER_COLOR_GREEN CLUTTER_COLOR_LIGHT_GRAY CLUTTER_COLOR_MAGENTA CLUTTER_COLOR_ORANGE CLUTTER_COLOR_ORANGE_DARK CLUTTER_COLOR_ORANGE_LIGHT CLUTTER_COLOR_PLUM CLUTTER_COLOR_PLUM_DARK CLUTTER_COLOR_PLUM_LIGHT CLUTTER_COLOR_RED CLUTTER_COLOR_SCARLET_RED CLUTTER_COLOR_SCARLET_RED_DARK CLUTTER_COLOR_SCARLET_RED_LIGHT CLUTTER_COLOR_SKY_BLUE CLUTTER_COLOR_SKY_BLUE_DARK CLUTTER_COLOR_SKY_BLUE_LIGHT CLUTTER_COLOR_TRANSPARENT CLUTTER_COLOR_WHITE CLUTTER_COLOR_YELLOW CLUTTER_CONTROL_MASK CLUTTER_CURSOR_DEVICE CLUTTER_CUSTOM_MODE CLUTTER_DELETE CLUTTER_DESTROY_NOTIFY CLUTTER_DRAG_AXIS_NONE CLUTTER_DRAG_X_AXIS CLUTTER_DRAG_Y_AXIS CLUTTER_EASE_IN_BACK CLUTTER_EASE_IN_BOUNCE CLUTTER_EASE_IN_CIRC CLUTTER_EASE_IN_CUBIC CLUTTER_EASE_IN_ELASTIC CLUTTER_EASE_IN_EXPO CLUTTER_EASE_IN_OUT_BACK CLUTTER_EASE_IN_OUT_BOUNCE CLUTTER_EASE_IN_OUT_CIRC CLUTTER_EASE_IN_OUT_CUBIC CLUTTER_EASE_IN_OUT_ELASTIC CLUTTER_EASE_IN_OUT_EXPO CLUTTER_EASE_IN_OUT_QUAD CLUTTER_EASE_IN_OUT_QUART CLUTTER_EASE_IN_OUT_QUINT CLUTTER_EASE_IN_OUT_SINE CLUTTER_EASE_IN_QUAD CLUTTER_EASE_IN_QUART CLUTTER_EASE_IN_QUINT CLUTTER_EASE_IN_SINE CLUTTER_EASE_OUT_BACK CLUTTER_EASE_OUT_BOUNCE CLUTTER_EASE_OUT_CIRC CLUTTER_EASE_OUT_CUBIC CLUTTER_EASE_OUT_ELASTIC CLUTTER_EASE_OUT_EXPO CLUTTER_EASE_OUT_QUAD CLUTTER_EASE_OUT_QUART CLUTTER_EASE_OUT_QUINT CLUTTER_EASE_OUT_SINE CLUTTER_ENTER CLUTTER_ERASER_DEVICE CLUTTER_EVENT_FLAG_SYNTHETIC CLUTTER_EVENT_NONE CLUTTER_EXTENSION_DEVICE CLUTTER_FEATURE_OFFSCREEN CLUTTER_FEATURE_SHADERS_GLSL CLUTTER_FEATURE_STAGE_CURSOR CLUTTER_FEATURE_STAGE_MULTIPLE CLUTTER_FEATURE_STAGE_STATIC CLUTTER_FEATURE_STAGE_USER_RESIZE CLUTTER_FEATURE_SWAP_EVENTS CLUTTER_FEATURE_SYNC_TO_VBLANK CLUTTER_FEATURE_TEXTURE_NPOT CLUTTER_FEATURE_TEXTURE_READ_PIXELS CLUTTER_FEATURE_TEXTURE_YUV CLUTTER_FLOW_HORIZONTAL CLUTTER_FLOW_VERTICAL CLUTTER_FONT_HINTING CLUTTER_FONT_MIPMAPPING CLUTTER_FRAGMENT_SHADER CLUTTER_GRAVITY_CENTER CLUTTER_GRAVITY_EAST CLUTTER_GRAVITY_NONE CLUTTER_GRAVITY_NORTH CLUTTER_GRAVITY_NORTH_EAST CLUTTER_GRAVITY_NORTH_WEST CLUTTER_GRAVITY_SOUTH CLUTTER_GRAVITY_SOUTH_EAST CLUTTER_GRAVITY_SOUTH_WEST CLUTTER_GRAVITY_WEST CLUTTER_HYPER_MASK CLUTTER_INIT_ERROR_BACKEND CLUTTER_INIT_ERROR_INTERNAL CLUTTER_INIT_ERROR_THREADS CLUTTER_INIT_ERROR_UNKNOWN CLUTTER_INIT_SUCCESS CLUTTER_INPUT_AXIS_IGNORE CLUTTER_INPUT_AXIS_PRESSURE CLUTTER_INPUT_AXIS_WHEEL CLUTTER_INPUT_AXIS_X CLUTTER_INPUT_AXIS_XTILT CLUTTER_INPUT_AXIS_Y CLUTTER_INPUT_AXIS_YTILT CLUTTER_INPUT_MODE_FLOATING CLUTTER_INPUT_MODE_MASTER CLUTTER_INPUT_MODE_SLAVE CLUTTER_INTERPOLATION_CUBIC CLUTTER_INTERPOLATION_LINEAR CLUTTER_JOYSTICK_DEVICE CLUTTER_KEYBOARD_DEVICE CLUTTER_KEY_PRESS CLUTTER_KEY_RELEASE CLUTTER_LEAVE CLUTTER_LINEAR CLUTTER_LOCK_MASK CLUTTER_META_MASK CLUTTER_MOD1_MASK CLUTTER_MOD2_MASK CLUTTER_MOD3_MASK CLUTTER_MOD4_MASK CLUTTER_MOD5_MASK CLUTTER_MODIFIER_MASK CLUTTER_MOTION CLUTTER_NOTHING CLUTTER_N_DEVICE_TYPES CLUTTER_PATH_CLOSE CLUTTER_PATH_CURVE_TO CLUTTER_PATH_LINE_TO CLUTTER_PATH_MOVE_TO CLUTTER_PATH_REL_CURVE_TO CLUTTER_PATH_REL_LINE_TO CLUTTER_PATH_REL_MOVE_TO CLUTTER_PEN_DEVICE CLUTTER_PICK_ALL CLUTTER_PICK_NONE CLUTTER_PICK_REACTIVE CLUTTER_POINTER_DEVICE CLUTTER_RELEASE_MASK CLUTTER_REQUEST_HEIGHT_FOR_WIDTH CLUTTER_REQUEST_WIDTH_FOR_HEIGHT CLUTTER_ROTATE_CCW CLUTTER_ROTATE_CW CLUTTER_SCRIPT_ERROR_INVALID_PROPERTY CLUTTER_SCRIPT_ERROR_INVALID_TYPE_FUNCTION CLUTTER_SCRIPT_ERROR_INVALID_VALUE CLUTTER_SCROLL CLUTTER_SCROLL_DOWN CLUTTER_SCROLL_LEFT CLUTTER_SCROLL_RIGHT CLUTTER_SCROLL_UP CLUTTER_SHADER_ERROR_COMPILE CLUTTER_SHADER_ERROR_NO_ASM CLUTTER_SHADER_ERROR_NO_GLSL CLUTTER_SHIFT_MASK CLUTTER_SNAP_EDGE_BOTTOM CLUTTER_SNAP_EDGE_LEFT CLUTTER_SNAP_EDGE_RIGHT CLUTTER_SNAP_EDGE_TOP CLUTTER_STAGE_STATE CLUTTER_STAGE_STATE_ACTIVATED CLUTTER_STAGE_STATE_FULLSCREEN CLUTTER_STAGE_STATE_OFFSCREEN CLUTTER_SUPER_MASK CLUTTER_TABLET_DEVICE CLUTTER_TABLE_ALIGNMENT_CENTER CLUTTER_TABLE_ALIGNMENT_END CLUTTER_TABLE_ALIGNMENT_START CLUTTER_TEXTURE_ERROR_BAD_FORMAT CLUTTER_TEXTURE_ERROR_NO_YUV CLUTTER_TEXTURE_ERROR_OUT_OF_MEMORY CLUTTER_TEXTURE_NONE CLUTTER_TEXTURE_QUALITY_HIGH CLUTTER_TEXTURE_QUALITY_LOW CLUTTER_TEXTURE_QUALITY_MEDIUM CLUTTER_TEXTURE_RGB_FLAG_BGR CLUTTER_TEXTURE_RGB_FLAG_PREMULT CLUTTER_TEXTURE_YUV_FLAG_YUV2 CLUTTER_TEXT_DIRECTION_DEFAULT CLUTTER_TEXT_DIRECTION_LTR CLUTTER_TEXT_DIRECTION_RTL CLUTTER_TIMELINE_BACKWARD CLUTTER_TIMELINE_FORWARD CLUTTER_TOUCHPAD_DEVICE CLUTTER_TOUCHSCREEN_DEVICE CLUTTER_UNIT_CM CLUTTER_UNIT_EM CLUTTER_UNIT_MM CLUTTER_UNIT_PIXEL CLUTTER_UNIT_POINT CLUTTER_VERTEX_SHADER CLUTTER_X11_FILTER_CONTINUE CLUTTER_X11_FILTER_REMOVE CLUTTER_X11_FILTER_TRANSLATE CLUTTER_X11_XINPUT_BUTTON_PRESS_EVENT CLUTTER_X11_XINPUT_BUTTON_RELEASE_EVENT CLUTTER_X11_XINPUT_KEY_PRESS_EVENT CLUTTER_X11_XINPUT_KEY_RELEASE_EVENT CLUTTER_X11_XINPUT_LAST_EVENT CLUTTER_X11_XINPUT_MOTION_NOTIFY_EVENT CLUTTER_X_AXIS CLUTTER_Y_AXIS CLUTTER_Z_AXIS COGL_ATTRIBUTE_NAME_ID_COLOR_ARRAY COGL_ATTRIBUTE_NAME_ID_CUSTOM_ARRAY COGL_ATTRIBUTE_NAME_ID_NORMAL_ARRAY COGL_ATTRIBUTE_NAME_ID_POSITION_ARRAY COGL_ATTRIBUTE_NAME_ID_TEXTURE_COORD_ARRAY COGL_ATTRIBUTE_TYPE_BYTE COGL_ATTRIBUTE_TYPE_FLOAT COGL_ATTRIBUTE_TYPE_SHORT COGL_ATTRIBUTE_TYPE_UNSIGNED_BYTE COGL_ATTRIBUTE_TYPE_UNSIGNED_SHORT COGL_BITMAP_ERROR_CORRUPT_IMAGE COGL_BITMAP_ERROR_FAILED COGL_BITMAP_ERROR_UNKNOWN_TYPE COGL_BLEND_STRING_ERROR_ARGUMENT_PARSE_ERROR COGL_BLEND_STRING_ERROR_GPU_UNSUPPORTED_ERROR COGL_BLEND_STRING_ERROR_INVALID_ERROR COGL_BLEND_STRING_ERROR_PARSE_ERROR COGL_BUFFER_ACCESS_READ COGL_BUFFER_ACCESS_READ_WRITE COGL_BUFFER_ACCESS_WRITE COGL_BUFFER_BIT_COLOR COGL_BUFFER_BIT_DEPTH COGL_BUFFER_BIT_STENCIL COGL_BUFFER_MAP_HINT_DISCARD COGL_BUFFER_UPDATE_HINT_DYNAMIC COGL_BUFFER_UPDATE_HINT_STATIC COGL_BUFFER_UPDATE_HINT_STREAM COGL_DEPTH_TEST_FUNCTION_ALWAYS COGL_DEPTH_TEST_FUNCTION_EQUAL COGL_DEPTH_TEST_FUNCTION_GEQUAL COGL_DEPTH_TEST_FUNCTION_GREATER COGL_DEPTH_TEST_FUNCTION_LEQUAL COGL_DEPTH_TEST_FUNCTION_LESS COGL_DEPTH_TEST_FUNCTION_NEVER COGL_DEPTH_TEST_FUNCTION_NOTEQUAL COGL_DRAW_COLOR_ATTRIBUTE_IS_OPAQUE COGL_DRAW_SKIP_FRAMEBUFFER_FLUSH COGL_DRAW_SKIP_JOURNAL_FLUSH COGL_DRAW_SKIP_LEGACY_STATE COGL_DRAW_SKIP_PIPELINE_VALIDATION COGL_DRIVER_ERROR_INVALID_VERSION COGL_DRIVER_ERROR_UNKNOWN_VERSION COGL_ERROR_UNSUPPORTED COGL_FEATURE_DEPTH_RANGE COGL_FEATURE_FOUR_CLIP_PLANES COGL_FEATURE_MAP_BUFFER_FOR_READ COGL_FEATURE_MAP_BUFFER_FOR_WRITE COGL_FEATURE_OFFSCREEN COGL_FEATURE_OFFSCREEN_BLIT COGL_FEATURE_OFFSCREEN_MULTISAMPLE COGL_FEATURE_PBOS COGL_FEATURE_POINT_SPRITE COGL_FEATURE_SHADERS_ARBFP COGL_FEATURE_SHADERS_GLSL COGL_FEATURE_STENCIL_BUFFER COGL_FEATURE_TEXTURE_3D COGL_FEATURE_TEXTURE_NPOT COGL_FEATURE_TEXTURE_NPOT_BASIC COGL_FEATURE_TEXTURE_NPOT_MIPMAP COGL_FEATURE_TEXTURE_NPOT_REPEAT COGL_FEATURE_TEXTURE_READ_PIXELS COGL_FEATURE_TEXTURE_RECTANGLE COGL_FEATURE_TEXTURE_YUV COGL_FEATURE_UNSIGNED_INT_INDICES COGL_FEATURE_VBOS COGL_FOG_MODE_EXPONENTIAL COGL_FOG_MODE_EXPONENTIAL_SQUARED COGL_FOG_MODE_LINEAR COGL_INDICES_TYPE_UNSIGNED_BYTE COGL_INDICES_TYPE_UNSIGNED_INT COGL_INDICES_TYPE_UNSIGNED_SHORT COGL_MATERIAL_ALPHA_FUNC_ALWAYS COGL_MATERIAL_ALPHA_FUNC_EQUAL COGL_MATERIAL_ALPHA_FUNC_GEQUAL COGL_MATERIAL_ALPHA_FUNC_GREATER COGL_MATERIAL_ALPHA_FUNC_LEQUAL COGL_MATERIAL_ALPHA_FUNC_LESS COGL_MATERIAL_ALPHA_FUNC_NEVER COGL_MATERIAL_ALPHA_FUNC_NOTEQUAL COGL_MATERIAL_FILTER_LINEAR COGL_MATERIAL_FILTER_LINEAR_MIPMAP_LINEAR COGL_MATERIAL_FILTER_LINEAR_MIPMAP_NEAREST COGL_MATERIAL_FILTER_NEAREST COGL_MATERIAL_FILTER_NEAREST_MIPMAP_LINEAR COGL_MATERIAL_FILTER_NEAREST_MIPMAP_NEAREST COGL_MATERIAL_LAYER_TYPE_TEXTURE COGL_MATERIAL_WRAP_MODE_AUTOMATIC COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE COGL_MATERIAL_WRAP_MODE_REPEAT COGL_OFFSCREEN_BUFFER COGL_PATH_FILL_RULE_EVEN_ODD COGL_PATH_FILL_RULE_NON_ZERO COGL_PIPELINE_ALPHA_FUNC_ALWAYS COGL_PIPELINE_ALPHA_FUNC_EQUAL COGL_PIPELINE_ALPHA_FUNC_GEQUAL COGL_PIPELINE_ALPHA_FUNC_GREATER COGL_PIPELINE_ALPHA_FUNC_LEQUAL COGL_PIPELINE_ALPHA_FUNC_LESS COGL_PIPELINE_ALPHA_FUNC_NEVER COGL_PIPELINE_ALPHA_FUNC_NOTEQUAL COGL_PIPELINE_FILTER_LINEAR COGL_PIPELINE_FILTER_LINEAR_MIPMAP_LINEAR COGL_PIPELINE_FILTER_LINEAR_MIPMAP_NEAREST COGL_PIPELINE_FILTER_NEAREST COGL_PIPELINE_FILTER_NEAREST_MIPMAP_LINEAR COGL_PIPELINE_FILTER_NEAREST_MIPMAP_NEAREST COGL_PIPELINE_WRAP_MODE_AUTOMATIC COGL_PIPELINE_WRAP_MODE_CLAMP_TO_EDGE COGL_PIPELINE_WRAP_MODE_REPEAT COGL_PIXEL_FORMAT_ABGR_8888 COGL_PIXEL_FORMAT_ABGR_8888_PRE COGL_PIXEL_FORMAT_ANY COGL_PIXEL_FORMAT_ARGB_8888 COGL_PIXEL_FORMAT_ARGB_8888_PRE COGL_PIXEL_FORMAT_A_8 COGL_PIXEL_FORMAT_BGRA_8888 COGL_PIXEL_FORMAT_BGRA_8888_PRE COGL_PIXEL_FORMAT_BGR_888 COGL_PIXEL_FORMAT_G_8 COGL_PIXEL_FORMAT_RGBA_4444 COGL_PIXEL_FORMAT_RGBA_4444_PRE COGL_PIXEL_FORMAT_RGBA_5551 COGL_PIXEL_FORMAT_RGBA_5551_PRE COGL_PIXEL_FORMAT_RGBA_8888 COGL_PIXEL_FORMAT_RGBA_8888_PRE COGL_PIXEL_FORMAT_RGB_565 COGL_PIXEL_FORMAT_RGB_888 COGL_PIXEL_FORMAT_YUV COGL_READ_PIXELS_COLOR_BUFFER COGL_SHADER_TYPE_FRAGMENT COGL_SHADER_TYPE_VERTEX COGL_TEXTURE_NONE COGL_TEXTURE_NO_ATLAS COGL_TEXTURE_NO_AUTO_MIPMAP COGL_TEXTURE_NO_SLICING COGL_VERTICES_MODE_LINES COGL_VERTICES_MODE_LINE_LOOP COGL_VERTICES_MODE_LINE_STRIP COGL_VERTICES_MODE_POINTS COGL_VERTICES_MODE_TRIANGLES COGL_VERTICES_MODE_TRIANGLE_FAN COGL_VERTICES_MODE_TRIANGLE_STRIP COGL_WINDOW_BUFFER
syn keyword clutterStruct CallyActor CallyActorClass CallyActorPrivate CallyClone CallyCloneClass CallyClonePrivate CallyGroup CallyGroupClass CallyGroupPrivate CallyRectangle CallyRectangleClass CallyRectanglePrivate CallyRoot CallyRootClass CallyRootPrivate CallyStage CallyStageClass CallyStagePrivate CallyText CallyTextClass CallyTextPrivate CallyTexture CallyTextureClass CallyTexturePrivate CallyUtil CallyUtilClass CallyUtilPrivate ClutterAction ClutterActionClass ClutterActor ClutterActorBox ClutterActorClass ClutterActorMeta ClutterActorMetaClass ClutterActorMetaPrivate ClutterActorPrivate ClutterAlignConstraint ClutterAlignConstraintClass ClutterAlpha ClutterAlphaClass ClutterAlphaPrivate ClutterAnimatable ClutterAnimatableIface ClutterAnimation ClutterAnimationClass ClutterAnimationPrivate ClutterAnimator ClutterAnimatorClass ClutterAnimatorKey ClutterAnimatorPrivate ClutterAnyEvent ClutterBackend ClutterBackendClass ClutterBinLayout ClutterBinLayoutClass ClutterBinLayoutPrivate ClutterBindConstraint ClutterBindConstraintClass ClutterBindingPool ClutterBindingPoolClass ClutterBlurEffect ClutterBlurEffectClass ClutterBox ClutterBoxClass ClutterBoxLayout ClutterBoxLayoutClass ClutterBoxLayoutPrivate ClutterBoxPrivate ClutterButtonEvent ClutterCairoTexture ClutterCairoTextureClass ClutterCairoTexturePrivate ClutterChildMeta ClutterChildMetaClass ClutterClickAction ClutterClickActionClass ClutterClickActionPrivate ClutterClone ClutterCloneClass ClutterClonePrivate ClutterColor ClutterColorizeEffect ClutterColorizeEffectClass ClutterConstraint ClutterConstraintClass ClutterContainer ClutterContainerIface ClutterCrossingEvent ClutterDeformEffect ClutterDeformEffectClass ClutterDeformEffectPrivate ClutterDesaturateEffect ClutterDesaturateEffectClass ClutterDeviceManager ClutterDeviceManagerClass ClutterDeviceManagerPrivate ClutterDragAction ClutterDragActionClass ClutterDragActionPrivate ClutterEffect ClutterEffectClass ClutterFixedLayout ClutterFixedLayoutClass ClutterFlowLayout ClutterFlowLayoutClass ClutterFlowLayoutPrivate ClutterFog ClutterGLXTexturePixmap ClutterGLXTexturePixmapClass ClutterGLXTexturePixmapPrivate ClutterGeometry ClutterGroup ClutterGroupClass ClutterGroupPrivate ClutterInputDevice ClutterInputDeviceClass ClutterInterval ClutterIntervalClass ClutterIntervalPrivate ClutterKeyEvent ClutterKnot ClutterLayoutManager ClutterLayoutManagerClass ClutterLayoutMeta ClutterLayoutMetaClass ClutterListModel ClutterListModelClass ClutterListModelPrivate ClutterMedia ClutterMediaIface ClutterModel ClutterModelClass ClutterModelIter ClutterModelIterClass ClutterModelIterPrivate ClutterModelPrivate ClutterMotionEvent ClutterOffscreenEffect ClutterOffscreenEffectClass ClutterOffscreenEffectPrivate ClutterPageTurnEffect ClutterPageTurnEffectClass ClutterPaintVolume ClutterParamSpecColor ClutterParamSpecFixed ClutterParamSpecUnits ClutterPath ClutterPathClass ClutterPathConstraint ClutterPathConstraintClass ClutterPathNode ClutterPathPrivate ClutterPerspective ClutterRectangle ClutterRectangleClass ClutterRectanglePrivate ClutterScore ClutterScoreClass ClutterScorePrivate ClutterScript ClutterScriptClass ClutterScriptPrivate ClutterScriptable ClutterScriptableIface ClutterScrollEvent ClutterSettings ClutterSettingsClass ClutterShader ClutterShaderClass ClutterShaderEffect ClutterShaderEffectClass ClutterShaderEffectPrivate ClutterShaderFloat ClutterShaderInt ClutterShaderMatrix ClutterShaderPrivate ClutterSnapConstraint ClutterSnapConstraintClass ClutterStage ClutterStageClass ClutterStageManager ClutterStageManagerClass ClutterStagePrivate ClutterStageStateEvent ClutterState ClutterStateClass ClutterStateKey ClutterStatePrivate ClutterTableLayout ClutterTableLayoutClass ClutterTableLayoutPrivate ClutterText ClutterTextClass ClutterTextPrivate ClutterTexture ClutterTextureClass ClutterTexturePrivate ClutterTimeline ClutterTimelineClass ClutterTimelinePrivate ClutterUnits ClutterVertex ClutterX11TexturePixmap ClutterX11TexturePixmapClass ClutterX11TexturePixmapPrivate ClutterX11XInputDevice CoglAttribute CoglBitmap CoglBuffer CoglClipState CoglColor CoglFramebuffer CoglIndexArray CoglIndices CoglMaterial CoglMaterialLayer CoglMatrix CoglObject CoglPath CoglPipeline CoglPixelArray CoglPrimitive CoglRectangleMap CoglRectangleMapEntry CoglTextureVertex CoglVertexArray
syn keyword clutterUnion ClutterEvent
syn keyword clutterMacro CALLY_ACCESSIBLE_FACTORY CALLY_ACTOR CALLY_ACTOR_CLASS CALLY_ACTOR_GET_CLASS CALLY_ACTOR_SET_FACTORY CALLY_CLONE CALLY_CLONE_CLASS CALLY_CLONE_GET_CLASS CALLY_GROUP CALLY_GROUP_CLASS CALLY_GROUP_GET_CLASS CALLY_IS_ACTOR CALLY_IS_ACTOR_CLASS CALLY_IS_CLONE CALLY_IS_CLONE_CLASS CALLY_IS_GROUP CALLY_IS_GROUP_CLASS CALLY_IS_RECTANGLE CALLY_IS_RECTANGLE_CLASS CALLY_IS_ROOT CALLY_IS_ROOT_CLASS CALLY_IS_STAGE CALLY_IS_STAGE_CLASS CALLY_IS_TEXT CALLY_IS_TEXTURE CALLY_IS_TEXTURE_CLASS CALLY_IS_TEXT_CLASS CALLY_IS_UTIL CALLY_IS_UTIL_CLASS CALLY_RECTANGLE CALLY_RECTANGLE_CLASS CALLY_RECTANGLE_GET_CLASS CALLY_ROOT CALLY_ROOT_CLASS CALLY_ROOT_GET_CLASS CALLY_STAGE CALLY_STAGE_CLASS CALLY_STAGE_GET_CLASS CALLY_TEXT CALLY_TEXTURE CALLY_TEXTURE_CLASS CALLY_TEXTURE_GET_CLASS CALLY_TEXT_CLASS CALLY_TEXT_GET_CLASS CALLY_UTIL CALLY_UTIL_CLASS CALLY_UTIL_GET_CLASS CLUTTER_ACTION CLUTTER_ACTION_CLASS CLUTTER_ACTION_GET_CLASS CLUTTER_ACTOR CLUTTER_ACTOR_CLASS CLUTTER_ACTOR_GET_CLASS CLUTTER_ACTOR_IS_MAPPED CLUTTER_ACTOR_IS_REACTIVE CLUTTER_ACTOR_IS_REALIZED CLUTTER_ACTOR_IS_VISIBLE CLUTTER_ACTOR_META CLUTTER_ACTOR_META_CLASS CLUTTER_ACTOR_META_GET_CLASS CLUTTER_ACTOR_SET_FLAGS CLUTTER_ACTOR_UNSET_FLAGS CLUTTER_ALIGN_CONSTRAINT CLUTTER_ALPHA CLUTTER_ALPHA_CLASS CLUTTER_ALPHA_GET_CLASS CLUTTER_ANIMATABLE CLUTTER_ANIMATABLE_GET_IFACE CLUTTER_ANIMATION CLUTTER_ANIMATION_CLASS CLUTTER_ANIMATION_GET_CLASS CLUTTER_ANIMATOR CLUTTER_ANIMATOR_CLASS CLUTTER_ANIMATOR_GET_CLASS CLUTTER_BACKEND CLUTTER_BINDING_POOL CLUTTER_BIND_CONSTRAINT CLUTTER_BIN_LAYOUT CLUTTER_BIN_LAYOUT_CLASS CLUTTER_BIN_LAYOUT_GET_CLASS CLUTTER_BLUR_EFFECT CLUTTER_BOX CLUTTER_BOX_CLASS CLUTTER_BOX_GET_CLASS CLUTTER_BOX_LAYOUT CLUTTER_BOX_LAYOUT_CLASS CLUTTER_BOX_LAYOUT_GET_CLASS CLUTTER_CAIRO_TEXTURE CLUTTER_CAIRO_TEXTURE_CLASS CLUTTER_CAIRO_TEXTURE_GET_CLASS CLUTTER_CALLBACK CLUTTER_CHECK_VERSION CLUTTER_CHILD_META CLUTTER_CHILD_META_CLASS CLUTTER_CHILD_META_GET_CLASS CLUTTER_CLICK_ACTION CLUTTER_CLICK_ACTION_CLASS CLUTTER_CLICK_ACTION_GET_CLASS CLUTTER_CLONE CLUTTER_CLONE_CLASS CLUTTER_CLONE_GET_CLASS CLUTTER_COLORIZE_EFFECT CLUTTER_CONSTRAINT CLUTTER_CONSTRAINT_CLASS CLUTTER_CONSTRAINT_GET_CLASS CLUTTER_CONTAINER CLUTTER_CONTAINER_GET_IFACE CLUTTER_DEFORM_EFFECT CLUTTER_DEFORM_EFFECT_CLASS CLUTTER_DEFORM_EFFECT_GET_CLASS CLUTTER_DESATURATE_EFFECT CLUTTER_DEVICE_MANAGER CLUTTER_DEVICE_MANAGER_CLASS CLUTTER_DEVICE_MANAGER_GET_CLASS CLUTTER_DRAG_ACTION CLUTTER_DRAG_ACTION_CLASS CLUTTER_DRAG_ACTION_GET_CLASS CLUTTER_EFFECT CLUTTER_EFFECT_CLASS CLUTTER_EFFECT_GET_CLASS CLUTTER_FIXED_LAYOUT CLUTTER_FIXED_LAYOUT_CLASS CLUTTER_FIXED_LAYOUT_GET_CLASS CLUTTER_FLOW_LAYOUT CLUTTER_FLOW_LAYOUT_CLASS CLUTTER_FLOW_LAYOUT_GET_CLASS CLUTTER_GLX_IS_TEXTURE_PIXMAP CLUTTER_GLX_IS_TEXTURE_PIXMAP_CLASS CLUTTER_GLX_TEXTURE_PIXMAP CLUTTER_GLX_TEXTURE_PIXMAP_CLASS CLUTTER_GLX_TEXTURE_PIXMAP_GET_CLASS CLUTTER_GROUP CLUTTER_GROUP_CLASS CLUTTER_GROUP_GET_CLASS CLUTTER_INPUT_DEVICE CLUTTER_INPUT_DEVICE_CLASS CLUTTER_INPUT_DEVICE_GET_CLASS CLUTTER_INTERVAL CLUTTER_INTERVAL_CLASS CLUTTER_INTERVAL_GET_CLASS CLUTTER_IS_ACTION CLUTTER_IS_ACTION_CLASS CLUTTER_IS_ACTOR CLUTTER_IS_ACTOR_CLASS CLUTTER_IS_ACTOR_META CLUTTER_IS_ACTOR_META_CLASS CLUTTER_IS_ALIGN_CONSTRAINT CLUTTER_IS_ALPHA CLUTTER_IS_ALPHA_CLASS CLUTTER_IS_ANIMATABLE CLUTTER_IS_ANIMATION CLUTTER_IS_ANIMATION_CLASS CLUTTER_IS_ANIMATOR CLUTTER_IS_ANIMATOR_CLASS CLUTTER_IS_BACKEND CLUTTER_IS_BINDING_POOL CLUTTER_IS_BIND_CONSTRAINT CLUTTER_IS_BIN_LAYOUT CLUTTER_IS_BIN_LAYOUT_CLASS CLUTTER_IS_BLUR_EFFECT CLUTTER_IS_BOX CLUTTER_IS_BOX_CLASS CLUTTER_IS_BOX_LAYOUT CLUTTER_IS_BOX_LAYOUT_CLASS CLUTTER_IS_CAIRO_TEXTURE CLUTTER_IS_CAIRO_TEXTURE_CLASS CLUTTER_IS_CHILD_META CLUTTER_IS_CHILD_META_CLASS CLUTTER_IS_CLICK_ACTION CLUTTER_IS_CLICK_ACTION_CLASS CLUTTER_IS_CLONE CLUTTER_IS_CLONE_CLASS CLUTTER_IS_COLORIZE_EFFECT CLUTTER_IS_CONSTRAINT CLUTTER_IS_CONSTRAINT_CLASS CLUTTER_IS_CONTAINER CLUTTER_IS_DEFORM_EFFECT CLUTTER_IS_DEFORM_EFFECT_CLASS CLUTTER_IS_DESATURATE_EFFECT CLUTTER_IS_DEVICE_MANAGER CLUTTER_IS_DEVICE_MANAGER_CLASS CLUTTER_IS_DRAG_ACTION CLUTTER_IS_DRAG_ACTION_CLASS CLUTTER_IS_EFFECT CLUTTER_IS_EFFECT_CLASS CLUTTER_IS_FIXED_LAYOUT CLUTTER_IS_FIXED_LAYOUT_CLASS CLUTTER_IS_FLOW_LAYOUT CLUTTER_IS_FLOW_LAYOUT_CLASS CLUTTER_IS_GROUP CLUTTER_IS_GROUP_CLASS CLUTTER_IS_INPUT_DEVICE CLUTTER_IS_INPUT_DEVICE_CLASS CLUTTER_IS_INTERVAL CLUTTER_IS_INTERVAL_CLASS CLUTTER_IS_LAYOUT_MANAGER CLUTTER_IS_LAYOUT_MANAGER_CLASS CLUTTER_IS_LAYOUT_META CLUTTER_IS_LAYOUT_META_CLASS CLUTTER_IS_LIST_MODEL CLUTTER_IS_LIST_MODEL_CLASS CLUTTER_IS_MEDIA CLUTTER_IS_MODEL CLUTTER_IS_MODEL_CLASS CLUTTER_IS_MODEL_ITER CLUTTER_IS_MODEL_ITER_CLASS CLUTTER_IS_OFFSCREEN_EFFECT CLUTTER_IS_OFFSCREEN_EFFECT_CLASS CLUTTER_IS_PAGE_TURN_EFFECT CLUTTER_IS_PARAM_SPEC_COLOR CLUTTER_IS_PARAM_SPEC_FIXED CLUTTER_IS_PARAM_SPEC_UNITS CLUTTER_IS_PATH CLUTTER_IS_PATH_CLASS CLUTTER_IS_PATH_CONSTRAINT CLUTTER_IS_RECTANGLE CLUTTER_IS_RECTANGLE_CLASS CLUTTER_IS_SCORE CLUTTER_IS_SCORE_CLASS CLUTTER_IS_SCRIPT CLUTTER_IS_SCRIPTABLE CLUTTER_IS_SCRIPT_CLASS CLUTTER_IS_SETTINGS CLUTTER_IS_SHADER CLUTTER_IS_SHADER_CLASS CLUTTER_IS_SHADER_EFFECT CLUTTER_IS_SHADER_EFFECT_CLASS CLUTTER_IS_SNAP_CONSTRAINT CLUTTER_IS_STAGE CLUTTER_IS_STAGE_CLASS CLUTTER_IS_STAGE_MANAGER CLUTTER_IS_STAGE_MANAGER_CLASS CLUTTER_IS_STATE CLUTTER_IS_STATE_CLASS CLUTTER_IS_TABLE_LAYOUT CLUTTER_IS_TABLE_LAYOUT_CLASS CLUTTER_IS_TEXT CLUTTER_IS_TEXTURE CLUTTER_IS_TEXTURE_CLASS CLUTTER_IS_TEXT_CLASS CLUTTER_IS_TIMELINE CLUTTER_IS_TIMELINE_CLASS CLUTTER_LAYOUT_MANAGER CLUTTER_LAYOUT_MANAGER_CLASS CLUTTER_LAYOUT_MANAGER_GET_CLASS CLUTTER_LAYOUT_META CLUTTER_LAYOUT_META_CLASS CLUTTER_LAYOUT_META_GET_CLASS CLUTTER_LIST_MODEL CLUTTER_LIST_MODEL_CLASS CLUTTER_LIST_MODEL_GET_CLASS CLUTTER_MEDIA CLUTTER_MEDIA_GET_INTERFACE CLUTTER_MODEL CLUTTER_MODEL_CLASS CLUTTER_MODEL_GET_CLASS CLUTTER_MODEL_ITER CLUTTER_MODEL_ITER_CLASS CLUTTER_MODEL_ITER_GET_CLASS CLUTTER_OFFSCREEN_EFFECT CLUTTER_OFFSCREEN_EFFECT_CLASS CLUTTER_OFFSCREEN_EFFECT_GET_CLASS CLUTTER_PAGE_TURN_EFFECT CLUTTER_PARAM_SPEC_COLOR CLUTTER_PARAM_SPEC_FIXED CLUTTER_PARAM_SPEC_UNITS CLUTTER_PATH CLUTTER_PATH_CLASS CLUTTER_PATH_CONSTRAINT CLUTTER_PATH_GET_CLASS CLUTTER_RECTANGLE CLUTTER_RECTANGLE_CLASS CLUTTER_RECTANGLE_GET_CLASS CLUTTER_SCORE CLUTTER_SCORE_CLASS CLUTTER_SCORE_GET_CLASS CLUTTER_SCRIPT CLUTTER_SCRIPTABLE CLUTTER_SCRIPTABLE_GET_IFACE CLUTTER_SCRIPT_CLASS CLUTTER_SCRIPT_GET_CLASS CLUTTER_SETTINGS CLUTTER_SHADER CLUTTER_SHADER_CLASS CLUTTER_SHADER_EFFECT CLUTTER_SHADER_EFFECT_CLASS CLUTTER_SHADER_EFFECT_GET_CLASS CLUTTER_SHADER_GET_CLASS CLUTTER_SNAP_CONSTRAINT CLUTTER_STAGE CLUTTER_STAGE_CLASS CLUTTER_STAGE_GET_CLASS CLUTTER_STAGE_MANAGER CLUTTER_STAGE_MANAGER_CLASS CLUTTER_STAGE_MANAGER_GET_CLASS CLUTTER_STATE CLUTTER_STATE_CLASS CLUTTER_STATE_GET_CLASS CLUTTER_TABLE_LAYOUT CLUTTER_TABLE_LAYOUT_CLASS CLUTTER_TABLE_LAYOUT_GET_CLASS CLUTTER_TEXT CLUTTER_TEXTURE CLUTTER_TEXTURE_CLASS CLUTTER_TEXTURE_GET_CLASS CLUTTER_TEXT_CLASS CLUTTER_TEXT_GET_CLASS CLUTTER_TIMELINE CLUTTER_TIMELINE_CLASS CLUTTER_TIMELINE_GET_CLASS CLUTTER_VALUE_HOLDS_COLOR CLUTTER_VALUE_HOLDS_FIXED CLUTTER_VALUE_HOLDS_SHADER_FLOAT CLUTTER_VALUE_HOLDS_SHADER_INT CLUTTER_VALUE_HOLDS_SHADER_MATRIX CLUTTER_VALUE_HOLDS_UNITS CLUTTER_X11_IS_TEXTURE_PIXMAP CLUTTER_X11_IS_TEXTURE_PIXMAP_CLASS CLUTTER_X11_TEXTURE_PIXMAP CLUTTER_X11_TEXTURE_PIXMAP_CLASS CLUTTER_X11_TEXTURE_PIXMAP_GET_CLASS COGL_FIXED_CEIL COGL_FIXED_DIV COGL_FIXED_FAST_DIV COGL_FIXED_FAST_MUL COGL_FIXED_FLOOR COGL_FIXED_FRACTION COGL_FIXED_FROM_DOUBLE COGL_FIXED_FROM_FLOAT COGL_FIXED_FROM_INT COGL_FIXED_MUL COGL_FIXED_MUL_DIV COGL_FIXED_TO_DOUBLE COGL_FIXED_TO_FLOAT COGL_FIXED_TO_INT COGL_FLOAT_TO_INT COGL_FLOAT_TO_UINT COGL_MATERIAL COGL_OBJECT COGL_PATH COGL_PIPELINE COGL_PRIVATE clutter_group_add clutter_stage_add clutter_units_cm clutter_units_em clutter_units_em_for_font clutter_units_mm clutter_units_pixels clutter_units_pt
syn keyword clutterEnum ClutterActorFlags ClutterAlignAxis ClutterAllocationFlags ClutterAnimationMode ClutterBinAlignment ClutterBindCoordinate ClutterBoxAlignment ClutterCex100BufferingMode ClutterDragAxis ClutterEventFlags ClutterEventType ClutterFeatureFlags ClutterFlowOrientation ClutterFontFlags ClutterGravity ClutterInitError ClutterInputAxis ClutterInputDeviceType ClutterInputMode ClutterInterpolation ClutterModifierType ClutterPathNodeType ClutterPickMode ClutterRequestMode ClutterRotateAxis ClutterRotateDirection ClutterScriptError ClutterScrollDirection ClutterShaderError ClutterShaderType ClutterSnapEdge ClutterStageState ClutterStaticColor ClutterTableAlignment ClutterTextDirection ClutterTextureError ClutterTextureFlags ClutterTextureQuality ClutterTimelineDirection ClutterUnitType ClutterX11FilterReturn ClutterX11XInputEventTypes CoglAttributeNameID CoglAttributeType CoglBitmapError CoglBlendStringError CoglBufferAccess CoglBufferBit CoglBufferMapHint CoglBufferTarget CoglBufferUpdateHint CoglDepthTestFunction CoglDrawFlags CoglDriverError CoglError CoglFeatureFlags CoglFogMode CoglIndicesType CoglMaterialAlphaFunc CoglMaterialFilter CoglMaterialLayerType CoglMaterialWrapMode CoglPathFillRule CoglPipelineAlphaFunc CoglPipelineFilter CoglPipelineWrapMode CoglPixelFormat CoglReadPixelsFlags CoglShaderType CoglTextureFlags CoglVerticesMode
syn keyword clutterVariable clutter_major_version clutter_micro_version clutter_minor_version
syn keyword clutterUserFunction CallyActionCallback CallyActionFunc ClutterAlphaFunc ClutterBindingActionFunc ClutterCallback ClutterModelFilterFunc ClutterModelForeachFunc ClutterModelSortFunc ClutterPathCallback ClutterProgressFunc ClutterScriptConnectFunc ClutterX11FilterFunc CoglBitmaskForeachFunc CoglCallbackListFunc CoglFuncPtr CoglMaterialLayerCallback CoglPipelineLayerCallback CoglRectangleMapCallback CoglUserDataDestroyCallback
syn keyword clutterDefine CALLY_TYPE_ACTOR CALLY_TYPE_CLONE CALLY_TYPE_GROUP CALLY_TYPE_RECTANGLE CALLY_TYPE_ROOT CALLY_TYPE_STAGE CALLY_TYPE_TEXT CALLY_TYPE_TEXTURE CALLY_TYPE_UTIL CLUTTER_COGL CLUTTER_CURRENT_TIME CLUTTER_FLAVOUR CLUTTER_GLX_TYPE_TEXTURE_PIXMAP CLUTTER_INIT_ERROR CLUTTER_MAJOR_VERSION CLUTTER_MICRO_VERSION CLUTTER_MINOR_VERSION CLUTTER_NO_FPU CLUTTER_PATH_RELATIVE CLUTTER_PRIORITY_EVENTS CLUTTER_PRIORITY_REDRAW CLUTTER_SCRIPT_ERROR CLUTTER_SHADER_ERROR CLUTTER_STAGE_TYPE CLUTTER_TEXTURE_ERROR CLUTTER_TYPE_ACTION CLUTTER_TYPE_ACTOR CLUTTER_TYPE_ACTOR_BOX CLUTTER_TYPE_ACTOR_META CLUTTER_TYPE_ALIGN_CONSTRAINT CLUTTER_TYPE_ALPHA CLUTTER_TYPE_ANIMATABLE CLUTTER_TYPE_ANIMATION CLUTTER_TYPE_ANIMATOR CLUTTER_TYPE_ANIMATOR_KEY CLUTTER_TYPE_BACKEND CLUTTER_TYPE_BINDING_POOL CLUTTER_TYPE_BIND_CONSTRAINT CLUTTER_TYPE_BIN_LAYOUT CLUTTER_TYPE_BLUR_EFFECT CLUTTER_TYPE_BOX CLUTTER_TYPE_BOX_LAYOUT CLUTTER_TYPE_CAIRO_TEXTURE CLUTTER_TYPE_CHILD_META CLUTTER_TYPE_CLICK_ACTION CLUTTER_TYPE_CLONE CLUTTER_TYPE_COLOR CLUTTER_TYPE_COLORIZE_EFFECT CLUTTER_TYPE_CONSTRAINT CLUTTER_TYPE_CONTAINER CLUTTER_TYPE_DEFORM_EFFECT CLUTTER_TYPE_DESATURATE_EFFECT CLUTTER_TYPE_DEVICE_MANAGER CLUTTER_TYPE_DRAG_ACTION CLUTTER_TYPE_EFFECT CLUTTER_TYPE_EVENT CLUTTER_TYPE_FIXED_LAYOUT CLUTTER_TYPE_FLOW_LAYOUT CLUTTER_TYPE_FOG CLUTTER_TYPE_GEOMETRY CLUTTER_TYPE_GROUP CLUTTER_TYPE_INPUT_DEVICE CLUTTER_TYPE_INTERVAL CLUTTER_TYPE_KNOT CLUTTER_TYPE_LAYOUT_MANAGER CLUTTER_TYPE_LAYOUT_META CLUTTER_TYPE_LIST_MODEL CLUTTER_TYPE_MEDIA CLUTTER_TYPE_MODEL CLUTTER_TYPE_MODEL_ITER CLUTTER_TYPE_OFFSCREEN_EFFECT CLUTTER_TYPE_PAGE_TURN_EFFECT CLUTTER_TYPE_PAINT_VOLUME CLUTTER_TYPE_PARAM_COLOR CLUTTER_TYPE_PARAM_FIXED CLUTTER_TYPE_PARAM_UNITS CLUTTER_TYPE_PATH CLUTTER_TYPE_PATH_CONSTRAINT CLUTTER_TYPE_PATH_NODE CLUTTER_TYPE_PERSPECTIVE CLUTTER_TYPE_RECTANGLE CLUTTER_TYPE_SCORE CLUTTER_TYPE_SCRIPT CLUTTER_TYPE_SCRIPTABLE CLUTTER_TYPE_SETTINGS CLUTTER_TYPE_SHADER CLUTTER_TYPE_SHADER_EFFECT CLUTTER_TYPE_SHADER_FLOAT CLUTTER_TYPE_SHADER_INT CLUTTER_TYPE_SHADER_MATRIX CLUTTER_TYPE_SNAP_CONSTRAINT CLUTTER_TYPE_STAGE CLUTTER_TYPE_STAGE_MANAGER CLUTTER_TYPE_STATE CLUTTER_TYPE_STATE_KEY CLUTTER_TYPE_TABLE_LAYOUT CLUTTER_TYPE_TEXT CLUTTER_TYPE_TEXTURE CLUTTER_TYPE_TIMELINE CLUTTER_TYPE_UNITS CLUTTER_TYPE_VERTEX CLUTTER_VERSION CLUTTER_VERSION_HEX CLUTTER_VERSION_S CLUTTER_X11_TYPE_TEXTURE_PIXMAP COGL_AFIRST_BIT COGL_A_BIT COGL_BGR_BIT COGL_BITMAP_ERROR COGL_BITMASK_MAX_DIRECT_BITS COGL_BLEND_STRING_ERROR COGL_DRIVER_ERROR COGL_ENABLE_EXPERIMENTAL_API COGL_ERROR COGL_FIXED_0_5 COGL_FIXED_1 COGL_FIXED_120 COGL_FIXED_180 COGL_FIXED_240 COGL_FIXED_255 COGL_FIXED_270 COGL_FIXED_2_PI COGL_FIXED_30 COGL_FIXED_360 COGL_FIXED_45 COGL_FIXED_60 COGL_FIXED_90 COGL_FIXED_BITS COGL_FIXED_EPSILON COGL_FIXED_MAX COGL_FIXED_MIN COGL_FIXED_PI COGL_FIXED_PI_2 COGL_FIXED_PI_4 COGL_FIXED_Q COGL_GTYPE_TYPE_MATRIX COGL_INVALID_HANDLE COGL_PIXEL_FORMAT_24 COGL_PIXEL_FORMAT_32 COGL_PREMULT_BIT COGL_RADIANS_TO_DEGREES COGL_TEXTURE_MAX_WASTE COGL_TYPE_ATTRIBUTE_TYPE COGL_TYPE_BITMAP_ERROR COGL_TYPE_BLEND_STRING_ERROR COGL_TYPE_BUFFER_ACCESS COGL_TYPE_BUFFER_BIT COGL_TYPE_BUFFER_MAP_HINT COGL_TYPE_BUFFER_TARGET COGL_TYPE_BUFFER_UPDATE_HINT COGL_TYPE_DEPTH_TEST_FUNCTION COGL_TYPE_DRIVER_ERROR COGL_TYPE_ERROR COGL_TYPE_FEATURE_FLAGS COGL_TYPE_FIXED COGL_TYPE_FOG_MODE COGL_TYPE_HANDLE COGL_TYPE_INDICES_TYPE COGL_TYPE_MATERIAL_ALPHA_FUNC COGL_TYPE_MATERIAL_FILTER COGL_TYPE_MATERIAL_LAYER_TYPE COGL_TYPE_MATERIAL_WRAP_MODE COGL_TYPE_PATH_FILL_RULE COGL_TYPE_PIPELINE_ALPHA_FUNC COGL_TYPE_PIPELINE_FILTER COGL_TYPE_PIPELINE_WRAP_MODE COGL_TYPE_PIXEL_FORMAT COGL_TYPE_READ_PIXELS_FLAGS COGL_TYPE_SHADER_TYPE COGL_TYPE_TEXTURE_FLAGS COGL_TYPE_VERTICES_MODE COGL_UNORDERED_MASK COGL_UNPREMULT_MASK cogl_buffer_get_usage_hint cogl_buffer_set_usage_hint cogl_pixel_array_new
syn keyword clutterDeprecatedFunction clutter_backend_get_double_click_distance clutter_backend_get_double_click_time clutter_backend_get_font_name clutter_backend_set_double_click_distance clutter_backend_set_double_click_time clutter_backend_set_font_name clutter_backend_set_resolution clutter_behaviour_actors_foreach clutter_behaviour_apply clutter_behaviour_depth_get_bounds clutter_behaviour_depth_get_type clutter_behaviour_depth_new clutter_behaviour_depth_set_bounds clutter_behaviour_ellipse_get_angle_end clutter_behaviour_ellipse_get_angle_start clutter_behaviour_ellipse_get_angle_tilt clutter_behaviour_ellipse_get_center clutter_behaviour_ellipse_get_direction clutter_behaviour_ellipse_get_height clutter_behaviour_ellipse_get_tilt clutter_behaviour_ellipse_get_type clutter_behaviour_ellipse_get_width clutter_behaviour_ellipse_new clutter_behaviour_ellipse_set_angle_end clutter_behaviour_ellipse_set_angle_start clutter_behaviour_ellipse_set_angle_tilt clutter_behaviour_ellipse_set_center clutter_behaviour_ellipse_set_direction clutter_behaviour_ellipse_set_height clutter_behaviour_ellipse_set_tilt clutter_behaviour_ellipse_set_width clutter_behaviour_get_actors clutter_behaviour_get_alpha clutter_behaviour_get_n_actors clutter_behaviour_get_nth_actor clutter_behaviour_get_type clutter_behaviour_is_applied clutter_behaviour_opacity_get_bounds clutter_behaviour_opacity_get_type clutter_behaviour_opacity_new clutter_behaviour_opacity_set_bounds clutter_behaviour_path_get_path clutter_behaviour_path_get_type clutter_behaviour_path_new clutter_behaviour_path_new_with_description clutter_behaviour_path_new_with_knots clutter_behaviour_path_set_path clutter_behaviour_remove clutter_behaviour_remove_all clutter_behaviour_rotate_get_axis clutter_behaviour_rotate_get_bounds clutter_behaviour_rotate_get_center clutter_behaviour_rotate_get_direction clutter_behaviour_rotate_get_type clutter_behaviour_rotate_new clutter_behaviour_rotate_set_axis clutter_behaviour_rotate_set_bounds clutter_behaviour_rotate_set_center clutter_behaviour_rotate_set_direction clutter_behaviour_scale_get_bounds clutter_behaviour_scale_get_type clutter_behaviour_scale_new clutter_behaviour_scale_set_bounds clutter_behaviour_set_alpha clutter_egl_display clutter_eglx_display clutter_frame_source_add clutter_frame_source_add_full clutter_stage_manager_set_default_stage clutter_threads_add_frame_source clutter_threads_add_frame_source_full clutter_timeout_pool_add clutter_timeout_pool_new clutter_timeout_pool_remove clutter_util_next_p2 clutter_x11_get_input_devices clutter_x11_get_stage_visual cogl_check_extension cogl_clip_ensure cogl_clip_push cogl_clip_push_window_rect cogl_clip_stack_restore cogl_clip_stack_save cogl_material_ref cogl_material_unref cogl_offscreen_ref cogl_offscreen_unref cogl_pop_draw_buffer cogl_program_uniform_1f cogl_program_uniform_1i cogl_program_uniform_float cogl_program_uniform_int cogl_program_uniform_matrix cogl_push_draw_buffer cogl_set_draw_buffer cogl_shader_ref cogl_shader_unref cogl_texture_ref cogl_texture_unref cogl_vertex_buffer_ref cogl_vertex_buffer_unref cogl_viewport
syn keyword clutterDeprecatedStruct ClutterBehaviour ClutterBehaviourClass ClutterBehaviourDepth ClutterBehaviourDepthClass ClutterBehaviourDepthPrivate ClutterBehaviourEllipse ClutterBehaviourEllipseClass ClutterBehaviourEllipsePrivate ClutterBehaviourOpacity ClutterBehaviourOpacityClass ClutterBehaviourOpacityPrivate ClutterBehaviourPath ClutterBehaviourPathClass ClutterBehaviourPathPrivate ClutterBehaviourPrivate ClutterBehaviourRotate ClutterBehaviourRotateClass ClutterBehaviourRotatePrivate ClutterBehaviourScale ClutterBehaviourScaleClass ClutterBehaviourScalePrivate ClutterTimeoutPool
syn keyword clutterDeprecatedMacro CLUTTER_BEHAVIOUR CLUTTER_BEHAVIOUR_CLASS CLUTTER_BEHAVIOUR_DEPTH CLUTTER_BEHAVIOUR_DEPTH_CLASS CLUTTER_BEHAVIOUR_DEPTH_GET_CLASS CLUTTER_BEHAVIOUR_ELLIPSE CLUTTER_BEHAVIOUR_ELLIPSE_CLASS CLUTTER_BEHAVIOUR_ELLIPSE_GET_CLASS CLUTTER_BEHAVIOUR_GET_CLASS CLUTTER_BEHAVIOUR_OPACITY CLUTTER_BEHAVIOUR_OPACITY_CLASS CLUTTER_BEHAVIOUR_OPACITY_GET_CLASS CLUTTER_BEHAVIOUR_PATH CLUTTER_BEHAVIOUR_PATH_CLASS CLUTTER_BEHAVIOUR_PATH_GET_CLASS CLUTTER_BEHAVIOUR_ROTATE CLUTTER_BEHAVIOUR_ROTATE_CLASS CLUTTER_BEHAVIOUR_ROTATE_GET_CLASS CLUTTER_BEHAVIOUR_SCALE CLUTTER_BEHAVIOUR_SCALE_CLASS CLUTTER_BEHAVIOUR_SCALE_GET_CLASS CLUTTER_IS_BEHAVIOUR CLUTTER_IS_BEHAVIOUR_CLASS CLUTTER_IS_BEHAVIOUR_DEPTH CLUTTER_IS_BEHAVIOUR_DEPTH_CLASS CLUTTER_IS_BEHAVIOUR_ELLIPSE CLUTTER_IS_BEHAVIOUR_ELLIPSE_CLASS CLUTTER_IS_BEHAVIOUR_OPACITY CLUTTER_IS_BEHAVIOUR_OPACITY_CLASS CLUTTER_IS_BEHAVIOUR_PATH CLUTTER_IS_BEHAVIOUR_PATH_CLASS CLUTTER_IS_BEHAVIOUR_ROTATE CLUTTER_IS_BEHAVIOUR_ROTATE_CLASS CLUTTER_IS_BEHAVIOUR_SCALE CLUTTER_IS_BEHAVIOUR_SCALE_CLASS CLUTTER_STAGE_HEIGHT CLUTTER_STAGE_WIDTH
syn keyword clutterDeprecatedUserFunction ClutterBehaviourForeachFunc
syn keyword clutterDeprecatedDefine CLUTTER_TYPE_BEHAVIOUR CLUTTER_TYPE_BEHAVIOUR_DEPTH CLUTTER_TYPE_BEHAVIOUR_ELLIPSE CLUTTER_TYPE_BEHAVIOUR_OPACITY CLUTTER_TYPE_BEHAVIOUR_PATH CLUTTER_TYPE_BEHAVIOUR_ROTATE CLUTTER_TYPE_BEHAVIOUR_SCALE

" Default highlighting
if version >= 508 || !exists("did_clutter_syntax_inits")
  if version < 508
    let did_clutter_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink clutterFunction Function
  HiLink clutterTypedef Type
  HiLink clutterConstant Constant
  HiLink clutterStruct Type
  HiLink clutterUnion Type
  HiLink clutterMacro Macro
  HiLink clutterEnum Type
  HiLink clutterVariable Identifier
  HiLink clutterUserFunction Type
  HiLink clutterDefine Constant
  if exists("clutter_deprecated_errors")
    HiLink clutterDeprecatedFunction Error
    HiLink clutterDeprecatedMacro Error
    HiLink clutterDeprecatedDefine Error
    HiLink clutterDeprecatedStruct Error
    HiLink clutterDeprecatedUserFunction Error
  elseif exists("clutter_enable_deprecated")
    HiLink clutterDeprecatedFunction Function
    HiLink clutterDeprecatedMacro Macro
    HiLink clutterDeprecatedDefine Constant
    HiLink clutterDeprecatedStruct Type
    HiLink clutterDeprecatedUserFunction Type
  endif

  delcommand HiLink
endif

