" Vim syntax file
" Language: C ORBit2 extension (for version 2.14.19)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py

syn keyword orbit2Function CORBA_any__freekids CORBA_free ORBit_alloc_by_tc ORBit_alloc_get_tcval ORBit_alloc_simple ORBit_alloc_string ORBit_alloc_tcval ORBit_alloc_with_free_fn ORBit_connection_set_max_buffer ORBit_free ORBit_free_T ORBit_freekids_via_TypeCode ORBit_get_safe_tmp ORBit_realloc_tcval ORBit_sequence_alloc ORBit_sequence_append ORBit_sequence_concat ORBit_sequence_remove ORBit_sequence_set_size ORBit_small_alloc ORBit_small_allocbuf ORBit_small_connection_unref ORBit_small_demarshal_async ORBit_small_freekids ORBit_small_get_connection ORBit_small_get_connection_ref ORBit_small_get_connection_status ORBit_small_get_iinterface ORBit_small_get_iinterfaces ORBit_small_get_servant ORBit_small_get_type_id ORBit_small_get_types ORBit_small_invoke_adaptor ORBit_small_invoke_async ORBit_small_invoke_stub ORBit_small_invoke_stub_n ORBit_small_listen_for_broken ORBit_small_load_typelib ORBit_small_unlisten_for_broken ORBit_small_unlisten_for_broken_full ORBit_trace_any ORBit_trace_end_method ORBit_trace_header ORBit_trace_objref ORBit_trace_profiles ORBit_trace_timestamp ORBit_trace_typecode ORBit_trace_value
syn keyword orbit2Constant ORBIT_CONNECTION_CONNECTED ORBIT_CONNECTION_CONNECTING ORBIT_CONNECTION_DISCONNECTED ORBIT_CONNECTION_IN_PROC ORBIT_DEBUG_ERRORS ORBIT_DEBUG_FORCE_THREADED ORBIT_DEBUG_GIOP ORBIT_DEBUG_INPROC_TRACES ORBIT_DEBUG_MESSAGES ORBIT_DEBUG_NONE ORBIT_DEBUG_OBJECTS ORBIT_DEBUG_REFS ORBIT_DEBUG_TIMINGS ORBIT_DEBUG_TRACES ORBIT_DEBUG_TYPES ORBIT_MEMHOW_FREEFNC ORBIT_MEMHOW_NONE ORBIT_MEMHOW_SIMPLE ORBIT_MEMHOW_TYPECODE
syn keyword orbit2Struct ORBitAsyncQueueEntry ORBitConnection ORBit_IModule ORBit_MemPrefix
syn keyword orbit2Macro CORBA_sequence_get_release CORBA_sequence_set_release MEMINFO_TO_PTR ORBIT_MEMHOW_ELEMENTS ORBIT_MEMHOW_HOW ORBIT_MEMHOW_MAKE ORBit_sequence_index PTR_TO_MEMINFO dprintf dump_arg tprintf tprintf_end_method tprintf_header tprintf_timestamp tprintf_trace_value
syn keyword orbit2Enum ORBitConnectionStatus ORBitMemHow OrbitDebugFlags
syn keyword orbit2Variable ORBit_small_flags
syn keyword orbit2UserFunction ORBitAsyncInvokeFunc ORBit_Mem_free_fn
syn keyword orbit2Define ERRORS GIOP MESSAGES OBJECTS ORBIT_SMALL_FAST_LOCALS ORBIT_SMALL_FORCE_GENERIC_MARSHAL TYPES

" Default highlighting
if version >= 508 || !exists("did_orbit2_syntax_inits")
  if version < 508
    let did_orbit2_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink orbit2Function Function
  HiLink orbit2Constant Constant
  HiLink orbit2Struct Type
  HiLink orbit2Macro Macro
  HiLink orbit2Enum Type
  HiLink orbit2Variable Identifier
  HiLink orbit2UserFunction Type
  HiLink orbit2Define Constant

  delcommand HiLink
endif

