" Vim syntax file
" Language: C dbus-glib extension (for version 0.92)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py

syn keyword dbusglibFunction dbus_binding_tool_error_quark dbus_binding_tool_output_glib_client dbus_binding_tool_output_glib_server dbus_connection_get_g_connection dbus_connection_get_g_type dbus_connection_setup_with_g_main dbus_g_bus_get dbus_g_bus_get_private dbus_g_connection_flush dbus_g_connection_get_connection dbus_g_connection_get_g_type dbus_g_connection_lookup_g_object dbus_g_connection_open dbus_g_connection_ref dbus_g_connection_register_g_object dbus_g_connection_unref dbus_g_connection_unregister_g_object dbus_g_error_domain_register dbus_g_error_get_name dbus_g_error_has_name dbus_g_error_quark dbus_g_message_get_g_type dbus_g_message_get_message dbus_g_message_ref dbus_g_message_unref dbus_g_method_get_reply dbus_g_method_get_sender dbus_g_method_return dbus_g_method_return_error dbus_g_method_send_reply dbus_g_object_path_get_g_type dbus_g_object_register_marshaller dbus_g_object_register_marshaller_array dbus_g_object_type_install_info dbus_g_object_type_register_shadow_property dbus_g_proxy_add_signal dbus_g_proxy_begin_call dbus_g_proxy_begin_call_with_timeout dbus_g_proxy_call dbus_g_proxy_call_no_reply dbus_g_proxy_call_with_timeout dbus_g_proxy_cancel_call dbus_g_proxy_connect_signal dbus_g_proxy_disconnect_signal dbus_g_proxy_end_call dbus_g_proxy_get_bus_name dbus_g_proxy_get_interface dbus_g_proxy_get_path dbus_g_proxy_get_type dbus_g_proxy_new_for_name dbus_g_proxy_new_for_name_owner dbus_g_proxy_new_for_peer dbus_g_proxy_new_from_proxy dbus_g_proxy_send dbus_g_proxy_set_default_timeout dbus_g_proxy_set_interface dbus_g_signature_get_g_type dbus_g_thread_init dbus_g_type_collection_get_fixed dbus_g_type_collection_peek_vtable dbus_g_type_collection_value_iterate dbus_g_type_get_collection dbus_g_type_get_collection_specialization dbus_g_type_get_map dbus_g_type_get_map_key_specialization dbus_g_type_get_map_value_specialization dbus_g_type_get_struct dbus_g_type_get_struct_member_type dbus_g_type_get_struct_size dbus_g_type_get_structv dbus_g_type_is_collection dbus_g_type_is_map dbus_g_type_is_struct dbus_g_type_map_peek_vtable dbus_g_type_map_value_iterate dbus_g_type_register_collection dbus_g_type_register_map dbus_g_type_register_struct dbus_g_type_specialized_collection_append dbus_g_type_specialized_collection_end_append dbus_g_type_specialized_construct dbus_g_type_specialized_init dbus_g_type_specialized_init_append dbus_g_type_specialized_map_append dbus_g_type_struct_get dbus_g_type_struct_get_member dbus_g_type_struct_peek_vtable dbus_g_type_struct_set dbus_g_type_struct_set_member dbus_g_value_build_g_variant dbus_g_value_parse_g_variant dbus_glib_global_set_disable_legacy_property_access dbus_glib_internal_do_not_use_run_tests dbus_glib_marshal_sm_object_BOOLEAN__POINTER dbus_glib_marshal_sm_object_BOOLEAN__POINTER_POINTER dbus_glib_marshal_sm_object_BOOLEAN__POINTER_POINTER_POINTER dbus_glib_marshal_sm_server_BOOLEAN__POINTER_POINTER dbus_glib_marshal_sm_server_BOOLEAN__STRING_POINTER dbus_glib_marshal_some_object_BOOLEAN__POINTER_POINTER dbus_glib_marshal_some_object_BOOLEAN__STRING_POINTER_POINTER dbus_glib_marshal_test_object_BOOLEAN__POINTER dbus_message_get_g_type dbus_pending_call_get_g_type dbus_server_setup_with_g_main dbus_set_g_error sm_error_get_type sm_error_quark sm_marshal_VOID__STRING_BOXED sm_object_get_acquiring_progress sm_object_get_info sm_object_get_type sm_object_reacquire sm_object_reinitialize sm_object_shutdown sm_object_start sm_object_state_get_type sm_server_create_machine sm_server_get_machines sm_server_get_type
syn keyword dbusglibTypedef DBusGObjectPath DBusGSignature SMObject SMObjectClass SMServer SMServerClass
syn keyword dbusglibConstant DBUS_BINDING_TOOL_ERROR_INVALID_ANNOTATION DBUS_BINDING_TOOL_ERROR_UNSUPPORTED_CONVERSION SM_ERROR_INVALID_STATE SM_ERROR_NAME_IN_USE SM_NUM_ERRORS SM_OBJECT_NUM_STATES SM_OBJECT_STATE_ACQUIRED SM_OBJECT_STATE_INITIALIZED SM_OBJECT_STATE_OPERATING SM_OBJECT_STATE_SHUTDOWN
syn keyword dbusglibStruct DBusGAsyncData DBusGConnection DBusGMessage DBusGMethodInfo DBusGMethodInvocation DBusGObjectInfo DBusGProxy DBusGProxyCall DBusGProxyClass DBusGTypeSpecializedAppendContext DBusGTypeSpecializedCollectionVtable DBusGTypeSpecializedMapVtable DBusGTypeSpecializedStructVtable DBusGTypeSpecializedVtable
syn keyword dbusglibMacro DBUS_G_PROXY DBUS_G_PROXY_CLASS DBUS_G_PROXY_GET_CLASS DBUS_IS_G_PROXY DBUS_IS_G_PROXY_CLASS SM_IS_OBJECT SM_IS_OBJECT_CLASS SM_IS_SERVER SM_IS_SERVER_CLASS SM_OBJECT SM_OBJECT_CLASS SM_OBJECT_GET_CLASS SM_SERVER SM_SERVER_CLASS SM_SERVER_GET_CLASS g_marshal_value_peek_boolean g_marshal_value_peek_boxed g_marshal_value_peek_char g_marshal_value_peek_double g_marshal_value_peek_enum g_marshal_value_peek_flags g_marshal_value_peek_float g_marshal_value_peek_int g_marshal_value_peek_int64 g_marshal_value_peek_long g_marshal_value_peek_object g_marshal_value_peek_param g_marshal_value_peek_pointer g_marshal_value_peek_string g_marshal_value_peek_uchar g_marshal_value_peek_uint g_marshal_value_peek_uint64 g_marshal_value_peek_ulong g_marshal_value_peek_variant
syn keyword dbusglibEnum DBusBindingToolError DBusGError SMError SMObjectState
syn keyword dbusglibUserFunction DBusGProxyCallNotify DBusGTypeSpecializedCollectionAppendFunc DBusGTypeSpecializedCollectionEndAppendFunc DBusGTypeSpecializedCollectionFixedAccessorFunc DBusGTypeSpecializedCollectionIterator DBusGTypeSpecializedCollectionIteratorFunc DBusGTypeSpecializedConstructor DBusGTypeSpecializedCopyFunc DBusGTypeSpecializedFreeFunc DBusGTypeSpecializedMapAppendFunc DBusGTypeSpecializedMapIterator DBusGTypeSpecializedMapIteratorFunc DBusGTypeSpecializedStructGetMember DBusGTypeSpecializedStructSetMember
syn keyword dbusglibDefine DBUS_BINDING_TOOL_ERROR DBUS_GERROR DBUS_GLIB_ANNOTATION_ASYNC DBUS_GLIB_ANNOTATION_CLIENT_C_SYMBOL DBUS_GLIB_ANNOTATION_CONST DBUS_GLIB_ANNOTATION_C_SYMBOL DBUS_GLIB_ANNOTATION_NOREPLY DBUS_GLIB_ANNOTATION_RETURNVAL DBUS_INSIDE_DBUS_GLIB_H DBUS_TYPE_CONNECTION DBUS_TYPE_G_BOOLEAN_ARRAY DBUS_TYPE_G_CONNECTION DBUS_TYPE_G_INT64_ARRAY DBUS_TYPE_G_INT_ARRAY DBUS_TYPE_G_MESSAGE DBUS_TYPE_G_OBJECT_ARRAY DBUS_TYPE_G_OBJECT_PATH DBUS_TYPE_G_PROXY DBUS_TYPE_G_SIGNATURE DBUS_TYPE_G_STRING_STRING_HASHTABLE DBUS_TYPE_G_UCHAR_ARRAY DBUS_TYPE_G_UINT64_ARRAY DBUS_TYPE_G_UINT_ARRAY DBUS_TYPE_MESSAGE DBUS_TYPE_PENDING_CALL SM_ERROR SM_TYPE_ERROR SM_TYPE_OBJECT SM_TYPE_OBJECT_STATE SM_TYPE_SERVER

" Default highlighting
if version >= 508 || !exists("did_dbusglib_syntax_inits")
  if version < 508
    let did_dbusglib_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink dbusglibFunction Function
  HiLink dbusglibTypedef Type
  HiLink dbusglibConstant Constant
  HiLink dbusglibStruct Type
  HiLink dbusglibMacro Macro
  HiLink dbusglibEnum Type
  HiLink dbusglibUserFunction Type
  HiLink dbusglibDefine Constant

  delcommand HiLink
endif

