" Vim syntax file
" Language: C json-glib extension (for version 0.12.2)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let jsonglib_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let jsonglib_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword jsonglibFunction json_array_add_array_element json_array_add_boolean_element json_array_add_double_element json_array_add_element json_array_add_int_element json_array_add_null_element json_array_add_object_element json_array_add_string_element json_array_dup_element json_array_foreach_element json_array_get_array_element json_array_get_boolean_element json_array_get_double_element json_array_get_element json_array_get_elements json_array_get_int_element json_array_get_length json_array_get_null_element json_array_get_object_element json_array_get_string_element json_array_get_type json_array_new json_array_ref json_array_remove_element json_array_sized_new json_array_unref json_boxed_can_deserialize json_boxed_can_serialize json_boxed_deserialize json_boxed_register_deserialize_func json_boxed_register_serialize_func json_boxed_serialize json_builder_add_boolean_value json_builder_add_double_value json_builder_add_int_value json_builder_add_null_value json_builder_add_string_value json_builder_add_value json_builder_begin_array json_builder_begin_object json_builder_end_array json_builder_end_object json_builder_get_root json_builder_get_type json_builder_new json_builder_reset json_builder_set_member_name json_generator_get_type json_generator_new json_generator_set_root json_generator_to_data json_generator_to_file json_generator_to_stream json_gobject_deserialize json_gobject_from_data json_gobject_serialize json_gobject_to_data json_node_copy json_node_dup_array json_node_dup_object json_node_dup_string json_node_free json_node_get_array json_node_get_boolean json_node_get_double json_node_get_int json_node_get_node_type json_node_get_object json_node_get_parent json_node_get_string json_node_get_type json_node_get_value json_node_get_value_type json_node_is_null json_node_new json_node_set_array json_node_set_boolean json_node_set_double json_node_set_int json_node_set_object json_node_set_parent json_node_set_string json_node_set_value json_node_take_array json_node_take_object json_node_type_name json_object_dup_member json_object_foreach_member json_object_get_array_member json_object_get_boolean_member json_object_get_double_member json_object_get_int_member json_object_get_member json_object_get_members json_object_get_null_member json_object_get_object_member json_object_get_size json_object_get_string_member json_object_get_type json_object_get_values json_object_has_member json_object_new json_object_ref json_object_remove_member json_object_set_array_member json_object_set_boolean_member json_object_set_double_member json_object_set_int_member json_object_set_member json_object_set_null_member json_object_set_object_member json_object_set_string_member json_object_unref json_parser_error_quark json_parser_get_current_line json_parser_get_current_pos json_parser_get_root json_parser_get_type json_parser_has_assignment json_parser_load_from_data json_parser_load_from_file json_parser_load_from_stream json_parser_load_from_stream_async json_parser_load_from_stream_finish json_parser_new json_reader_count_elements json_reader_count_members json_reader_end_element json_reader_end_member json_reader_error_quark json_reader_get_boolean_value json_reader_get_double_value json_reader_get_error json_reader_get_int_value json_reader_get_null_value json_reader_get_string_value json_reader_get_type json_reader_get_value json_reader_is_array json_reader_is_object json_reader_is_value json_reader_new json_reader_read_element json_reader_read_member json_reader_set_root json_serializable_default_deserialize_property json_serializable_default_serialize_property json_serializable_deserialize_property json_serializable_get_type json_serializable_serialize_property
syn keyword jsonglibConstant JSON_NODE_ARRAY JSON_NODE_NULL JSON_NODE_OBJECT JSON_NODE_VALUE JSON_PARSER_ERROR_INVALID_BAREWORD JSON_PARSER_ERROR_MISSING_COLON JSON_PARSER_ERROR_MISSING_COMMA JSON_PARSER_ERROR_PARSE JSON_PARSER_ERROR_TRAILING_COMMA JSON_PARSER_ERROR_UNKNOWN JSON_READER_ERROR_INVALID_INDEX JSON_READER_ERROR_INVALID_MEMBER JSON_READER_ERROR_NO_ARRAY JSON_READER_ERROR_NO_OBJECT
syn keyword jsonglibStruct JsonArray JsonBuilder JsonBuilderClass JsonBuilderPrivate JsonGenerator JsonGeneratorClass JsonGeneratorPrivate JsonNode JsonObject JsonParser JsonParserClass JsonParserPrivate JsonReader JsonReaderClass JsonReaderPrivate JsonSerializable JsonSerializableIface
syn keyword jsonglibMacro JSON_BUILDER JSON_BUILDER_CLASS JSON_BUILDER_GET_CLASS JSON_CHECK_VERSION JSON_GENERATOR JSON_GENERATOR_CLASS JSON_GENERATOR_GET_CLASS JSON_IS_BUILDER JSON_IS_BUILDER_CLASS JSON_IS_GENERATOR JSON_IS_GENERATOR_CLASS JSON_IS_PARSER JSON_IS_PARSER_CLASS JSON_IS_READER JSON_IS_READER_CLASS JSON_IS_SERIALIZABLE JSON_NODE_HOLDS JSON_NODE_HOLDS_ARRAY JSON_NODE_HOLDS_NULL JSON_NODE_HOLDS_OBJECT JSON_NODE_HOLDS_VALUE JSON_NODE_TYPE JSON_PARSER JSON_PARSER_CLASS JSON_PARSER_GET_CLASS JSON_READER JSON_READER_CLASS JSON_READER_GET_CLASS JSON_SERIALIZABLE JSON_SERIALIZABLE_GET_IFACE
syn keyword jsonglibEnum JsonNodeType JsonParserError JsonReaderError
syn keyword jsonglibUserFunction JsonArrayForeach JsonBoxedDeserializeFunc JsonBoxedSerializeFunc JsonObjectForeach
syn keyword jsonglibDefine JSON_MAJOR_VERSION JSON_MICRO_VERSION JSON_MINOR_VERSION JSON_PARSER_ERROR JSON_READER_ERROR JSON_TYPE_ARRAY JSON_TYPE_BUILDER JSON_TYPE_GENERATOR JSON_TYPE_NODE JSON_TYPE_OBJECT JSON_TYPE_PARSER JSON_TYPE_READER JSON_TYPE_SERIALIZABLE JSON_VERSION JSON_VERSION_HEX JSON_VERSION_S
syn keyword jsonglibDeprecatedFunction json_construct_gobject json_object_add_member json_serialize_gobject

" Default highlighting
if version >= 508 || !exists("did_jsonglib_syntax_inits")
  if version < 508
    let did_jsonglib_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink jsonglibFunction Function
  HiLink jsonglibConstant Constant
  HiLink jsonglibStruct Type
  HiLink jsonglibMacro Macro
  HiLink jsonglibEnum Type
  HiLink jsonglibUserFunction Type
  HiLink jsonglibDefine Constant
  if exists("jsonglib_deprecated_errors")
    HiLink jsonglibDeprecatedFunction Error
  elseif exists("jsonglib_enable_deprecated")
    HiLink jsonglibDeprecatedFunction Function
  endif

  delcommand HiLink
endif

