" Vim syntax file
" Language:	C Xlib
" Maintainer:	krisna
" Last change:	2003-01-05

" x extentions
syn keyword xType		XID Mask Atom VisualID Time
syn keyword xType		Window Drawable Font Pixmap Cursor Colormap
syn keyword xType		GContext KeySym KeyCode
syn keyword xType		Bool Status

" X.h
syn keyword xConstant		X_H
syn keyword xConstant		X_PROTOCOL
syn keyword xConstant		X_PROTOCOL_REVISION
syn keyword xConstant		None
syn keyword xConstant		ParentRelative
syn keyword xConstant		CopyFromParent
syn keyword xConstant		PointerWindow
syn keyword xConstant		InputFocus
syn keyword xConstant		PointerRoot
syn keyword xConstant		AnyPropertyType
syn keyword xConstant		AnyKey
syn keyword xConstant		AnyButton
syn keyword xConstant		AllTemporary
syn keyword xConstant		CurrentTime
syn keyword xConstant		NoSymbol
syn keyword xConstant		NoEventMask
syn keyword xConstant		KeyPressMask
syn keyword xConstant		KeyReleaseMask
syn keyword xConstant		ButtonPressMask
syn keyword xConstant		ButtonReleaseMask
syn keyword xConstant		EnterWindowMask
syn keyword xConstant		LeaveWindowMask
syn keyword xConstant		PointerMotionMask
syn keyword xConstant		PointerMotionHintMask
syn keyword xConstant		Button1MotionMask
syn keyword xConstant		Button2MotionMask
syn keyword xConstant		Button3MotionMask
syn keyword xConstant		Button4MotionMask
syn keyword xConstant		Button5MotionMask
syn keyword xConstant		ButtonMotionMask
syn keyword xConstant		KeymapStateMask
syn keyword xConstant		ExposureMask
syn keyword xConstant		VisibilityChangeMask
syn keyword xConstant		StructureNotifyMask
syn keyword xConstant		ResizeRedirectMask
syn keyword xConstant		SubstructureNotifyMask
syn keyword xConstant		SubstructureRedirectMask
syn keyword xConstant		FocusChangeMask
syn keyword xConstant		PropertyChangeMask
syn keyword xConstant		ColormapChangeMask
syn keyword xConstant		OwnerGrabButtonMask
syn keyword xConstant		KeyPress
syn keyword xConstant		KeyRelease
syn keyword xConstant		ButtonPress
syn keyword xConstant		ButtonRelease
syn keyword xConstant		MotionNotify
syn keyword xConstant		EnterNotify
syn keyword xConstant		LeaveNotify
syn keyword xConstant		FocusIn
syn keyword xConstant		FocusOut
syn keyword xConstant		KeymapNotify
syn keyword xConstant		Expose
syn keyword xConstant		GraphicsExpose
syn keyword xConstant		NoExpose
syn keyword xConstant		VisibilityNotify
syn keyword xConstant		CreateNotify
syn keyword xConstant		DestroyNotify
syn keyword xConstant		UnmapNotify
syn keyword xConstant		MapNotify
syn keyword xConstant		MapRequest
syn keyword xConstant		ReparentNotify
syn keyword xConstant		ConfigureNotify
syn keyword xConstant		ConfigureRequest
syn keyword xConstant		GravityNotify
syn keyword xConstant		ResizeRequest
syn keyword xConstant		CirculateNotify
syn keyword xConstant		CirculateRequest
syn keyword xConstant		PropertyNotify
syn keyword xConstant		SelectionClear
syn keyword xConstant		SelectionRequest
syn keyword xConstant		SelectionNotify
syn keyword xConstant		ColormapNotify
syn keyword xConstant		ClientMessage
syn keyword xConstant		MappingNotify
syn keyword xConstant		LASTEvent
syn keyword xConstant		ShiftMask
syn keyword xConstant		LockMask
syn keyword xConstant		ControlMask
syn keyword xConstant		Mod1Mask
syn keyword xConstant		Mod2Mask
syn keyword xConstant		Mod3Mask
syn keyword xConstant		Mod4Mask
syn keyword xConstant		Mod5Mask
syn keyword xConstant		ShiftMapIndex
syn keyword xConstant		LockMapIndex
syn keyword xConstant		ControlMapIndex
syn keyword xConstant		Mod1MapIndex
syn keyword xConstant		Mod2MapIndex
syn keyword xConstant		Mod3MapIndex
syn keyword xConstant		Mod4MapIndex
syn keyword xConstant		Mod5MapIndex
syn keyword xConstant		Button1Mask
syn keyword xConstant		Button2Mask
syn keyword xConstant		Button3Mask
syn keyword xConstant		Button4Mask
syn keyword xConstant		Button5Mask
syn keyword xConstant		AnyModifier
syn keyword xConstant		Button1
syn keyword xConstant		Button2
syn keyword xConstant		Button3
syn keyword xConstant		Button4
syn keyword xConstant		Button5
syn keyword xConstant		NotifyNormal
syn keyword xConstant		NotifyGrab
syn keyword xConstant		NotifyUngrab
syn keyword xConstant		NotifyWhileGrabbed
syn keyword xConstant		NotifyHint
syn keyword xConstant		NotifyAncestor
syn keyword xConstant		NotifyVirtual
syn keyword xConstant		NotifyInferior
syn keyword xConstant		NotifyNonlinear
syn keyword xConstant		NotifyNonlinearVirtual
syn keyword xConstant		NotifyPointer
syn keyword xConstant		NotifyPointerRoot
syn keyword xConstant		NotifyDetailNone
syn keyword xConstant		VisibilityUnobscured
syn keyword xConstant		VisibilityPartiallyObscured
syn keyword xConstant		VisibilityFullyObscured
syn keyword xConstant		PlaceOnTop
syn keyword xConstant		PlaceOnBottom
syn keyword xConstant		FamilyInternet
syn keyword xConstant		FamilyDECnet
syn keyword xConstant		FamilyChaos
syn keyword xConstant		PropertyNewValue
syn keyword xConstant		PropertyDelete
syn keyword xConstant		ColormapUninstalled
syn keyword xConstant		ColormapInstalled
syn keyword xConstant		GrabModeSync
syn keyword xConstant		GrabModeAsync
syn keyword xConstant		GrabSuccess
syn keyword xConstant		AlreadyGrabbed
syn keyword xConstant		GrabInvalidTime
syn keyword xConstant		GrabNotViewable
syn keyword xConstant		GrabFrozen
syn keyword xConstant		AsyncPointer
syn keyword xConstant		SyncPointer
syn keyword xConstant		ReplayPointer
syn keyword xConstant		AsyncKeyboard
syn keyword xConstant		SyncKeyboard
syn keyword xConstant		ReplayKeyboard
syn keyword xConstant		AsyncBoth
syn keyword xConstant		SyncBoth
syn keyword xConstant		RevertToNone
syn keyword xConstant		RevertToPointerRoot
syn keyword xConstant		RevertToParent
syn keyword xConstant		Success
syn keyword xConstant		BadRequest
syn keyword xConstant		BadValue
syn keyword xConstant		BadWindow
syn keyword xConstant		BadPixmap
syn keyword xConstant		BadAtom
syn keyword xConstant		BadCursor
syn keyword xConstant		BadFont
syn keyword xConstant		BadMatch
syn keyword xConstant		BadDrawable
syn keyword xConstant		BadAccess
syn keyword xConstant		BadAlloc
syn keyword xConstant		BadColor
syn keyword xConstant		BadGC
syn keyword xConstant		BadIDChoice
syn keyword xConstant		BadName
syn keyword xConstant		BadLength
syn keyword xConstant		BadImplementation
syn keyword xConstant		FirstExtensionError
syn keyword xConstant		LastExtensionError
syn keyword xConstant		InputOutput
syn keyword xConstant		InputOnly
syn keyword xConstant		CWBackPixmap
syn keyword xConstant		CWBackPixel
syn keyword xConstant		CWBorderPixmap
syn keyword xConstant		CWBorderPixel
syn keyword xConstant		CWBitGravity
syn keyword xConstant		CWWinGravity
syn keyword xConstant		CWBackingStore
syn keyword xConstant		CWBackingPlanes
syn keyword xConstant		CWBackingPixel
syn keyword xConstant		CWOverrideRedirect
syn keyword xConstant		CWSaveUnder
syn keyword xConstant		CWEventMask
syn keyword xConstant		CWDontPropagate
syn keyword xConstant		CWColormap
syn keyword xConstant		CWCursor
syn keyword xConstant		CWX
syn keyword xConstant		CWY
syn keyword xConstant		CWWidth
syn keyword xConstant		CWHeight
syn keyword xConstant		CWBorderWidth
syn keyword xConstant		CWSibling
syn keyword xConstant		CWStackMode
syn keyword xConstant		ForgetGravity
syn keyword xConstant		NorthWestGravity
syn keyword xConstant		NorthGravity
syn keyword xConstant		NorthEastGravity
syn keyword xConstant		WestGravity
syn keyword xConstant		CenterGravity
syn keyword xConstant		EastGravity
syn keyword xConstant		SouthWestGravity
syn keyword xConstant		SouthGravity
syn keyword xConstant		SouthEastGravity
syn keyword xConstant		StaticGravity
syn keyword xConstant		UnmapGravity
syn keyword xConstant		NotUseful
syn keyword xConstant		WhenMapped
syn keyword xConstant		Always
syn keyword xConstant		IsUnmapped
syn keyword xConstant		IsUnviewable
syn keyword xConstant		IsViewable
syn keyword xConstant		SetModeInsert
syn keyword xConstant		SetModeDelete
syn keyword xConstant		DestroyAll
syn keyword xConstant		RetainPermanent
syn keyword xConstant		RetainTemporary
syn keyword xConstant		Above
syn keyword xConstant		Below
syn keyword xConstant		TopIf
syn keyword xConstant		BottomIf
syn keyword xConstant		Opposite
syn keyword xConstant		RaiseLowest
syn keyword xConstant		LowerHighest
syn keyword xConstant		PropModeReplace
syn keyword xConstant		PropModePrepend
syn keyword xConstant		PropModeAppend
syn keyword xConstant		GXclear
syn keyword xConstant		GXand
syn keyword xConstant		GXandReverse
syn keyword xConstant		GXcopy
syn keyword xConstant		GXandInverted
syn keyword xConstant		GXnoop
syn keyword xConstant		GXxor
syn keyword xConstant		GXor
syn keyword xConstant		GXnor
syn keyword xConstant		GXequiv
syn keyword xConstant		GXinvert
syn keyword xConstant		GXorReverse
syn keyword xConstant		GXcopyInverted
syn keyword xConstant		GXorInverted
syn keyword xConstant		GXnand
syn keyword xConstant		GXset
syn keyword xConstant		LineSolid
syn keyword xConstant		LineOnOffDash
syn keyword xConstant		LineDoubleDash
syn keyword xConstant		CapNotLast
syn keyword xConstant		CapButt
syn keyword xConstant		CapRound
syn keyword xConstant		CapProjecting
syn keyword xConstant		JoinMiter
syn keyword xConstant		JoinRound
syn keyword xConstant		JoinBevel
syn keyword xConstant		FillSolid
syn keyword xConstant		FillTiled
syn keyword xConstant		FillStippled
syn keyword xConstant		FillOpaqueStippled
syn keyword xConstant		EvenOddRule
syn keyword xConstant		WindingRule
syn keyword xConstant		ClipByChildren
syn keyword xConstant		IncludeInferiors
syn keyword xConstant		Unsorted
syn keyword xConstant		YSorted
syn keyword xConstant		YXSorted
syn keyword xConstant		YXBanded
syn keyword xConstant		CoordModeOrigin
syn keyword xConstant		CoordModePrevious
syn keyword xConstant		Complex
syn keyword xConstant		Nonconvex
syn keyword xConstant		Convex
syn keyword xConstant		ArcChord
syn keyword xConstant		ArcPieSlice
syn keyword xConstant		GCFunction
syn keyword xConstant		GCPlaneMask
syn keyword xConstant		GCForeground
syn keyword xConstant		GCBackground
syn keyword xConstant		GCLineWidth
syn keyword xConstant		GCLineStyle
syn keyword xConstant		GCCapStyle
syn keyword xConstant		GCJoinStyle
syn keyword xConstant		GCFillStyle
syn keyword xConstant		GCFillRule
syn keyword xConstant		GCTile
syn keyword xConstant		GCStipple
syn keyword xConstant		GCTileStipXOrigin
syn keyword xConstant		GCTileStipYOrigin
syn keyword xConstant		GCFont
syn keyword xConstant		GCSubwindowMode
syn keyword xConstant		GCGraphicsExposures
syn keyword xConstant		GCClipXOrigin
syn keyword xConstant		GCClipYOrigin
syn keyword xConstant		GCClipMask
syn keyword xConstant		GCDashOffset
syn keyword xConstant		GCDashList
syn keyword xConstant		GCArcMode
syn keyword xConstant		GCLastBit
syn keyword xConstant		FontLeftToRight
syn keyword xConstant		FontRightToLeft
syn keyword xConstant		FontChange
syn keyword xConstant		XYBitmap
syn keyword xConstant		XYPixmap
syn keyword xConstant		ZPixmap
syn keyword xConstant		AllocNone
syn keyword xConstant		AllocAll
syn keyword xConstant		DoRed
syn keyword xConstant		DoGreen
syn keyword xConstant		DoBlue
syn keyword xConstant		CursorShape
syn keyword xConstant		TileShape
syn keyword xConstant		StippleShape
syn keyword xConstant		AutoRepeatModeOff
syn keyword xConstant		AutoRepeatModeOn
syn keyword xConstant		AutoRepeatModeDefault
syn keyword xConstant		LedModeOff
syn keyword xConstant		LedModeOn
syn keyword xConstant		KBKeyClickPercent
syn keyword xConstant		KBBellPercent
syn keyword xConstant		KBBellPitch
syn keyword xConstant		KBBellDuration
syn keyword xConstant		KBLed
syn keyword xConstant		KBLedMode
syn keyword xConstant		KBKey
syn keyword xConstant		KBAutoRepeatMode
syn keyword xConstant		MappingSuccess
syn keyword xConstant		MappingBusy
syn keyword xConstant		MappingFailed
syn keyword xConstant		MappingModifier
syn keyword xConstant		MappingKeyboard
syn keyword xConstant		MappingPointer
syn keyword xConstant		DontPreferBlanking
syn keyword xConstant		PreferBlanking
syn keyword xConstant		DefaultBlanking
syn keyword xConstant		DisableScreenSaver
syn keyword xConstant		DisableScreenInterval
syn keyword xConstant		DontAllowExposures
syn keyword xConstant		AllowExposures
syn keyword xConstant		DefaultExposures
syn keyword xConstant		ScreenSaverReset
syn keyword xConstant		ScreenSaverActive
syn keyword xConstant		HostInsert
syn keyword xConstant		HostDelete
syn keyword xConstant		EnableAccess
syn keyword xConstant		DisableAccess
syn keyword xConstant		StaticGray
syn keyword xConstant		GrayScale
syn keyword xConstant		StaticColor
syn keyword xConstant		PseudoColor
syn keyword xConstant		TrueColor
syn keyword xConstant		DirectColor
syn keyword xConstant		LSBFirst
syn keyword xConstant		MSBFirst

" Xlib.h
syn keyword xBoolean		True False

syn keyword xConstant		XNRequiredCharSet
syn keyword xConstant		XNQueryOrientation
syn keyword xConstant		XNBaseFontName
syn keyword xConstant		XNOMAutomatic
syn keyword xConstant		XNMissingCharSet
syn keyword xConstant		XNDefaultString
syn keyword xConstant		XNOrientation
syn keyword xConstant		XNDirectionalDependentDrawing
syn keyword xConstant		XNContextualDrawing
syn keyword xConstant		XNFontInfo
syn keyword xConstant		XIMPreeditArea
syn keyword xConstant		XIMPreeditCallbacks
syn keyword xConstant		XIMPreeditPosition
syn keyword xConstant		XIMPreeditNothing
syn keyword xConstant		XIMPreeditNone
syn keyword xConstant		XIMStatusArea
syn keyword xConstant		XIMStatusCallbacks
syn keyword xConstant		XIMStatusNothing
syn keyword xConstant		XIMStatusNone
syn keyword xConstant		XNVaNestedList
syn keyword xConstant		XNQueryInputStyle
syn keyword xConstant		XNClientWindow
syn keyword xConstant		XNInputStyle
syn keyword xConstant		XNFocusWindow
syn keyword xConstant		XNResourceName
syn keyword xConstant		XNResourceClass
syn keyword xConstant		XNGeometryCallback
syn keyword xConstant		XNDestroyCallback
syn keyword xConstant		XNFilterEvents
syn keyword xConstant		XNPreeditStartCallback
syn keyword xConstant		XNPreeditDoneCallback
syn keyword xConstant		XNPreeditDrawCallback
syn keyword xConstant		XNPreeditCaretCallback
syn keyword xConstant		XNPreeditStateNotifyCallback
syn keyword xConstant		XNPreeditAttributes
syn keyword xConstant		XNStatusStartCallback
syn keyword xConstant		XNStatusDoneCallback
syn keyword xConstant		XNStatusDrawCallback
syn keyword xConstant		XNStatusAttributes
syn keyword xConstant		XNArea
syn keyword xConstant		XNAreaNeeded
syn keyword xConstant		XNSpotLocation
syn keyword xConstant		XNColormap
syn keyword xConstant		XNStdColormap
syn keyword xConstant		XNForeground
syn keyword xConstant		XNBackground
syn keyword xConstant		XNBackgroundPixmap
syn keyword xConstant		XNFontSet
syn keyword xConstant		XNLineSpace
syn keyword xConstant		XNCursor
syn keyword xConstant		XNQueryIMValuesList
syn keyword xConstant		XNQueryICValuesList
syn keyword xConstant		XNVisiblePosition
syn keyword xConstant		XNR6PreeditCallback
syn keyword xConstant		XNStringConversionCallback
syn keyword xConstant		XNStringConversion
syn keyword xConstant		XNResetState
syn keyword xConstant		XNHotKey
syn keyword xConstant		XNHotKeyState
syn keyword xConstant		XNPreeditState
syn keyword xConstant		XNSeparatorofNestedList
syn keyword xConstant		XBufferOverflow
syn keyword xConstant		XLookupNone
syn keyword xConstant		XLookupChars
syn keyword xConstant		XLookupKeySym
syn keyword xConstant		XLookupBoth
syn keyword xConstant		XIMReverse
syn keyword xConstant		XIMUnderline
syn keyword xConstant		XIMHighlight
syn keyword xConstant		XIMPrimary
syn keyword xConstant		XIMSecondary
syn keyword xConstant		XIMTertiary
syn keyword xConstant		XIMVisibleToForward
syn keyword xConstant		XIMVisibleToBackword
syn keyword xConstant		XIMVisibleToCenter
syn keyword xConstant		XIMPreeditUnKnown
syn keyword xConstant		XIMPreeditEnable
syn keyword xConstant		XIMPreeditDisable
syn keyword xConstant		XIMInitialState
syn keyword xConstant		XIMPreserveState
syn keyword xConstant		XIMStringConversionLeftEdge
syn keyword xConstant		XIMStringConversionRightEdge
syn keyword xConstant		XIMStringConversionTopEdge
syn keyword xConstant		XIMStringConversionBottomEdge
syn keyword xConstant		XIMStringConversionConcealed
syn keyword xConstant		XIMStringConversionWrapped
syn keyword xConstant		XIMStringConversionBuffer
syn keyword xConstant		XIMStringConversionLine
syn keyword xConstant		XIMStringConversionWord
syn keyword xConstant		XIMStringConversionChar
syn keyword xConstant		XIMStringConversionSubstitution
syn keyword xConstant		XIMStringConversionRetrieval
syn keyword xConstant		XIMHotKeyStateON
syn keyword xConstant		XIMHotKeyStateOFF

syn keyword xConstant		XOMOrientation_LTR_TTB
syn keyword xConstant		XOMOrientation_RTL_TTB
syn keyword xConstant		XOMOrientation_TTB_LTR
syn keyword xConstant		XOMOrientation_TTB_RTL
syn keyword xConstant		XOMOrientation_Context
syn keyword xConstant		XIMForwardChar XIMBackwardChar
syn keyword xConstant		XIMForwardWord XIMBackwardWord
syn keyword xConstant		XIMCaretUp XIMCaretDown
syn keyword xConstant		XIMNextLine XIMPreviousLine
syn keyword xConstant		XIMLineStart XIMLineEnd
syn keyword xConstant		XIMAbsolutePosition
syn keyword xConstant		XIMDontChange
syn keyword xConstant		XIMIsInvisible XIMIsPrimary XIMIsSecondary
syn keyword xConstant		XIMTextType XIMBitmapType

syn keyword xStorageClass	XExtData
syn keyword xStorageClass	XExtCodes
syn keyword xStorageClass	XPixmapFormatValues
syn keyword xStorageClass	XGCValues
syn keyword xStorageClass	Visual
syn keyword xStorageClass	Depth
syn keyword xStorageClass	Screen
syn keyword xStorageClass	ScreenFormat
syn keyword xStorageClass	XSetWindowAttributes
syn keyword xStorageClass	XWindowAttributes
syn keyword xStorageClass	XHostAddress
syn keyword xStorageClass	XImage
syn keyword xStorageClass	XWindowChanges
syn keyword xStorageClass	XColor
syn keyword xStorageClass	XSegment
syn keyword xStorageClass	XPoint
syn keyword xStorageClass	XRectangle
syn keyword xStorageClass	XArc
syn keyword xStorageClass	XKeyboardControl
syn keyword xStorageClass	XKeyboardState
syn keyword xStorageClass	XTimeCoord
syn keyword xStorageClass	XModifierKeymap
syn keyword xStorageClass	XKeyEvent
syn keyword xStorageClass	XButtonEvent
syn keyword xStorageClass	XMotionEvent
syn keyword xStorageClass	XCrossingEvent
syn keyword xStorageClass	XFocusChangeEvent
syn keyword xStorageClass	XKeymapEvent
syn keyword xStorageClass	XExposeEvent
syn keyword xStorageClass	XGraphicsExposeEvent
syn keyword xStorageClass	XNoExposeEvent
syn keyword xStorageClass	XVisibilityEvent
syn keyword xStorageClass	XCreateWindowEvent
syn keyword xStorageClass	XDestroyWindowEvent
syn keyword xStorageClass	XUnmapEvent
syn keyword xStorageClass	XMapEvent
syn keyword xStorageClass	XMapRequestEvent
syn keyword xStorageClass	XReparentEvent
syn keyword xStorageClass	XConfigureEvent
syn keyword xStorageClass	XGravityEvent
syn keyword xStorageClass	XResizeRequestEvent
syn keyword xStorageClass	XConfigureRequestEvent
syn keyword xStorageClass	XCirculateEvent
syn keyword xStorageClass	XCirculateRequestEvent
syn keyword xStorageClass	XPropertyEvent
syn keyword xStorageClass	XSelectionClearEvent
syn keyword xStorageClass	XSelectionRequestEvent
syn keyword xStorageClass	XSelectionEvent
syn keyword xStorageClass	XColormapEvent
syn keyword xStorageClass	XClientMessageEvent
syn keyword xStorageClass	XMappingEvent
syn keyword xStorageClass	XErrorEvent
syn keyword xStorageClass	XAnyEvent
syn keyword xStorageClass	XEvent
syn keyword xStorageClass	XCharStruct
syn keyword xStorageClass	XFontProp
syn keyword xStorageClass	XFontStruct
syn keyword xStorageClass	XTextItem
syn keyword xStorageClass	XChar2b
syn keyword xStorageClass	XTextItem16
syn keyword xStorageClass	XFontSetExtents
syn keyword xStorageClass	XmbTextItem
syn keyword xStorageClass	XwcTextItem
syn keyword xStorageClass	XOMCharSetList
syn keyword xStorageClass	XOrientation
syn keyword xStorageClass	XOMOrientation
syn keyword xStorageClass	XOMFontInfo
syn keyword xStorageClass	XIMStyles
syn keyword xStorageClass	XIMCallback
syn keyword xStorageClass	XICCallback
syn keyword xStorageClass	XIMText
syn keyword xStorageClass	XIMPreeditStateNotifyCallbackStruct
syn keyword xStorageClass	XIMStringConversionText
syn keyword xStorageClass	XIMCaretDirection
syn keyword xStorageClass	XIMStringConversionCallbackStruct
syn keyword xStorageClass	XIMPreeditDrawCallbackStruct
syn keyword xStorageClass	XIMCaretStyle
syn keyword xStorageClass	XIMPreeditCaretCallbackStruct
syn keyword xStorageClass	XIMStatusDataType
syn keyword xStorageClass	XIMStatusDrawCallbackStruct
syn keyword xStorageClass	XIMHotKeyTrigger
syn keyword xStorageClass	XIMHotKeyTriggers
syn keyword xStorageClass	XIMValuesList

syn keyword xStorageClass	XPointer
syn keyword xStorageClass	Display
syn keyword xStorageClass	XKeyPressedEvent
syn keyword xStorageClass	XKeyReleasedEvent
syn keyword xStorageClass	XButtonPressedEvent
syn keyword xStorageClass	XButtonReleasedEvent
syn keyword xStorageClass	XPointerMovedEvent
syn keyword xStorageClass	XEnterWindowEvent
syn keyword xStorageClass	XLeaveWindowEvent
syn keyword xStorageClass	XFocusInEvent
syn keyword xStorageClass	XFocusOutEvent
syn keyword xStorageClass	XOMProc
syn keyword xStorageClass	XOM
syn keyword xStorageClass	XOC XFontSet
syn keyword xStorageClass	XIM
syn keyword xStorageClass	XIC
syn keyword xStorageClass	XIMStyle
syn keyword xStorageClass	XVaNestedList
syn keyword xStorageClass	XVaNestedList
syn keyword xStorageClass	XIMFeedback
syn keyword xStorageClass	XIMPreeditState
syn keyword xStorageClass	XIMResetState
syn keyword xStorageClass	XIMStringConversionFeedback
syn keyword xStorageClass	XIMStringConversionPosition
syn keyword xStorageClass	XIMStringConversionType
syn keyword xStorageClass	XIMStringConversionOperation
syn keyword xStorageClass	XIMHotKeyState

syn keyword xFunction		XLoadQueryFont
syn keyword xFunction		XQueryFont
syn keyword xFunction		XGetMotionEvents
syn keyword xFunction		XDeleteModifiermapEntry
syn keyword xFunction		XGetModifierMapping
syn keyword xFunction		XInsertModifiermapEntry
syn keyword xFunction		XNewModifiermap
syn keyword xFunction		XCreateImage
syn keyword xFunction		XInitImage
syn keyword xFunction		XGetImage
syn keyword xFunction		XGetSubImage
syn keyword xFunction		XOpenDisplay
syn keyword xFunction		XrmInitialize
syn keyword xFunction		XFetchBytes
syn keyword xFunction		XFetchBuffer
syn keyword xFunction		XGetAtomName
syn keyword xFunction		XGetAtomNames
syn keyword xFunction		XGetDefault
syn keyword xFunction		XDisplayName
syn keyword xFunction		XKeysymToString
syn keyword xFunction		XSynchronize
syn keyword xFunction		XSetAfterFunction
syn keyword xFunction		XInternAtom
syn keyword xFunction		XInternAtoms
syn keyword xFunction		XCopyColormapAndFree
syn keyword xFunction		XCreateColormap
syn keyword xFunction		XCreatePixmapCursor
syn keyword xFunction		XCreateGlyphCursor
syn keyword xFunction		XCreateFontCursor
syn keyword xFunction		XLoadFont
syn keyword xFunction		XCreateGC
syn keyword xFunction		XGContextFromGC
syn keyword xFunction		XFlushGC
syn keyword xFunction		XCreatePixmap
syn keyword xFunction		XCreateBitmapFromData
syn keyword xFunction		XCreatePixmapFromBitmapData
syn keyword xFunction		XCreateSimpleWindow
syn keyword xFunction		XGetSelectionOwner
syn keyword xFunction		XCreateWindow
syn keyword xFunction		XListInstalledColormaps
syn keyword xFunction		XListFonts
syn keyword xFunction		XListFontsWithInfo
syn keyword xFunction		XGetFontPath
syn keyword xFunction		XListExtensions
syn keyword xFunction		XListProperties
syn keyword xFunction		XListHosts
syn keyword xFunction		XKeycodeToKeysym
syn keyword xFunction		XLookupKeysym
syn keyword xFunction		XGetKeyboardMapping
syn keyword xFunction		XStringToKeysym
syn keyword xFunction		XMaxRequestSize
syn keyword xFunction		XExtendedMaxRequestSize
syn keyword xFunction		XResourceManagerString
syn keyword xFunction		XScreenResourceString
syn keyword xFunction		XDisplayMotionBufferSize
syn keyword xFunction		XVisualIDFromVisual
syn keyword xFunction		XInitThreads
syn keyword xFunction		XLockDisplay
syn keyword xFunction		XUnlockDisplay
syn keyword xFunction		XInitExtension
syn keyword xFunction		XAddExtension
syn keyword xFunction		XFindOnExtensionList
syn keyword xFunction		XEHeadOfExtensionList
syn keyword xFunction		XRootWindow
syn keyword xFunction		XDefaultRootWindow
syn keyword xFunction		XRootWindowOfScreen
syn keyword xFunction		XDefaultVisual
syn keyword xFunction		XDefaultVisualOfScreen
syn keyword xFunction		XDefaultGC
syn keyword xFunction		XDefaultGCOfScreen
syn keyword xFunction		XBlackPixel
syn keyword xFunction		XWhitePixel
syn keyword xFunction		XAllPlanes
syn keyword xFunction		XBlackPixelOfScreen
syn keyword xFunction		XWhitePixelOfScreen
syn keyword xFunction		XNextRequest
syn keyword xFunction		XLastKnownRequestProcessed
syn keyword xFunction		XServerVendor
syn keyword xFunction		XDisplayString
syn keyword xFunction		XDefaultColormap
syn keyword xFunction		XDefaultColormapOfScreen
syn keyword xFunction		XDisplayOfScreen
syn keyword xFunction		XScreenOfDisplay
syn keyword xFunction		XDefaultScreenOfDisplay
syn keyword xFunction		XEventMaskOfScreen
syn keyword xFunction		XScreenNumberOfScreen
syn keyword xFunction		XSetErrorHandler
syn keyword xFunction		XSetIOErrorHandler
syn keyword xFunction		XListPixmapFormats
syn keyword xFunction		XListDepths
syn keyword xFunction		XReconfigureWMWindow
syn keyword xFunction		XGetWMProtocols
syn keyword xFunction		XSetWMProtocols
syn keyword xFunction		XIconifyWindow
syn keyword xFunction		XWithdrawWindow
syn keyword xFunction		XGetCommand
syn keyword xFunction		XGetWMColormapWindows
syn keyword xFunction		XSetWMColormapWindows
syn keyword xFunction		XFreeStringList
syn keyword xFunction		XSetTransientForHint
syn keyword xFunction		XActivateScreenSaver
syn keyword xFunction		XAddHost
syn keyword xFunction		XAddHosts
syn keyword xFunction		XAddToExtensionList
syn keyword xFunction		XAddToSaveSet
syn keyword xFunction		XAllocColor
syn keyword xFunction		XAllocColorCells
syn keyword xFunction		XAllocColorPlanes
syn keyword xFunction		XAllocNamedColor
syn keyword xFunction		XAllowEvents
syn keyword xFunction		XAutoRepeatOff
syn keyword xFunction		XAutoRepeatOn
syn keyword xFunction		XBell
syn keyword xFunction		XBitmapBitOrder
syn keyword xFunction		XBitmapPad
syn keyword xFunction		XBitmapUnit
syn keyword xFunction		XCellsOfScreen
syn keyword xFunction		XChangeActivePointerGrab
syn keyword xFunction		XChangeGC
syn keyword xFunction		XChangeKeyboardControl
syn keyword xFunction		XChangeKeyboardMapping
syn keyword xFunction		XChangePointerControl
syn keyword xFunction		XChangeProperty
syn keyword xFunction		XChangeSaveSet
syn keyword xFunction		XChangeWindowAttributes
syn keyword xFunction		XCheckIfEvent
syn keyword xFunction		XCheckMaskEvent
syn keyword xFunction		XCheckTypedEvent
syn keyword xFunction		XCheckTypedWindowEvent
syn keyword xFunction		XCheckWindowEvent
syn keyword xFunction		XCirculateSubwindows
syn keyword xFunction		XCirculateSubwindowsDown
syn keyword xFunction		XCirculateSubwindowsUp
syn keyword xFunction		XClearArea
syn keyword xFunction		XClearWindow
syn keyword xFunction		XCloseDisplay
syn keyword xFunction		XConfigureWindow
syn keyword xFunction		XConnectionNumber
syn keyword xFunction		XConvertSelection
syn keyword xFunction		XCopyArea
syn keyword xFunction		XCopyGC
syn keyword xFunction		XCopyPlane
syn keyword xFunction		XDefaultDepth
syn keyword xFunction		XDefaultDepthOfScreen
syn keyword xFunction		XDefaultScreen
syn keyword xFunction		XDefineCursor
syn keyword xFunction		XDeleteProperty
syn keyword xFunction		XDestroyWindow
syn keyword xFunction		XDestroySubwindows
syn keyword xFunction		XDoesBackingStore
syn keyword xFunction		XDoesSaveUnders
syn keyword xFunction		XDisableAccessControl
syn keyword xFunction		XDisplayCells
syn keyword xFunction		XDisplayHeight
syn keyword xFunction		XDisplayHeightMM
syn keyword xFunction		XDisplayKeycodes
syn keyword xFunction		XDisplayPlanes
syn keyword xFunction		XDisplayWidth
syn keyword xFunction		XDisplayWidthMM
syn keyword xFunction		XDrawArc
syn keyword xFunction		XDrawArcs
syn keyword xFunction		XDrawImageString
syn keyword xFunction		XDrawImageString16
syn keyword xFunction		XDrawLine
syn keyword xFunction		XDrawLines
syn keyword xFunction		XDrawPoint
syn keyword xFunction		XDrawPoints
syn keyword xFunction		XDrawRectangle
syn keyword xFunction		XDrawRectangles
syn keyword xFunction		XDrawSegments
syn keyword xFunction		XDrawString
syn keyword xFunction		XDrawString16
syn keyword xFunction		XDrawText
syn keyword xFunction		XDrawText16
syn keyword xFunction		XEnableAccessControl
syn keyword xFunction		XEventsQueued
syn keyword xFunction		XFetchName
syn keyword xFunction		XFillArc
syn keyword xFunction		XFillArcs
syn keyword xFunction		XFillPolygon
syn keyword xFunction		XFillRectangle
syn keyword xFunction		XFillRectangles
syn keyword xFunction		XFlush
syn keyword xFunction		XForceScreenSaver
syn keyword xFunction		XFree
syn keyword xFunction		XFreeColormap
syn keyword xFunction		XFreeColors
syn keyword xFunction		XFreeCursor
syn keyword xFunction		XFreeExtensionList
syn keyword xFunction		XFreeFont
syn keyword xFunction		XFreeFontInfo
syn keyword xFunction		XFreeFontNames
syn keyword xFunction		XFreeFontPath
syn keyword xFunction		XFreeGC
syn keyword xFunction		XFreeModifiermap
syn keyword xFunction		XFreePixmap
syn keyword xFunction		XGeometry
syn keyword xFunction		XGetErrorDatabaseText
syn keyword xFunction		XGetErrorText
syn keyword xFunction		XGetFontProperty
syn keyword xFunction		XGetGCValues
syn keyword xFunction		XGetGeometry
syn keyword xFunction		XGetIconName
syn keyword xFunction		XGetInputFocus
syn keyword xFunction		XGetKeyboardControl
syn keyword xFunction		XGetPointerControl
syn keyword xFunction		XGetPointerMapping
syn keyword xFunction		XGetScreenSaver
syn keyword xFunction		XGetTransientForHint
syn keyword xFunction		XGetWindowProperty
syn keyword xFunction		XGetWindowAttributes
syn keyword xFunction		XGrabButton
syn keyword xFunction		XGrabKey
syn keyword xFunction		XGrabKeyboard
syn keyword xFunction		XGrabPointer
syn keyword xFunction		XGrabServer
syn keyword xFunction		XHeightMMOfScreen
syn keyword xFunction		XHeightOfScreen
syn keyword xFunction		XIfEvent
syn keyword xFunction		XImageByteOrder
syn keyword xFunction		XInstallColormap
syn keyword xFunction		XKeysymToKeycode
syn keyword xFunction		XKillClient
syn keyword xFunction		XLookupColor
syn keyword xFunction		XLowerWindow
syn keyword xFunction		XMapRaised
syn keyword xFunction		XMapSubwindows
syn keyword xFunction		XMapWindow
syn keyword xFunction		XMaskEvent
syn keyword xFunction		XMaxCmapsOfScreen
syn keyword xFunction		XMinCmapsOfScreen
syn keyword xFunction		XMoveResizeWindow
syn keyword xFunction		XMoveWindow
syn keyword xFunction		XNextEvent
syn keyword xFunction		XNoOp
syn keyword xFunction		XParseColor
syn keyword xFunction		XParseGeometry
syn keyword xFunction		XPeekEvent
syn keyword xFunction		XPeekIfEvent
syn keyword xFunction		XPending
syn keyword xFunction		XPlanesOfScreen
syn keyword xFunction		XProtocolRevision
syn keyword xFunction		XProtocolVersion
syn keyword xFunction		XPutBackEvent
syn keyword xFunction		XPutImage
syn keyword xFunction		XQLength
syn keyword xFunction		XQueryBestCursor
syn keyword xFunction		XQueryBestSize
syn keyword xFunction		XQueryBestStipple
syn keyword xFunction		XQueryBestTile
syn keyword xFunction		XQueryColor
syn keyword xFunction		XQueryColors
syn keyword xFunction		XQueryExtension
syn keyword xFunction		XQueryKeymap
syn keyword xFunction		XQueryPointer
syn keyword xFunction		XQueryTextExtents
syn keyword xFunction		XQueryTextExtents16
syn keyword xFunction		XQueryTree
syn keyword xFunction		XRaiseWindow
syn keyword xFunction		XReadBitmapFile
syn keyword xFunction		XReadBitmapFileData
syn keyword xFunction		XRebindKeysym
syn keyword xFunction		XRecolorCursor
syn keyword xFunction		XRefreshKeyboardMapping
syn keyword xFunction		XRemoveFromSaveSet
syn keyword xFunction		XRemoveHost
syn keyword xFunction		XRemoveHosts
syn keyword xFunction		XReparentWindow
syn keyword xFunction		XResetScreenSaver
syn keyword xFunction		XResizeWindow
syn keyword xFunction		XRestackWindows
syn keyword xFunction		XRotateBuffers
syn keyword xFunction		XRotateWindowProperties
syn keyword xFunction		XScreenCount
syn keyword xFunction		XSelectInput
syn keyword xFunction		XSendEvent
syn keyword xFunction		XSetAccessControl
syn keyword xFunction		XSetArcMode
syn keyword xFunction		XSetBackground
syn keyword xFunction		XSetClipMask
syn keyword xFunction		XSetClipOrigin
syn keyword xFunction		XSetClipRectangles
syn keyword xFunction		XSetCloseDownMode
syn keyword xFunction		XSetCommand
syn keyword xFunction		XSetDashes
syn keyword xFunction		XSetFillRule
syn keyword xFunction		XSetFillStyle
syn keyword xFunction		XSetFont
syn keyword xFunction		XSetFontPath
syn keyword xFunction		XSetForeground
syn keyword xFunction		XSetFunction
syn keyword xFunction		XSetGraphicsExposures
syn keyword xFunction		XSetIconName
syn keyword xFunction		XSetInputFocus
syn keyword xFunction		XSetLineAttributes
syn keyword xFunction		XSetModifierMapping
syn keyword xFunction		XSetPlaneMask
syn keyword xFunction		XSetPointerMapping
syn keyword xFunction		XSetScreenSaver
syn keyword xFunction		XSetSelectionOwner
syn keyword xFunction		XSetState
syn keyword xFunction		XSetStipple
syn keyword xFunction		XSetSubwindowMode
syn keyword xFunction		XSetTSOrigin
syn keyword xFunction		XSetTile
syn keyword xFunction		XSetWindowBackground
syn keyword xFunction		XSetWindowBackgroundPixmap
syn keyword xFunction		XSetWindowBorder
syn keyword xFunction		XSetWindowBorderPixmap
syn keyword xFunction		XSetWindowBorderWidth
syn keyword xFunction		XSetWindowColormap
syn keyword xFunction		XStoreBuffer
syn keyword xFunction		XStoreBytes
syn keyword xFunction		XStoreColor
syn keyword xFunction		XStoreColors
syn keyword xFunction		XStoreName
syn keyword xFunction		XStoreNamedColor
syn keyword xFunction		XSync
syn keyword xFunction		XTextExtents
syn keyword xFunction		XTextExtents16
syn keyword xFunction		XTextWidth
syn keyword xFunction		XTextWidth16
syn keyword xFunction		XTranslateCoordinates
syn keyword xFunction		XUndefineCursor
syn keyword xFunction		XUngrabButton
syn keyword xFunction		XUngrabKey
syn keyword xFunction		XUngrabKeyboard
syn keyword xFunction		XUngrabPointer
syn keyword xFunction		XUngrabServer
syn keyword xFunction		XUninstallColormap
syn keyword xFunction		XUnloadFont
syn keyword xFunction		XUnmapSubwindows
syn keyword xFunction		XUnmapWindow
syn keyword xFunction		XVendorRelease
syn keyword xFunction		XWarpPointer
syn keyword xFunction		XWidthMMOfScreen
syn keyword xFunction		XWidthOfScreen
syn keyword xFunction		XWindowEvent
syn keyword xFunction		XWriteBitmapFile
syn keyword xFunction		XSupportsLocale
syn keyword xFunction		XSetLocaleModifiers
syn keyword xFunction		XOpenOM
syn keyword xFunction		XCloseOM
syn keyword xFunction		XSetOMValues
syn keyword xFunction		XGetOMValues
syn keyword xFunction		XDisplayOfOM
syn keyword xFunction		XLocaleOfOM
syn keyword xFunction		XCreateOC
syn keyword xFunction		XDestroyOC
syn keyword xFunction		XOMOfOC
syn keyword xFunction		XSetOCValues
syn keyword xFunction		XGetOCValues
syn keyword xFunction		XCreateFontSet
syn keyword xFunction		XFreeFontSet
syn keyword xFunction		XFontsOfFontSet
syn keyword xFunction		XBaseFontNameListOfFontSet
syn keyword xFunction		XLocaleOfFontSet
syn keyword xFunction		XContextDependentDrawing
syn keyword xFunction		XDirectionalDependentDrawing
syn keyword xFunction		XContextualDrawing
syn keyword xFunction		XExtentsOfFontSet
syn keyword xFunction		XmbTextEscapement
syn keyword xFunction		XwcTextEscapement
syn keyword xFunction		Xutf8TextEscapement
syn keyword xFunction		XmbTextExtents
syn keyword xFunction		XwcTextExtents
syn keyword xFunction		Xutf8TextExtents
syn keyword xFunction		XmbTextPerCharExtents
syn keyword xFunction		XwcTextPerCharExtents
syn keyword xFunction		Xutf8TextPerCharExtents
syn keyword xFunction		XmbDrawText
syn keyword xFunction		XwcDrawText
syn keyword xFunction		Xutf8DrawText
syn keyword xFunction		XmbDrawString
syn keyword xFunction		XwcDrawString
syn keyword xFunction		Xutf8DrawString
syn keyword xFunction		XmbDrawImageString
syn keyword xFunction		XwcDrawImageString
syn keyword xFunction		Xutf8DrawImageString
syn keyword xFunction		XOpenIM
syn keyword xFunction		XCloseIM
syn keyword xFunction		XGetIMValues
syn keyword xFunction		XSetIMValues
syn keyword xFunction		XDisplayOfIM
syn keyword xFunction		XLocaleOfIM
syn keyword xFunction		XCreateIC
syn keyword xFunction		XDestroyIC
syn keyword xFunction		XSetICFocus
syn keyword xFunction		XUnsetICFocus
syn keyword xFunction		XwcResetIC
syn keyword xFunction		XmbResetIC
syn keyword xFunction		Xutf8ResetIC
syn keyword xFunction		XSetICValues
syn keyword xFunction		XGetICValues
syn keyword xFunction		XIMOfIC
syn keyword xFunction		XFilterEvent
syn keyword xFunction		XmbLookupString
syn keyword xFunction		XwcLookupString
syn keyword xFunction		Xutf8LookupString
syn keyword xFunction		XVaCreateNestedList
syn keyword xFunction		XRegisterIMInstantiateCallback
syn keyword xFunction		XUnregisterIMInstantiateCallback
syn keyword xFunction		XInternalConnectionNumbers
syn keyword xFunction		XProcessInternalConnection
syn keyword xFunction		XAddConnectionWatch
syn keyword xFunction		XRemoveConnectionWatch
syn keyword xFunction		XSetAuthorization
syn keyword xFunction		_Xmbtowc
syn keyword xFunction		_Xwctomb

" Xutil.h
syn keyword xConstant		XStringStyle
syn keyword xConstant		XCompoundTextStyle
syn keyword xConstant		XTextStyle
syn keyword xConstant		XStdICCTextStyle
syn keyword xConstant		XUTF8StringStyle

syn keyword xStorageClass	XSizeHints
syn keyword xStorageClass	XWMHints
syn keyword xStorageClass	XTextProperty
syn keyword xStorageClass	XICCEncodingStyle
syn keyword xStorageClass	XIconSize
syn keyword xStorageClass	XClassHint
syn keyword xStorageClass	XComposeStatus
syn keyword xStorageClass	XVisualInfo
syn keyword xStorageClass	XStandardColormap

syn keyword xFunction		XAllocClassHint
syn keyword xFunction		XAllocIconSize
syn keyword xFunction		XAllocSizeHints
syn keyword xFunction		XAllocStandardColormap
syn keyword xFunction		XAllocWMHints
syn keyword xFunction		XClipBox
syn keyword xFunction		XCreateRegion
syn keyword xFunction		XDefaultString
syn keyword xFunction		XDeleteContext
syn keyword xFunction		XDestroyRegion
syn keyword xFunction		XEmptyRegion
syn keyword xFunction		XEqualRegion
syn keyword xFunction		XFindContext
syn keyword xFunction		XGetClassHint
syn keyword xFunction		XGetIconSizes
syn keyword xFunction		XGetNormalHints
syn keyword xFunction		XGetRGBColormaps
syn keyword xFunction		XGetSizeHints
syn keyword xFunction		XGetStandardColormap
syn keyword xFunction		XGetTextProperty
syn keyword xFunction		XGetVisualInfo
syn keyword xFunction		XGetWMClientMachine
syn keyword xFunction		XGetWMHints
syn keyword xFunction		XGetWMIconName
syn keyword xFunction		XGetWMName
syn keyword xFunction		XGetWMNormalHints
syn keyword xFunction		XGetWMSizeHints
syn keyword xFunction		XGetZoomHints
syn keyword xFunction		XIntersectRegion
syn keyword xFunction		XConvertCase
syn keyword xFunction		XLookupString
syn keyword xFunction		XMatchVisualInfo
syn keyword xFunction		XOffsetRegion
syn keyword xFunction		XPointInRegion
syn keyword xFunction		XPolygonRegion
syn keyword xFunction		XRectInRegion
syn keyword xFunction		XSaveContext
syn keyword xFunction		XSetClassHint
syn keyword xFunction		XSetIconSizes
syn keyword xFunction		XSetNormalHints
syn keyword xFunction		XSetRGBColormaps
syn keyword xFunction		XSetSizeHints
syn keyword xFunction		XSetStandardProperties
syn keyword xFunction		XSetTextProperty
syn keyword xFunction		XSetWMClientMachine
syn keyword xFunction		XSetWMHints
syn keyword xFunction		XSetWMIconName
syn keyword xFunction		XSetWMName
syn keyword xFunction		XSetWMNormalHints
syn keyword xFunction		XSetWMProperties
syn keyword xFunction		XmbSetWMProperties
syn keyword xFunction		Xutf8SetWMProperties
syn keyword xFunction		XSetWMSizeHints
syn keyword xFunction		XSetRegion
syn keyword xFunction		XSetStandardColormap
syn keyword xFunction		XSetZoomHints
syn keyword xFunction		XShrinkRegion
syn keyword xFunction		XStringListToTextProperty
syn keyword xFunction		XSubtractRegion
syn keyword xFunction		XmbTextListToTextProperty
syn keyword xFunction		XwcTextListToTextProperty
syn keyword xFunction		Xutf8TextListToTextProperty
syn keyword xFunction		XwcFreeStringList
syn keyword xFunction		XTextPropertyToStringList
syn keyword xFunction		XmbTextPropertyToTextList
syn keyword xFunction		XwcTextPropertyToTextList
syn keyword xFunction		Xutf8TextPropertyToTextList
syn keyword xFunction		XUnionRectWithRegion
syn keyword xFunction		XUnionRegion
syn keyword xFunction		XWMGeometry
syn keyword xFunction		XXorRegion

" Default highlighting
if version >= 508 || !exists("did_xlib_syntax_inits")
  if version < 508
    let did_xlib_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
   HiLink xType			Type
   HiLink xConstant		Constant
   HiLink xStorageClass		StorageClass
   HiLink xFunction		Function
   HiLink xBoolean		Boolean
  delcommand HiLink
endif

" vim: ts=8
