" Vim syntax file
" Language: C librsvg extension (for version 2.32.1)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let librsvg_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let librsvg_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword librsvgFunction args_fini args_init args_parse args_print librsvg_postinit librsvg_preinit lpyramid_create lpyramid_destroy lpyramid_get_value pdiff_compare rsvg_error_get_type rsvg_error_quark rsvg_handle_close rsvg_handle_flags_get_type rsvg_handle_get_base_uri rsvg_handle_get_desc rsvg_handle_get_dimensions rsvg_handle_get_dimensions_sub rsvg_handle_get_metadata rsvg_handle_get_pixbuf rsvg_handle_get_pixbuf_sub rsvg_handle_get_position_sub rsvg_handle_get_title rsvg_handle_get_type rsvg_handle_has_sub rsvg_handle_new rsvg_handle_new_from_data rsvg_handle_new_from_file rsvg_handle_new_from_gfile_sync rsvg_handle_new_from_stream_sync rsvg_handle_read_stream_sync rsvg_handle_render_cairo rsvg_handle_render_cairo_sub rsvg_handle_set_base_gfile rsvg_handle_set_base_uri rsvg_handle_set_dpi rsvg_handle_set_dpi_x_y rsvg_handle_write rsvg_init rsvg_rc_style_register_type rsvg_set_default_dpi rsvg_set_default_dpi_x_y rsvg_style_register_type rsvg_term rsvg_tools_main test_utils_get_test_data_path theme_pixbuf_destroy theme_pixbuf_get_pixbuf theme_pixbuf_new theme_pixbuf_render theme_pixbuf_set_border theme_pixbuf_set_filename theme_pixbuf_set_stretch
syn keyword librsvgTypedef RsvgHandlePrivate bool lpyramid_t
syn keyword librsvgConstant COMPONENT_ALL COMPONENT_CENTER COMPONENT_EAST COMPONENT_NORTH COMPONENT_NORTH_EAST COMPONENT_NORTH_WEST COMPONENT_SOUTH COMPONENT_SOUTH_EAST COMPONENT_SOUTH_WEST COMPONENT_WEST RSVG_ERROR_FAILED RSVG_HANDLE_FLAGS_NONE THEME_CONSTANT_COLS THEME_CONSTANT_ROWS THEME_MATCH_ARROW_DIRECTION THEME_MATCH_GAP_SIDE THEME_MATCH_ORIENTATION THEME_MATCH_SHADOW THEME_MATCH_STATE THEME_MISSING
syn keyword librsvgStruct RsvgDimensionData RsvgHandle RsvgHandleClass RsvgPositionData RsvgRcStyle RsvgRcStyleClass RsvgStyle RsvgStyleClass ThemeData ThemeImage ThemeMatchData ThemePixbuf
syn keyword librsvgMacro LIBRSVG_CHECK_FEATURE LIBRSVG_CHECK_VERSION RSVG_HANDLE RSVG_HANDLE_CLASS RSVG_HANDLE_GET_CLASS RSVG_IS_HANDLE RSVG_IS_HANDLE_CLASS RSVG_IS_RC_STYLE RSVG_IS_RC_STYLE_CLASS RSVG_IS_STYLE RSVG_IS_STYLE_CLASS RSVG_RC_STYLE RSVG_RC_STYLE_CLASS RSVG_RC_STYLE_GET_CLASS RSVG_STYLE RSVG_STYLE_CLASS RSVG_STYLE_GET_CLASS
syn keyword librsvgEnum RsvgError RsvgHandleFlags ThemeMatchFlags ThemePixbufComponent ThemeRenderHints
syn keyword librsvgVariable librsvg_version rsvg_type_rc_style rsvg_type_style
syn keyword librsvgDefine LIBRSVG_HAVE_CSS LIBRSVG_HAVE_SVGZ LIBRSVG_MAJOR_VERSION LIBRSVG_MICRO_VERSION LIBRSVG_MINOR_VERSION LIBRSVG_VERSION MAX_PYR_LEVELS RSVG_ERROR RSVG_TYPE_ERROR RSVG_TYPE_HANDLE RSVG_TYPE_HANDLE_FLAGS RSVG_TYPE_RC_STYLE RSVG_TYPE_STYLE false true
syn keyword librsvgDeprecatedFunction rsvg_handle_free rsvg_handle_set_size_callback rsvg_pixbuf_from_file rsvg_pixbuf_from_file_at_max_size rsvg_pixbuf_from_file_at_size rsvg_pixbuf_from_file_at_zoom rsvg_pixbuf_from_file_at_zoom_with_max
syn keyword librsvgDeprecatedUserFunction RsvgSizeFunc

" Default highlighting
if version >= 508 || !exists("did_librsvg_syntax_inits")
  if version < 508
    let did_librsvg_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink librsvgFunction Function
  HiLink librsvgTypedef Type
  HiLink librsvgConstant Constant
  HiLink librsvgStruct Type
  HiLink librsvgMacro Macro
  HiLink librsvgEnum Type
  HiLink librsvgVariable Identifier
  HiLink librsvgDefine Constant
  if exists("librsvg_deprecated_errors")
    HiLink librsvgDeprecatedFunction Error
    HiLink librsvgDeprecatedUserFunction Error
  elseif exists("librsvg_enable_deprecated")
    HiLink librsvgDeprecatedFunction Function
    HiLink librsvgDeprecatedUserFunction Type
  endif

  delcommand HiLink
endif

