" Vim syntax file
" Language: C gimp extension (for version 2.6.11)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let gimp_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let gimp_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword gimpFunction gimp_adaptive_supersample_area gimp_add_mask_type_get_type gimp_airbrush gimp_airbrush_default gimp_any_to_utf8 gimp_aspect_preview_get_type gimp_aspect_preview_new gimp_aspect_type_get_type gimp_attach_new_parasite gimp_bilinear gimp_bilinear_16 gimp_bilinear_32 gimp_bilinear_8 gimp_bilinear_pixels_8 gimp_bilinear_rgb gimp_bilinear_rgba gimp_blend_mode_get_type gimp_brightness_contrast gimp_browser_add_search_types gimp_browser_get_type gimp_browser_new gimp_browser_set_widget gimp_browser_show_message gimp_brush_application_mode_get_type gimp_brush_delete gimp_brush_duplicate gimp_brush_generated_shape_get_type gimp_brush_get_angle gimp_brush_get_aspect_ratio gimp_brush_get_hardness gimp_brush_get_info gimp_brush_get_pixels gimp_brush_get_radius gimp_brush_get_shape gimp_brush_get_spacing gimp_brush_get_spikes gimp_brush_is_editable gimp_brush_is_generated gimp_brush_new gimp_brush_rename gimp_brush_select_button_get_brush gimp_brush_select_button_get_type gimp_brush_select_button_new gimp_brush_select_button_set_brush gimp_brush_select_destroy gimp_brush_select_new gimp_brush_set_angle gimp_brush_set_aspect_ratio gimp_brush_set_hardness gimp_brush_set_radius gimp_brush_set_shape gimp_brush_set_spacing gimp_brush_set_spikes gimp_brushes_close_popup gimp_brushes_get_list gimp_brushes_popup gimp_brushes_refresh gimp_brushes_set_popup gimp_bucket_fill_mode_get_type gimp_buffer_delete gimp_buffer_get_bytes gimp_buffer_get_height gimp_buffer_get_image_type gimp_buffer_get_width gimp_buffer_rename gimp_buffers_get_list gimp_button_extended_clicked gimp_button_get_type gimp_button_new gimp_by_color_select gimp_by_color_select_full gimp_cairo_checkerboard_create gimp_cairo_set_focus_line_pattern gimp_cairo_set_source_rgb gimp_cairo_set_source_rgba gimp_cairo_surface_create_from_pixbuf gimp_canonicalize_identifier gimp_cell_renderer_color_get_type gimp_cell_renderer_color_new gimp_cell_renderer_toggle_clicked gimp_cell_renderer_toggle_get_type gimp_cell_renderer_toggle_new gimp_chain_button_get_active gimp_chain_button_get_type gimp_chain_button_new gimp_chain_button_set_active gimp_chain_position_get_type gimp_channel_combine_masks gimp_channel_combo_box_get_type gimp_channel_combo_box_new gimp_channel_copy gimp_channel_get_color gimp_channel_get_opacity gimp_channel_get_show_masked gimp_channel_new gimp_channel_new_from_component gimp_channel_ops_get_type gimp_channel_set_color gimp_channel_set_opacity gimp_channel_set_show_masked gimp_channel_type_get_type gimp_check_size gimp_check_size_get_type gimp_check_type gimp_check_type_get_type gimp_checks_get_shades gimp_clone gimp_clone_default gimp_clone_type_get_type gimp_cmyk_get_type gimp_cmyk_get_uchar gimp_cmyk_set gimp_cmyk_set_uchar gimp_cmyk_to_rgb gimp_cmyk_to_rgb_int gimp_cmyka_get_uchar gimp_cmyka_set gimp_cmyka_set_uchar gimp_color_area_get_color gimp_color_area_get_type gimp_color_area_has_alpha gimp_color_area_new gimp_color_area_set_color gimp_color_area_set_draw_border gimp_color_area_set_type gimp_color_area_type_get_type gimp_color_balance gimp_color_button_get_color gimp_color_button_get_type gimp_color_button_get_update gimp_color_button_has_alpha gimp_color_button_new gimp_color_button_set_color gimp_color_button_set_type gimp_color_button_set_update gimp_color_config_get_type gimp_color_display_changed gimp_color_display_clone gimp_color_display_configure gimp_color_display_configure_reset gimp_color_display_convert gimp_color_display_get_config gimp_color_display_get_enabled gimp_color_display_get_managed gimp_color_display_get_type gimp_color_display_load_state gimp_color_display_save_state gimp_color_display_set_enabled gimp_color_display_stack_add gimp_color_display_stack_changed gimp_color_display_stack_clone gimp_color_display_stack_convert gimp_color_display_stack_get_type gimp_color_display_stack_new gimp_color_display_stack_remove gimp_color_display_stack_reorder_down gimp_color_display_stack_reorder_up gimp_color_hex_entry_get_color gimp_color_hex_entry_get_type gimp_color_hex_entry_new gimp_color_hex_entry_set_color gimp_color_managed_get_icc_profile gimp_color_managed_interface_get_type gimp_color_managed_profile_changed gimp_color_management_mode_get_type gimp_color_notebook_get_type gimp_color_notebook_set_has_page gimp_color_profile_combo_box_add gimp_color_profile_combo_box_get_active gimp_color_profile_combo_box_get_type gimp_color_profile_combo_box_new gimp_color_profile_combo_box_new_with_model gimp_color_profile_combo_box_set_active gimp_color_profile_store_add gimp_color_profile_store_get_type gimp_color_profile_store_new gimp_color_rendering_intent_get_type gimp_color_scale_entry_new gimp_color_scale_get_type gimp_color_scale_new gimp_color_scale_set_channel gimp_color_scale_set_color gimp_color_scales_get_type gimp_color_select_get_type gimp_color_selection_color_changed gimp_color_selection_get_color gimp_color_selection_get_old_color gimp_color_selection_get_show_alpha gimp_color_selection_get_type gimp_color_selection_new gimp_color_selection_reset gimp_color_selection_set_color gimp_color_selection_set_config gimp_color_selection_set_old_color gimp_color_selection_set_show_alpha gimp_color_selector_channel_changed gimp_color_selector_channel_get_type gimp_color_selector_color_changed gimp_color_selector_get_type gimp_color_selector_new gimp_color_selector_set_channel gimp_color_selector_set_color gimp_color_selector_set_config gimp_color_selector_set_show_alpha gimp_color_selector_set_toggles_sensitive gimp_color_selector_set_toggles_visible gimp_colorize gimp_config_build_data_path gimp_config_build_plug_in_path gimp_config_build_writable_path gimp_config_copy gimp_config_deserialize_file gimp_config_deserialize_properties gimp_config_deserialize_property gimp_config_deserialize_return gimp_config_deserialize_string gimp_config_diff gimp_config_duplicate gimp_config_error_quark gimp_config_interface_get_type gimp_config_is_equal_to gimp_config_path_expand gimp_config_path_get_type gimp_config_reset gimp_config_reset_properties gimp_config_reset_property gimp_config_serialize_changed_properties gimp_config_serialize_properties gimp_config_serialize_property gimp_config_serialize_property_by_name gimp_config_serialize_to_fd gimp_config_serialize_to_file gimp_config_serialize_to_string gimp_config_serialize_value gimp_config_string_append_escaped gimp_config_sync gimp_config_writer_close gimp_config_writer_comment gimp_config_writer_comment_mode gimp_config_writer_data gimp_config_writer_finish gimp_config_writer_identifier gimp_config_writer_linefeed gimp_config_writer_new_fd gimp_config_writer_new_file gimp_config_writer_new_string gimp_config_writer_open gimp_config_writer_print gimp_config_writer_printf gimp_config_writer_revert gimp_config_writer_string gimp_context_get_background gimp_context_get_brush gimp_context_get_font gimp_context_get_foreground gimp_context_get_gradient gimp_context_get_opacity gimp_context_get_paint_method gimp_context_get_paint_mode gimp_context_get_palette gimp_context_get_pattern gimp_context_help gimp_context_list_paint_methods gimp_context_pop gimp_context_push gimp_context_set_background gimp_context_set_brush gimp_context_set_default_colors gimp_context_set_font gimp_context_set_foreground gimp_context_set_gradient gimp_context_set_opacity gimp_context_set_paint_method gimp_context_set_paint_mode gimp_context_set_palette gimp_context_set_pattern gimp_context_swap_colors gimp_controller_event gimp_controller_get_event_blurb gimp_controller_get_event_name gimp_controller_get_n_events gimp_controller_get_type gimp_controller_new gimp_convert_dither_type_get_type gimp_convert_palette_type_get_type gimp_convolution_type_get_type gimp_convolve gimp_convolve_default gimp_convolve_type_get_type gimp_coordinates_new gimp_cpu_accel_get_support gimp_cpu_accel_set_use gimp_curves_explicit gimp_curves_spline gimp_data_directory gimp_datafiles_check_extension gimp_datafiles_read_directories gimp_default_display gimp_desaturate gimp_desaturate_full gimp_desaturate_mode_get_type gimp_destroy_paramdefs gimp_destroy_params gimp_dialog_add_button gimp_dialog_add_buttons gimp_dialog_add_buttons_valist gimp_dialog_get_type gimp_dialog_new gimp_dialog_new_valist gimp_dialog_run gimp_dialogs_show_help_button gimp_directory gimp_display_delete gimp_display_get_window_handle gimp_display_is_valid gimp_display_name gimp_display_new gimp_displays_flush gimp_displays_reconnect gimp_dodge_burn_type_get_type gimp_dodgeburn gimp_dodgeburn_default gimp_double_adjustment_update gimp_drawable_attach_new_parasite gimp_drawable_bpp gimp_drawable_combo_box_get_type gimp_drawable_combo_box_new gimp_drawable_delete gimp_drawable_detach gimp_drawable_fill gimp_drawable_flush gimp_drawable_foreground_extract gimp_drawable_free_shadow gimp_drawable_get gimp_drawable_get_color_uchar gimp_drawable_get_image gimp_drawable_get_linked gimp_drawable_get_name gimp_drawable_get_pixel gimp_drawable_get_sub_thumbnail gimp_drawable_get_sub_thumbnail_data gimp_drawable_get_tattoo gimp_drawable_get_thumbnail gimp_drawable_get_thumbnail_data gimp_drawable_get_tile gimp_drawable_get_tile2 gimp_drawable_get_visible gimp_drawable_has_alpha gimp_drawable_height gimp_drawable_is_channel gimp_drawable_is_gray gimp_drawable_is_indexed gimp_drawable_is_layer gimp_drawable_is_layer_mask gimp_drawable_is_rgb gimp_drawable_is_text_layer gimp_drawable_is_valid gimp_drawable_mask_bounds gimp_drawable_mask_intersect gimp_drawable_merge_shadow gimp_drawable_offset gimp_drawable_offsets gimp_drawable_parasite_attach gimp_drawable_parasite_detach gimp_drawable_parasite_find gimp_drawable_parasite_list gimp_drawable_preview_draw_region gimp_drawable_preview_get_drawable gimp_drawable_preview_get_type gimp_drawable_preview_new gimp_drawable_set_linked gimp_drawable_set_name gimp_drawable_set_pixel gimp_drawable_set_tattoo gimp_drawable_set_visible gimp_drawable_transform_2d gimp_drawable_transform_2d_default gimp_drawable_transform_flip gimp_drawable_transform_flip_default gimp_drawable_transform_flip_simple gimp_drawable_transform_matrix gimp_drawable_transform_matrix_default gimp_drawable_transform_perspective gimp_drawable_transform_perspective_default gimp_drawable_transform_rotate gimp_drawable_transform_rotate_default gimp_drawable_transform_rotate_simple gimp_drawable_transform_scale gimp_drawable_transform_scale_default gimp_drawable_transform_shear gimp_drawable_transform_shear_default gimp_drawable_type gimp_drawable_type_with_alpha gimp_drawable_update gimp_drawable_width gimp_edit_blend gimp_edit_bucket_fill gimp_edit_bucket_fill_full gimp_edit_clear gimp_edit_copy gimp_edit_copy_visible gimp_edit_cut gimp_edit_fill gimp_edit_named_copy gimp_edit_named_copy_visible gimp_edit_named_cut gimp_edit_named_paste gimp_edit_named_paste_as_new gimp_edit_paste gimp_edit_paste_as_new gimp_edit_stroke gimp_edit_stroke_vectors gimp_ellipse_select gimp_enum_combo_box_get_type gimp_enum_combo_box_new gimp_enum_combo_box_new_with_model gimp_enum_combo_box_set_stock_prefix gimp_enum_get_desc gimp_enum_get_value gimp_enum_get_value_descriptions gimp_enum_label_get_type gimp_enum_label_new gimp_enum_label_set_value gimp_enum_radio_box_new gimp_enum_radio_box_new_with_range gimp_enum_radio_frame_new gimp_enum_radio_frame_new_with_range gimp_enum_set_value_descriptions gimp_enum_stock_box_new gimp_enum_stock_box_new_with_range gimp_enum_stock_box_set_child_padding gimp_enum_store_get_type gimp_enum_store_new gimp_enum_store_new_with_range gimp_enum_store_new_with_values gimp_enum_store_new_with_values_valist gimp_enum_store_set_stock_prefix gimp_enum_value_get_desc gimp_enum_value_get_help gimp_enums_get_type_names gimp_enums_init gimp_env_init gimp_equalize gimp_eraser gimp_eraser_default gimp_escape_uline gimp_export_image gimp_extension_ack gimp_extension_enable gimp_extension_process gimp_file_load gimp_file_load_layer gimp_file_load_layers gimp_file_save gimp_file_save_thumbnail gimp_filename_to_utf8 gimp_fill_type_get_type gimp_flags_get_first_desc gimp_flags_get_first_value gimp_flags_get_value_descriptions gimp_flags_set_value_descriptions gimp_flags_value_get_desc gimp_flags_value_get_help gimp_float_adjustment_update gimp_floating_sel_anchor gimp_floating_sel_attach gimp_floating_sel_relax gimp_floating_sel_remove gimp_floating_sel_rigor gimp_floating_sel_to_layer gimp_font_select_button_get_font gimp_font_select_button_get_type gimp_font_select_button_new gimp_font_select_button_set_font gimp_font_select_destroy gimp_font_select_new gimp_fonts_close_popup gimp_fonts_get_list gimp_fonts_popup gimp_fonts_refresh gimp_fonts_set_popup gimp_foreground_extract_mode_get_type gimp_frame_get_type gimp_frame_new gimp_free_select gimp_fuzzy_select gimp_fuzzy_select_full gimp_gamma gimp_get_color_configuration gimp_get_default_comment gimp_get_default_unit gimp_get_module_load_inhibit gimp_get_monitor_resolution gimp_get_pdb_error gimp_get_progname gimp_get_theme_dir gimp_getpid gimp_gimprc_query gimp_gimprc_set gimp_gradient_delete gimp_gradient_duplicate gimp_gradient_get_custom_samples gimp_gradient_get_number_of_segments gimp_gradient_get_uniform_samples gimp_gradient_is_editable gimp_gradient_new gimp_gradient_rename gimp_gradient_segment_color_get_type gimp_gradient_segment_get_blending_function gimp_gradient_segment_get_coloring_type gimp_gradient_segment_get_left_color gimp_gradient_segment_get_left_pos gimp_gradient_segment_get_middle_pos gimp_gradient_segment_get_right_color gimp_gradient_segment_get_right_pos gimp_gradient_segment_range_blend_colors gimp_gradient_segment_range_blend_opacity gimp_gradient_segment_range_delete gimp_gradient_segment_range_flip gimp_gradient_segment_range_move gimp_gradient_segment_range_redistribute_handles gimp_gradient_segment_range_replicate gimp_gradient_segment_range_set_blending_function gimp_gradient_segment_range_set_coloring_type gimp_gradient_segment_range_split_midpoint gimp_gradient_segment_range_split_uniform gimp_gradient_segment_set_left_color gimp_gradient_segment_set_left_pos gimp_gradient_segment_set_middle_pos gimp_gradient_segment_set_right_color gimp_gradient_segment_set_right_pos gimp_gradient_segment_type_get_type gimp_gradient_select_button_get_gradient gimp_gradient_select_button_get_type gimp_gradient_select_button_new gimp_gradient_select_button_set_gradient gimp_gradient_select_destroy gimp_gradient_select_new gimp_gradient_type_get_type gimp_gradients_close_popup gimp_gradients_get_list gimp_gradients_popup gimp_gradients_refresh gimp_gradients_set_popup gimp_grid_style_get_type gimp_gtkrc gimp_heal gimp_heal_default gimp_help gimp_help_connect gimp_help_disable_tooltips gimp_help_enable_tooltips gimp_help_id_quark gimp_help_set_help_data gimp_help_set_help_data_with_markup gimp_hint_box_get_type gimp_hint_box_new gimp_histogram gimp_histogram_channel_get_type gimp_hsl_get_type gimp_hsl_to_rgb gimp_hsl_to_rgb_int gimp_hsv_clamp gimp_hsv_get_type gimp_hsv_set gimp_hsv_to_rgb gimp_hsv_to_rgb4 gimp_hsv_to_rgb_int gimp_hsva_set gimp_hue_range_get_type gimp_hue_saturation gimp_hwb_to_rgb gimp_icon_type_get_type gimp_image_add_channel gimp_image_add_hguide gimp_image_add_layer gimp_image_add_vectors gimp_image_add_vguide gimp_image_attach_new_parasite gimp_image_base_type gimp_image_base_type_get_type gimp_image_clean_all gimp_image_combo_box_get_type gimp_image_combo_box_new gimp_image_convert_grayscale gimp_image_convert_indexed gimp_image_convert_rgb gimp_image_convert_set_dither_matrix gimp_image_crop gimp_image_delete gimp_image_delete_guide gimp_image_duplicate gimp_image_find_next_guide gimp_image_flatten gimp_image_flip gimp_image_floating_sel_attached_to gimp_image_get_active_channel gimp_image_get_active_drawable gimp_image_get_active_layer gimp_image_get_active_vectors gimp_image_get_channel_by_tattoo gimp_image_get_channel_position gimp_image_get_channels gimp_image_get_colormap gimp_image_get_component_active gimp_image_get_component_visible gimp_image_get_filename gimp_image_get_floating_sel gimp_image_get_guide_orientation gimp_image_get_guide_position gimp_image_get_layer_by_tattoo gimp_image_get_layer_position gimp_image_get_layers gimp_image_get_name gimp_image_get_resolution gimp_image_get_selection gimp_image_get_tattoo_state gimp_image_get_thumbnail gimp_image_get_thumbnail_data gimp_image_get_unit gimp_image_get_vectors gimp_image_get_vectors_by_tattoo gimp_image_get_vectors_position gimp_image_grid_get_background_color gimp_image_grid_get_foreground_color gimp_image_grid_get_offset gimp_image_grid_get_spacing gimp_image_grid_get_style gimp_image_grid_set_background_color gimp_image_grid_set_foreground_color gimp_image_grid_set_offset gimp_image_grid_set_spacing gimp_image_grid_set_style gimp_image_height gimp_image_is_dirty gimp_image_is_valid gimp_image_list gimp_image_lower_channel gimp_image_lower_layer gimp_image_lower_layer_to_bottom gimp_image_lower_vectors gimp_image_lower_vectors_to_bottom gimp_image_merge_down gimp_image_merge_visible_layers gimp_image_new gimp_image_parasite_attach gimp_image_parasite_detach gimp_image_parasite_find gimp_image_parasite_list gimp_image_pick_color gimp_image_pick_correlate_layer gimp_image_raise_channel gimp_image_raise_layer gimp_image_raise_layer_to_top gimp_image_raise_vectors gimp_image_raise_vectors_to_top gimp_image_remove_channel gimp_image_remove_layer gimp_image_remove_vectors gimp_image_resize gimp_image_resize_to_layers gimp_image_rotate gimp_image_scale gimp_image_scale_full gimp_image_set_active_channel gimp_image_set_active_layer gimp_image_set_active_vectors gimp_image_set_colormap gimp_image_set_component_active gimp_image_set_component_visible gimp_image_set_filename gimp_image_set_resolution gimp_image_set_tattoo_state gimp_image_set_unit gimp_image_type_get_type gimp_image_undo_disable gimp_image_undo_enable gimp_image_undo_freeze gimp_image_undo_group_end gimp_image_undo_group_start gimp_image_undo_is_enabled gimp_image_undo_thaw gimp_image_unset_active_channel gimp_image_width gimp_install_cmap gimp_install_procedure gimp_install_temp_proc gimp_int_adjustment_update gimp_int_combo_box_append gimp_int_combo_box_connect gimp_int_combo_box_get_active gimp_int_combo_box_get_type gimp_int_combo_box_new gimp_int_combo_box_new_array gimp_int_combo_box_new_valist gimp_int_combo_box_prepend gimp_int_combo_box_set_active gimp_int_combo_box_set_sensitivity gimp_int_radio_group_new gimp_int_radio_group_set_active gimp_int_store_get_type gimp_int_store_lookup_by_value gimp_int_store_new gimp_interpolation_type_get_type gimp_invert gimp_label_set_attributes gimp_layer_add_alpha gimp_layer_add_mask gimp_layer_combo_box_get_type gimp_layer_combo_box_new gimp_layer_copy gimp_layer_create_mask gimp_layer_flatten gimp_layer_from_mask gimp_layer_get_apply_mask gimp_layer_get_edit_mask gimp_layer_get_lock_alpha gimp_layer_get_mask gimp_layer_get_mode gimp_layer_get_opacity gimp_layer_get_show_mask gimp_layer_is_floating_sel gimp_layer_mode_effects_get_type gimp_layer_new gimp_layer_new_from_drawable gimp_layer_new_from_pixbuf gimp_layer_new_from_visible gimp_layer_remove_mask gimp_layer_resize gimp_layer_resize_to_image_size gimp_layer_scale gimp_layer_scale_full gimp_layer_set_apply_mask gimp_layer_set_edit_mask gimp_layer_set_lock_alpha gimp_layer_set_mode gimp_layer_set_offsets gimp_layer_set_opacity gimp_layer_set_show_mask gimp_layer_translate gimp_levels gimp_levels_stretch gimp_locale_directory gimp_main gimp_mask_apply_mode_get_type gimp_matrix2_get_type gimp_matrix2_identity gimp_matrix2_mult gimp_matrix3_affine gimp_matrix3_determinant gimp_matrix3_identity gimp_matrix3_invert gimp_matrix3_is_affine gimp_matrix3_is_diagonal gimp_matrix3_is_identity gimp_matrix3_is_simple gimp_matrix3_mult gimp_matrix3_rotate gimp_matrix3_scale gimp_matrix3_transform_point gimp_matrix3_translate gimp_matrix3_xshear gimp_matrix3_yshear gimp_matrix4_to_deg gimp_md5_get_digest gimp_memsize_deserialize gimp_memsize_entry_get_type gimp_memsize_entry_get_value gimp_memsize_entry_new gimp_memsize_entry_set_value gimp_memsize_get_type gimp_memsize_serialize gimp_merge_type_get_type gimp_message gimp_message_get_handler gimp_message_handler_type_get_type gimp_message_set_handler gimp_min_colors gimp_module_db_get_load_inhibit gimp_module_db_get_type gimp_module_db_load gimp_module_db_new gimp_module_db_refresh gimp_module_db_set_load_inhibit gimp_module_get_type gimp_module_info_copy gimp_module_info_free gimp_module_info_new gimp_module_modified gimp_module_new gimp_module_query_module gimp_module_set_load_inhibit gimp_module_state_name gimp_monitor_number gimp_number_pair_entry_get_aspect gimp_number_pair_entry_get_default_text gimp_number_pair_entry_get_default_values gimp_number_pair_entry_get_ratio gimp_number_pair_entry_get_type gimp_number_pair_entry_get_user_override gimp_number_pair_entry_get_values gimp_number_pair_entry_new gimp_number_pair_entry_set_aspect gimp_number_pair_entry_set_default_text gimp_number_pair_entry_set_default_values gimp_number_pair_entry_set_ratio gimp_number_pair_entry_set_user_override gimp_number_pair_entry_set_values gimp_offset_area_get_type gimp_offset_area_new gimp_offset_area_set_offsets gimp_offset_area_set_pixbuf gimp_offset_area_set_size gimp_offset_type_get_type gimp_orientation_type_get_type gimp_page_selector_get_n_pages gimp_page_selector_get_page_label gimp_page_selector_get_page_thumbnail gimp_page_selector_get_selected_pages gimp_page_selector_get_selected_range gimp_page_selector_get_target gimp_page_selector_get_type gimp_page_selector_new gimp_page_selector_page_is_selected gimp_page_selector_select_all gimp_page_selector_select_page gimp_page_selector_select_range gimp_page_selector_set_n_pages gimp_page_selector_set_page_label gimp_page_selector_set_page_thumbnail gimp_page_selector_set_target gimp_page_selector_target_get_type gimp_page_selector_unselect_all gimp_page_selector_unselect_page gimp_paint_application_mode_get_type gimp_paintbrush gimp_paintbrush_default gimp_palette_add_entry gimp_palette_delete gimp_palette_delete_entry gimp_palette_duplicate gimp_palette_entry_get_color gimp_palette_entry_get_name gimp_palette_entry_set_color gimp_palette_entry_set_name gimp_palette_get_colors gimp_palette_get_columns gimp_palette_get_info gimp_palette_is_editable gimp_palette_new gimp_palette_rename gimp_palette_select_button_get_palette gimp_palette_select_button_get_type gimp_palette_select_button_new gimp_palette_select_button_set_palette gimp_palette_select_destroy gimp_palette_select_new gimp_palette_set_columns gimp_palettes_close_popup gimp_palettes_get_list gimp_palettes_popup gimp_palettes_refresh gimp_palettes_set_popup gimp_param_config_path_get_type gimp_param_matrix2_get_type gimp_param_memsize_get_type gimp_param_parasite_get_type gimp_param_rgb_get_type gimp_param_spec_config_path gimp_param_spec_config_path_type gimp_param_spec_matrix2 gimp_param_spec_memsize gimp_param_spec_parasite gimp_param_spec_rgb gimp_param_spec_rgb_has_alpha gimp_param_spec_unit gimp_param_unit_get_type gimp_parasite_attach gimp_parasite_compare gimp_parasite_copy gimp_parasite_data gimp_parasite_data_size gimp_parasite_detach gimp_parasite_find gimp_parasite_flags gimp_parasite_free gimp_parasite_get_type gimp_parasite_has_flag gimp_parasite_is_persistent gimp_parasite_is_type gimp_parasite_is_undoable gimp_parasite_list gimp_parasite_name gimp_parasite_new gimp_path_editor_get_dir_writable gimp_path_editor_get_path gimp_path_editor_get_type gimp_path_editor_get_writable_path gimp_path_editor_new gimp_path_editor_set_dir_writable gimp_path_editor_set_path gimp_path_editor_set_writable_path gimp_path_free gimp_path_get_user_writable_dir gimp_path_parse gimp_path_to_str gimp_pattern_get_info gimp_pattern_get_pixels gimp_pattern_select_button_get_pattern gimp_pattern_select_button_get_type gimp_pattern_select_button_new gimp_pattern_select_button_set_pattern gimp_pattern_select_destroy gimp_pattern_select_new gimp_patterns_close_popup gimp_patterns_get_list gimp_patterns_popup gimp_patterns_refresh gimp_patterns_set_popup gimp_pdb_arg_type_get_type gimp_pdb_error_handler_get_type gimp_pdb_proc_type_get_type gimp_pdb_status_type_get_type gimp_pencil gimp_personal_rc_file gimp_pick_button_get_type gimp_pick_button_new gimp_pixel_fetcher_destroy gimp_pixel_fetcher_get_pixel gimp_pixel_fetcher_new gimp_pixel_fetcher_put_pixel gimp_pixel_fetcher_set_bg_color gimp_pixel_fetcher_set_edge_mode gimp_pixel_rgn_get_col gimp_pixel_rgn_get_pixel gimp_pixel_rgn_get_rect gimp_pixel_rgn_get_row gimp_pixel_rgn_init gimp_pixel_rgn_resize gimp_pixel_rgn_set_col gimp_pixel_rgn_set_pixel gimp_pixel_rgn_set_rect gimp_pixel_rgn_set_row gimp_pixel_rgns_process gimp_pixel_rgns_register gimp_pixel_rgns_register2 gimp_pixpipe_params_build gimp_pixpipe_params_init gimp_pixpipe_params_parse gimp_plug_in_directory gimp_plugin_domain_register gimp_plugin_get_pdb_error_handler gimp_plugin_help_register gimp_plugin_icon_register gimp_plugin_menu_branch_register gimp_plugin_menu_register gimp_plugin_set_pdb_error_handler gimp_posterize gimp_preview_area_blend gimp_preview_area_draw gimp_preview_area_fill gimp_preview_area_get_type gimp_preview_area_mask gimp_preview_area_menu_popup gimp_preview_area_new gimp_preview_area_set_colormap gimp_preview_area_set_max_size gimp_preview_area_set_offsets gimp_preview_draw gimp_preview_draw_buffer gimp_preview_get_area gimp_preview_get_controls gimp_preview_get_position gimp_preview_get_size gimp_preview_get_type gimp_preview_get_update gimp_preview_invalidate gimp_preview_set_bounds gimp_preview_set_default_cursor gimp_preview_set_update gimp_preview_transform gimp_preview_untransform gimp_proc_browser_dialog_get_selected gimp_proc_browser_dialog_get_type gimp_proc_browser_dialog_new gimp_proc_view_new gimp_procedural_db_dump gimp_procedural_db_get_data gimp_procedural_db_get_data_size gimp_procedural_db_proc_arg gimp_procedural_db_proc_exists gimp_procedural_db_proc_info gimp_procedural_db_proc_val gimp_procedural_db_query gimp_procedural_db_set_data gimp_procedural_db_temp_name gimp_progress_bar_get_type gimp_progress_bar_new gimp_progress_cancel gimp_progress_command_get_type gimp_progress_end gimp_progress_get_window_handle gimp_progress_init gimp_progress_init_printf gimp_progress_install_vtable gimp_progress_pulse gimp_progress_set_text gimp_progress_set_text_printf gimp_progress_uninstall gimp_progress_update gimp_prop_boolean_combo_box_new gimp_prop_boolean_radio_frame_new gimp_prop_check_button_new gimp_prop_color_area_new gimp_prop_coordinates_connect gimp_prop_coordinates_new gimp_prop_entry_new gimp_prop_enum_check_button_new gimp_prop_enum_combo_box_new gimp_prop_enum_label_new gimp_prop_enum_radio_box_new gimp_prop_enum_radio_frame_new gimp_prop_enum_stock_box_new gimp_prop_expander_new gimp_prop_file_chooser_button_new gimp_prop_file_chooser_button_new_with_dialog gimp_prop_hscale_new gimp_prop_int_combo_box_new gimp_prop_label_new gimp_prop_memsize_entry_new gimp_prop_opacity_entry_new gimp_prop_path_editor_new gimp_prop_scale_entry_new gimp_prop_size_entry_new gimp_prop_spin_button_new gimp_prop_stock_image_new gimp_prop_string_combo_box_new gimp_prop_text_buffer_new gimp_prop_unit_menu_new gimp_query_boolean_box gimp_query_double_box gimp_query_int_box gimp_query_size_box gimp_query_string_box gimp_quit gimp_radio_button_update gimp_radio_group_new gimp_radio_group_new2 gimp_radio_group_set_active gimp_random_seed_new gimp_rect_select gimp_rectangle_intersect gimp_register_file_handler_mime gimp_register_load_handler gimp_register_magic_load_handler gimp_register_save_handler gimp_register_thumbnail_loader gimp_repeat_mode_get_type gimp_rgb_add gimp_rgb_clamp gimp_rgb_composite gimp_rgb_distance gimp_rgb_gamma gimp_rgb_get_type gimp_rgb_get_uchar gimp_rgb_list_names gimp_rgb_luminance gimp_rgb_luminance_uchar gimp_rgb_max gimp_rgb_min gimp_rgb_multiply gimp_rgb_parse_css gimp_rgb_parse_hex gimp_rgb_parse_name gimp_rgb_set gimp_rgb_set_alpha gimp_rgb_set_uchar gimp_rgb_subtract gimp_rgb_to_cmyk gimp_rgb_to_cmyk_int gimp_rgb_to_hsl gimp_rgb_to_hsl_int gimp_rgb_to_hsv gimp_rgb_to_hsv4 gimp_rgb_to_hsv_int gimp_rgb_to_hwb gimp_rgb_to_l_int gimp_rgba_add gimp_rgba_distance gimp_rgba_get_uchar gimp_rgba_multiply gimp_rgba_parse_css gimp_rgba_set gimp_rgba_set_uchar gimp_rgba_subtract gimp_rgn_iterate1 gimp_rgn_iterate2 gimp_rgn_iterator_dest gimp_rgn_iterator_free gimp_rgn_iterator_new gimp_rgn_iterator_src gimp_rgn_iterator_src_dest gimp_rotation_type_get_type gimp_round_rect_select gimp_ruler_get_position gimp_ruler_get_range gimp_ruler_get_type gimp_ruler_get_unit gimp_ruler_new gimp_ruler_set_position gimp_ruler_set_range gimp_ruler_set_unit gimp_run_mode_get_type gimp_run_procedure gimp_run_procedure2 gimp_scale_entry_get_logarithmic gimp_scale_entry_new gimp_scale_entry_set_logarithmic gimp_scale_entry_set_sensitive gimp_scanner_destroy gimp_scanner_new_file gimp_scanner_new_string gimp_scanner_parse_color gimp_scanner_parse_data gimp_scanner_parse_float gimp_scanner_parse_identifier gimp_scanner_parse_int gimp_scanner_parse_matrix2 gimp_scanner_parse_string gimp_scanner_parse_string_no_validate gimp_scanner_parse_token gimp_scrolled_preview_freeze gimp_scrolled_preview_get_type gimp_scrolled_preview_set_policy gimp_scrolled_preview_set_position gimp_scrolled_preview_thaw gimp_select_button_close_popup gimp_select_button_get_type gimp_select_criterion_get_type gimp_selection_all gimp_selection_border gimp_selection_bounds gimp_selection_combine gimp_selection_feather gimp_selection_float gimp_selection_grow gimp_selection_invert gimp_selection_is_empty gimp_selection_layer_alpha gimp_selection_load gimp_selection_none gimp_selection_save gimp_selection_sharpen gimp_selection_shrink gimp_selection_translate gimp_selection_value gimp_shm_ID gimp_shm_addr gimp_show_help_button gimp_show_tool_tips gimp_signal_private gimp_size_entry_add_field gimp_size_entry_attach_label gimp_size_entry_get_help_widget gimp_size_entry_get_refval gimp_size_entry_get_type gimp_size_entry_get_unit gimp_size_entry_get_value gimp_size_entry_grab_focus gimp_size_entry_new gimp_size_entry_set_activates_default gimp_size_entry_set_pixel_digits gimp_size_entry_set_refval gimp_size_entry_set_refval_boundaries gimp_size_entry_set_refval_digits gimp_size_entry_set_resolution gimp_size_entry_set_size gimp_size_entry_set_unit gimp_size_entry_set_value gimp_size_entry_set_value_boundaries gimp_size_entry_show_unit_menu gimp_size_entry_update_policy_get_type gimp_size_type_get_type gimp_smudge gimp_smudge_default gimp_spin_button_new gimp_stack_trace_mode_get_type gimp_standard_help_func gimp_stock_init gimp_string_combo_box_get_active gimp_string_combo_box_get_type gimp_string_combo_box_new gimp_string_combo_box_set_active gimp_strip_uline gimp_sysconf_directory gimp_table_attach_aligned gimp_temp_name gimp_text_direction_get_type gimp_text_fontname gimp_text_get_extents_fontname gimp_text_justification_get_type gimp_text_layer_get_antialias gimp_text_layer_get_base_direction gimp_text_layer_get_color gimp_text_layer_get_font gimp_text_layer_get_font_size gimp_text_layer_get_hinting gimp_text_layer_get_indent gimp_text_layer_get_justification gimp_text_layer_get_kerning gimp_text_layer_get_language gimp_text_layer_get_letter_spacing gimp_text_layer_get_line_spacing gimp_text_layer_get_text gimp_text_layer_new gimp_text_layer_set_antialias gimp_text_layer_set_base_direction gimp_text_layer_set_color gimp_text_layer_set_font gimp_text_layer_set_font_size gimp_text_layer_set_hinting gimp_text_layer_set_indent gimp_text_layer_set_justification gimp_text_layer_set_kerning gimp_text_layer_set_language gimp_text_layer_set_letter_spacing gimp_text_layer_set_line_spacing gimp_text_layer_set_text gimp_threshold gimp_thumb_ensure_thumb_dir gimp_thumb_ensure_thumb_dir_local gimp_thumb_error_quark gimp_thumb_file_test gimp_thumb_file_type_get_type gimp_thumb_find_thumb gimp_thumb_get_thumb_dir gimp_thumb_get_thumb_dir_local gimp_thumb_init gimp_thumb_name_from_uri gimp_thumb_name_from_uri_local gimp_thumb_size_get_type gimp_thumb_state_get_type gimp_thumbnail_check_thumb gimp_thumbnail_delete_failure gimp_thumbnail_delete_others gimp_thumbnail_get_type gimp_thumbnail_has_failed gimp_thumbnail_load_thumb gimp_thumbnail_new gimp_thumbnail_peek_image gimp_thumbnail_peek_thumb gimp_thumbnail_save_failure gimp_thumbnail_save_thumb gimp_thumbnail_save_thumb_local gimp_thumbnail_set_filename gimp_thumbnail_set_from_thumb gimp_thumbnail_set_uri gimp_thumbs_delete_for_uri gimp_thumbs_delete_for_uri_local gimp_tile_cache_ntiles gimp_tile_cache_size gimp_tile_flush gimp_tile_height gimp_tile_ref gimp_tile_ref_zero gimp_tile_unref gimp_tile_width gimp_toggle_button_sensitive_update gimp_toggle_button_update gimp_transfer_mode_get_type gimp_transform_direction_get_type gimp_transform_resize_get_type gimp_type_get_translation_domain gimp_type_set_translation_domain gimp_ui_get_display_window gimp_ui_get_progress_window gimp_ui_init gimp_uint_adjustment_update gimp_uninstall_temp_proc gimp_unit_get_abbreviation gimp_unit_get_deletion_flag gimp_unit_get_digits gimp_unit_get_factor gimp_unit_get_identifier gimp_unit_get_number_of_built_in_units gimp_unit_get_number_of_units gimp_unit_get_plural gimp_unit_get_singular gimp_unit_get_symbol gimp_unit_get_type gimp_unit_menu_get_pixel_digits gimp_unit_menu_get_type gimp_unit_menu_get_unit gimp_unit_menu_new gimp_unit_menu_set_pixel_digits gimp_unit_menu_set_unit gimp_unit_menu_update gimp_unit_new gimp_unit_set_deletion_flag gimp_user_time gimp_utf8_strtrim gimp_value_get_rgb gimp_value_set_rgb gimp_vector2_add gimp_vector2_add_val gimp_vector2_cross_product gimp_vector2_cross_product_val gimp_vector2_inner_product gimp_vector2_inner_product_val gimp_vector2_length gimp_vector2_length_val gimp_vector2_mul gimp_vector2_mul_val gimp_vector2_neg gimp_vector2_neg_val gimp_vector2_new gimp_vector2_normalize gimp_vector2_normalize_val gimp_vector2_rotate gimp_vector2_rotate_val gimp_vector2_set gimp_vector2_sub gimp_vector2_sub_val gimp_vector3_add gimp_vector3_add_val gimp_vector3_cross_product gimp_vector3_cross_product_val gimp_vector3_inner_product gimp_vector3_inner_product_val gimp_vector3_length gimp_vector3_length_val gimp_vector3_mul gimp_vector3_mul_val gimp_vector3_neg gimp_vector3_neg_val gimp_vector3_new gimp_vector3_normalize gimp_vector3_normalize_val gimp_vector3_rotate gimp_vector3_rotate_val gimp_vector3_set gimp_vector3_sub gimp_vector3_sub_val gimp_vector_2d_to_3d gimp_vector_2d_to_3d_val gimp_vector_3d_to_2d gimp_vectors_bezier_stroke_conicto gimp_vectors_bezier_stroke_cubicto gimp_vectors_bezier_stroke_lineto gimp_vectors_bezier_stroke_new_ellipse gimp_vectors_bezier_stroke_new_moveto gimp_vectors_combo_box_get_type gimp_vectors_combo_box_new gimp_vectors_copy gimp_vectors_export_to_file gimp_vectors_export_to_string gimp_vectors_get_image gimp_vectors_get_linked gimp_vectors_get_name gimp_vectors_get_strokes gimp_vectors_get_tattoo gimp_vectors_get_visible gimp_vectors_import_from_file gimp_vectors_import_from_string gimp_vectors_is_valid gimp_vectors_new gimp_vectors_new_from_text_layer gimp_vectors_parasite_attach gimp_vectors_parasite_detach gimp_vectors_parasite_find gimp_vectors_parasite_list gimp_vectors_remove_stroke gimp_vectors_set_linked gimp_vectors_set_name gimp_vectors_set_tattoo gimp_vectors_set_visible gimp_vectors_stroke_close gimp_vectors_stroke_flip gimp_vectors_stroke_flip_free gimp_vectors_stroke_get_length gimp_vectors_stroke_get_point_at_dist gimp_vectors_stroke_get_points gimp_vectors_stroke_interpolate gimp_vectors_stroke_new_from_points gimp_vectors_stroke_rotate gimp_vectors_stroke_scale gimp_vectors_stroke_translate gimp_vectors_stroke_type_get_type gimp_vectors_to_selection gimp_version gimp_window_set_transient gimp_window_set_transient_for_display gimp_wm_class gimp_zoom_button_new gimp_zoom_model_get_factor gimp_zoom_model_get_fraction gimp_zoom_model_get_type gimp_zoom_model_new gimp_zoom_model_set_range gimp_zoom_model_zoom gimp_zoom_model_zoom_step gimp_zoom_preview_get_drawable gimp_zoom_preview_get_factor gimp_zoom_preview_get_model gimp_zoom_preview_get_source gimp_zoom_preview_get_type gimp_zoom_preview_new gimp_zoom_preview_new_with_model gimp_zoom_type_get_type
syn keyword gimpTypedef GimpDrawableConstraintFunc GimpVectorsConstraintFunc
syn keyword gimpConstant GIMP_ABSOLUTE_CONVOL GIMP_ADDITION_MODE GIMP_ADD_ALPHA_MASK GIMP_ADD_ALPHA_TRANSFER_MASK GIMP_ADD_BLACK_MASK GIMP_ADD_CHANNEL_MASK GIMP_ADD_COPY_MASK GIMP_ADD_SELECTION_MASK GIMP_ADD_WHITE_MASK GIMP_ALL_HUES GIMP_ALPHA_CHANNEL GIMP_ASPECT_LANDSCAPE GIMP_ASPECT_PORTRAIT GIMP_ASPECT_SQUARE GIMP_BACKGROUND_FILL GIMP_BEHIND_MODE GIMP_BG_BUCKET_FILL GIMP_BLUE_CHANNEL GIMP_BLUE_HUES GIMP_BLUR_CONVOLVE GIMP_BRUSH_GENERATED_CIRCLE GIMP_BRUSH_GENERATED_DIAMOND GIMP_BRUSH_GENERATED_SQUARE GIMP_BRUSH_HARD GIMP_BRUSH_SOFT GIMP_BURN GIMP_BURN_MODE GIMP_CHAIN_BOTTOM GIMP_CHAIN_LEFT GIMP_CHAIN_RIGHT GIMP_CHAIN_TOP GIMP_CHANNEL_OP_ADD GIMP_CHANNEL_OP_INTERSECT GIMP_CHANNEL_OP_REPLACE GIMP_CHANNEL_OP_SUBTRACT GIMP_CHECK_SIZE_LARGE_CHECKS GIMP_CHECK_SIZE_MEDIUM_CHECKS GIMP_CHECK_SIZE_SMALL_CHECKS GIMP_CHECK_TYPE_BLACK_ONLY GIMP_CHECK_TYPE_DARK_CHECKS GIMP_CHECK_TYPE_GRAY_CHECKS GIMP_CHECK_TYPE_GRAY_ONLY GIMP_CHECK_TYPE_LIGHT_CHECKS GIMP_CHECK_TYPE_WHITE_ONLY GIMP_CLIP_TO_BOTTOM_LAYER GIMP_CLIP_TO_IMAGE GIMP_COLOR_AREA_FLAT GIMP_COLOR_AREA_LARGE_CHECKS GIMP_COLOR_AREA_SMALL_CHECKS GIMP_COLOR_ERASE_MODE GIMP_COLOR_MANAGEMENT_DISPLAY GIMP_COLOR_MANAGEMENT_OFF GIMP_COLOR_MANAGEMENT_SOFTPROOF GIMP_COLOR_MODE GIMP_COLOR_RENDERING_INTENT_ABSOLUTE_COLORIMETRIC GIMP_COLOR_RENDERING_INTENT_PERCEPTUAL GIMP_COLOR_RENDERING_INTENT_RELATIVE_COLORIMETRIC GIMP_COLOR_RENDERING_INTENT_SATURATION GIMP_COLOR_SELECTOR_ALPHA GIMP_COLOR_SELECTOR_BLUE GIMP_COLOR_SELECTOR_GREEN GIMP_COLOR_SELECTOR_HUE GIMP_COLOR_SELECTOR_RED GIMP_COLOR_SELECTOR_SATURATION GIMP_COLOR_SELECTOR_VALUE GIMP_CONFIG_ERROR_OPEN GIMP_CONFIG_ERROR_OPEN_ENOENT GIMP_CONFIG_ERROR_PARSE GIMP_CONFIG_ERROR_VERSION GIMP_CONFIG_ERROR_WRITE GIMP_CONFIG_PATH_DIR GIMP_CONFIG_PATH_DIR_LIST GIMP_CONFIG_PATH_FILE GIMP_CONFIG_PATH_FILE_LIST GIMP_CONSOLE GIMP_CONTROLLER_EVENT_TRIGGER GIMP_CONTROLLER_EVENT_VALUE GIMP_CPU_ACCEL_NONE GIMP_CPU_ACCEL_PPC_ALTIVEC GIMP_CPU_ACCEL_X86_3DNOW GIMP_CPU_ACCEL_X86_MMX GIMP_CPU_ACCEL_X86_MMXEXT GIMP_CPU_ACCEL_X86_SSE GIMP_CPU_ACCEL_X86_SSE2 GIMP_CPU_ACCEL_X86_SSE3 GIMP_CUSTOM_MODE GIMP_CUSTOM_PALETTE GIMP_CYAN_HUES GIMP_DARKEN_ONLY_MODE GIMP_DESATURATE_AVERAGE GIMP_DESATURATE_LIGHTNESS GIMP_DESATURATE_LUMINOSITY GIMP_DIFFERENCE_MODE GIMP_DISSOLVE_MODE GIMP_DIVIDE_MODE GIMP_DODGE GIMP_DODGE_MODE GIMP_ERROR_CONSOLE GIMP_EXPAND_AS_NECESSARY GIMP_EXPORT_CANCEL GIMP_EXPORT_CAN_HANDLE_ALPHA GIMP_EXPORT_CAN_HANDLE_BITMAP GIMP_EXPORT_CAN_HANDLE_GRAY GIMP_EXPORT_CAN_HANDLE_INDEXED GIMP_EXPORT_CAN_HANDLE_LAYERS GIMP_EXPORT_CAN_HANDLE_LAYERS_AS_ANIMATION GIMP_EXPORT_CAN_HANDLE_LAYER_MASKS GIMP_EXPORT_CAN_HANDLE_RGB GIMP_EXPORT_EXPORT GIMP_EXPORT_IGNORE GIMP_EXPORT_NEEDS_ALPHA GIMP_EXTENSION GIMP_FG_BG_HSV_MODE GIMP_FG_BG_RGB_MODE GIMP_FG_BUCKET_FILL GIMP_FG_TRANSPARENT_MODE GIMP_FIXED_DITHER GIMP_FLATTEN_IMAGE GIMP_FOREGROUND_EXTRACT_SIOX GIMP_FOREGROUND_FILL GIMP_FSLOWBLEED_DITHER GIMP_FS_DITHER GIMP_GRADIENT_BILINEAR GIMP_GRADIENT_CONICAL_ASYMMETRIC GIMP_GRADIENT_CONICAL_SYMMETRIC GIMP_GRADIENT_LINEAR GIMP_GRADIENT_RADIAL GIMP_GRADIENT_SEGMENT_CURVED GIMP_GRADIENT_SEGMENT_HSV_CCW GIMP_GRADIENT_SEGMENT_HSV_CW GIMP_GRADIENT_SEGMENT_LINEAR GIMP_GRADIENT_SEGMENT_RGB GIMP_GRADIENT_SEGMENT_SINE GIMP_GRADIENT_SEGMENT_SPHERE_DECREASING GIMP_GRADIENT_SEGMENT_SPHERE_INCREASING GIMP_GRADIENT_SHAPEBURST_ANGULAR GIMP_GRADIENT_SHAPEBURST_DIMPLED GIMP_GRADIENT_SHAPEBURST_SPHERICAL GIMP_GRADIENT_SPIRAL_ANTICLOCKWISE GIMP_GRADIENT_SPIRAL_CLOCKWISE GIMP_GRADIENT_SQUARE GIMP_GRAIN_EXTRACT_MODE GIMP_GRAIN_MERGE_MODE GIMP_GRAY GIMP_GRAYA_IMAGE GIMP_GRAY_CHANNEL GIMP_GRAY_IMAGE GIMP_GREEN_CHANNEL GIMP_GREEN_HUES GIMP_GRID_DOTS GIMP_GRID_DOUBLE_DASH GIMP_GRID_INTERSECTIONS GIMP_GRID_ON_OFF_DASH GIMP_GRID_SOLID GIMP_HARDLIGHT_MODE GIMP_HIGHLIGHTS GIMP_HISTOGRAM_ALPHA GIMP_HISTOGRAM_BLUE GIMP_HISTOGRAM_GREEN GIMP_HISTOGRAM_RED GIMP_HISTOGRAM_VALUE GIMP_HUE_MODE GIMP_ICON_TYPE_IMAGE_FILE GIMP_ICON_TYPE_INLINE_PIXBUF GIMP_ICON_TYPE_STOCK_ID GIMP_IMAGE_CLONE GIMP_INDEXED GIMP_INDEXEDA_IMAGE GIMP_INDEXED_CHANNEL GIMP_INDEXED_IMAGE GIMP_INTERNAL GIMP_INTERPOLATION_CUBIC GIMP_INTERPOLATION_LANCZOS GIMP_INTERPOLATION_LINEAR GIMP_INTERPOLATION_NONE GIMP_INT_STORE_LABEL GIMP_INT_STORE_NUM_COLUMNS GIMP_INT_STORE_PIXBUF GIMP_INT_STORE_STOCK_ID GIMP_INT_STORE_USER_DATA GIMP_INT_STORE_VALUE GIMP_LIGHTEN_ONLY_MODE GIMP_MAGENTA_HUES GIMP_MAKE_PALETTE GIMP_MASK_APPLY GIMP_MASK_DISCARD GIMP_MESSAGE_BOX GIMP_MIDTONES GIMP_MODULE_STATE_ERROR GIMP_MODULE_STATE_LOADED GIMP_MODULE_STATE_LOAD_FAILED GIMP_MODULE_STATE_NOT_LOADED GIMP_MONO_PALETTE GIMP_MULTIPLY_MODE GIMP_NEGATIVE_CONVOL GIMP_NORMAL_CONVOL GIMP_NORMAL_MODE GIMP_NO_DITHER GIMP_OFFSET_BACKGROUND GIMP_OFFSET_TRANSPARENT GIMP_ORIENTATION_HORIZONTAL GIMP_ORIENTATION_UNKNOWN GIMP_ORIENTATION_VERTICAL GIMP_OVERLAY_MODE GIMP_PAGE_SELECTOR_TARGET_IMAGES GIMP_PAGE_SELECTOR_TARGET_LAYERS GIMP_PAINT_CONSTANT GIMP_PAINT_INCREMENTAL GIMP_PATTERN_BUCKET_FILL GIMP_PATTERN_CLONE GIMP_PATTERN_FILL GIMP_PDB_BOUNDARY GIMP_PDB_CALLING_ERROR GIMP_PDB_CANCEL GIMP_PDB_CHANNEL GIMP_PDB_COLOR GIMP_PDB_COLORARRAY GIMP_PDB_DISPLAY GIMP_PDB_DRAWABLE GIMP_PDB_END GIMP_PDB_ERROR_HANDLER_INTERNAL GIMP_PDB_ERROR_HANDLER_PLUGIN GIMP_PDB_EXECUTION_ERROR GIMP_PDB_FLOAT GIMP_PDB_FLOATARRAY GIMP_PDB_IMAGE GIMP_PDB_INT16 GIMP_PDB_INT16ARRAY GIMP_PDB_INT32 GIMP_PDB_INT32ARRAY GIMP_PDB_INT8 GIMP_PDB_INT8ARRAY GIMP_PDB_LAYER GIMP_PDB_PARASITE GIMP_PDB_PASS_THROUGH GIMP_PDB_PATH GIMP_PDB_REGION GIMP_PDB_SELECTION GIMP_PDB_STATUS GIMP_PDB_STRING GIMP_PDB_STRINGARRAY GIMP_PDB_SUCCESS GIMP_PDB_VECTORS GIMP_PIXBUF_KEEP_ALPHA GIMP_PIXBUF_LARGE_CHECKS GIMP_PIXBUF_SMALL_CHECKS GIMP_PIXELS GIMP_PIXEL_FETCHER_EDGE_BACKGROUND GIMP_PIXEL_FETCHER_EDGE_BLACK GIMP_PIXEL_FETCHER_EDGE_NONE GIMP_PIXEL_FETCHER_EDGE_SMEAR GIMP_PIXEL_FETCHER_EDGE_WRAP GIMP_PLUGIN GIMP_POINTS GIMP_PROGRESS_COMMAND_END GIMP_PROGRESS_COMMAND_GET_WINDOW GIMP_PROGRESS_COMMAND_PULSE GIMP_PROGRESS_COMMAND_SET_TEXT GIMP_PROGRESS_COMMAND_SET_VALUE GIMP_PROGRESS_COMMAND_START GIMP_RED_CHANNEL GIMP_RED_HUES GIMP_REPEAT_NONE GIMP_REPEAT_SAWTOOTH GIMP_REPEAT_TRIANGULAR GIMP_REUSE_PALETTE GIMP_RGB GIMP_RGBA_IMAGE GIMP_RGB_COMPOSITE_BEHIND GIMP_RGB_COMPOSITE_NONE GIMP_RGB_COMPOSITE_NORMAL GIMP_RGB_IMAGE GIMP_ROTATE_180 GIMP_ROTATE_270 GIMP_ROTATE_90 GIMP_RUN_INTERACTIVE GIMP_RUN_NONINTERACTIVE GIMP_RUN_WITH_LAST_VALS GIMP_SATURATION_MODE GIMP_SCREEN_MODE GIMP_SELECT_CRITERION_B GIMP_SELECT_CRITERION_COMPOSITE GIMP_SELECT_CRITERION_G GIMP_SELECT_CRITERION_H GIMP_SELECT_CRITERION_R GIMP_SELECT_CRITERION_S GIMP_SELECT_CRITERION_V GIMP_SHADOWS GIMP_SHARPEN_CONVOLVE GIMP_SIZE_ENTRY_UPDATE_NONE GIMP_SIZE_ENTRY_UPDATE_RESOLUTION GIMP_SIZE_ENTRY_UPDATE_SIZE GIMP_SOFTLIGHT_MODE GIMP_STACK_TRACE_ALWAYS GIMP_STACK_TRACE_NEVER GIMP_STACK_TRACE_QUERY GIMP_SUBTRACT_MODE GIMP_TEMPORARY GIMP_TEXT_DIRECTION_LTR GIMP_TEXT_DIRECTION_RTL GIMP_TEXT_JUSTIFY_CENTER GIMP_TEXT_JUSTIFY_FILL GIMP_TEXT_JUSTIFY_LEFT GIMP_TEXT_JUSTIFY_RIGHT GIMP_THUMB_ERROR_MKDIR GIMP_THUMB_ERROR_OPEN GIMP_THUMB_ERROR_OPEN_ENOENT GIMP_THUMB_FILE_TYPE_FOLDER GIMP_THUMB_FILE_TYPE_NONE GIMP_THUMB_FILE_TYPE_REGULAR GIMP_THUMB_FILE_TYPE_SPECIAL GIMP_THUMB_SIZE_FAIL GIMP_THUMB_SIZE_LARGE GIMP_THUMB_SIZE_NORMAL GIMP_THUMB_STATE_EXISTS GIMP_THUMB_STATE_FAILED GIMP_THUMB_STATE_FOLDER GIMP_THUMB_STATE_NOT_FOUND GIMP_THUMB_STATE_OK GIMP_THUMB_STATE_OLD GIMP_THUMB_STATE_REMOTE GIMP_THUMB_STATE_SPECIAL GIMP_THUMB_STATE_UNKNOWN GIMP_TRANSFORM_BACKWARD GIMP_TRANSFORM_FORWARD GIMP_TRANSFORM_RESIZE_ADJUST GIMP_TRANSFORM_RESIZE_CLIP GIMP_TRANSFORM_RESIZE_CROP GIMP_TRANSFORM_RESIZE_CROP_WITH_ASPECT GIMP_TRANSPARENT_FILL GIMP_UNIT_END GIMP_UNIT_INCH GIMP_UNIT_MM GIMP_UNIT_PERCENT GIMP_UNIT_PICA GIMP_UNIT_PIXEL GIMP_UNIT_POINT GIMP_VALUE_MODE GIMP_VECTORS_STROKE_TYPE_BEZIER GIMP_WEB_PALETTE GIMP_WHITE_FILL GIMP_YELLOW_HUES GIMP_ZOOM_IN GIMP_ZOOM_IN_MAX GIMP_ZOOM_IN_MORE GIMP_ZOOM_OUT GIMP_ZOOM_OUT_MAX GIMP_ZOOM_OUT_MORE GIMP_ZOOM_TO
syn keyword gimpStruct GimpAspectPreview GimpAspectPreviewClass GimpBrowser GimpBrowserClass GimpBrushSelectButton GimpBrushSelectButtonClass GimpButton GimpButtonClass GimpCMYK GimpCellRendererColor GimpCellRendererColorClass GimpCellRendererToggle GimpCellRendererToggleClass GimpChainButton GimpChainButtonClass GimpChannelComboBox GimpColorArea GimpColorAreaClass GimpColorButton GimpColorButtonClass GimpColorConfig GimpColorConfigClass GimpColorDisplay GimpColorDisplayClass GimpColorDisplayStack GimpColorDisplayStackClass GimpColorHexEntry GimpColorHexEntryClass GimpColorManaged GimpColorManagedInterface GimpColorNotebook GimpColorNotebookClass GimpColorProfileComboBox GimpColorProfileComboBoxClass GimpColorProfileStore GimpColorProfileStoreClass GimpColorScale GimpColorScaleClass GimpColorScales GimpColorSelect GimpColorSelection GimpColorSelectionClass GimpColorSelector GimpColorSelectorClass GimpConfig GimpConfigInterface GimpConfigWriter GimpController GimpControllerClass GimpControllerEventAny GimpControllerEventTrigger GimpControllerEventValue GimpDatafileData GimpDialog GimpDialogClass GimpDrawable GimpDrawableComboBox GimpDrawablePreview GimpDrawablePreviewClass GimpEnumComboBox GimpEnumComboBoxClass GimpEnumDesc GimpEnumLabel GimpEnumLabelClass GimpEnumStore GimpEnumStoreClass GimpFlagsDesc GimpFontSelectButton GimpFontSelectButtonClass GimpFrame GimpFrameClass GimpGradientSelectButton GimpGradientSelectButtonClass GimpHSL GimpHSV GimpImageComboBox GimpIntComboBox GimpIntComboBoxClass GimpIntStore GimpIntStoreClass GimpLayerComboBox GimpMatrix2 GimpMatrix3 GimpMatrix4 GimpMemsizeEntry GimpMemsizeEntryClass GimpModule GimpModuleClass GimpModuleDB GimpModuleDBClass GimpModuleInfo GimpNumberPairEntry GimpNumberPairEntryClass GimpOffsetArea GimpOffsetAreaClass GimpPageSelector GimpPageSelectorClass GimpPaletteSelectButton GimpPaletteSelectButtonClass GimpParam GimpParamDef GimpParamRegion GimpParasite GimpPathEditor GimpPathEditorClass GimpPatternSelectButton GimpPatternSelectButtonClass GimpPickButton GimpPickButtonClass GimpPixelFetcher GimpPixelRgn GimpPlugInInfo GimpPreview GimpPreviewArea GimpPreviewAreaClass GimpPreviewClass GimpProcBrowserDialog GimpProcBrowserDialogClass GimpProgressBar GimpProgressBarClass GimpProgressVtable GimpRGB GimpRgnIterator GimpRuler GimpRulerClass GimpScrolledPreview GimpScrolledPreviewClass GimpSelectButton GimpSelectButtonClass GimpSizeEntry GimpSizeEntryClass GimpSizeEntryField GimpStringComboBox GimpStringComboBoxClass GimpThumbnail GimpThumbnailClass GimpTile GimpUnitMenu GimpUnitMenuClass GimpVector2 GimpVector3 GimpVector4 GimpVectorsComboBox GimpZoomModel GimpZoomModelClass GimpZoomPreview GimpZoomPreviewClass
syn keyword gimpUnion GimpControllerEvent GimpParamData
syn keyword gimpMacro CLAMP0255 GIMP_ASPECT_PREVIEW GIMP_ASPECT_PREVIEW_CLASS GIMP_ASPECT_PREVIEW_GET_CLASS GIMP_BROWSER GIMP_BROWSER_CLASS GIMP_BROWSER_GET_CLASS GIMP_BRUSH_SELECT_BUTTON GIMP_BRUSH_SELECT_BUTTON_CLASS GIMP_BRUSH_SELECT_BUTTON_GET_CLASS GIMP_BUTTON GIMP_BUTTON_CLASS GIMP_BUTTON_GET_CLASS GIMP_CAIRO_ARGB32_SET_PIXEL GIMP_CAIRO_RGB24_SET_PIXEL GIMP_CELL_RENDERER_COLOR GIMP_CELL_RENDERER_COLOR_CLASS GIMP_CELL_RENDERER_COLOR_GET_CLASS GIMP_CELL_RENDERER_TOGGLE GIMP_CELL_RENDERER_TOGGLE_CLASS GIMP_CELL_RENDERER_TOGGLE_GET_CLASS GIMP_CHAIN_BUTTON GIMP_CHAIN_BUTTON_CLASS GIMP_CHAIN_BUTTON_GET_CLASS GIMP_CHANNEL_COMBO_BOX GIMP_CHECK_VERSION GIMP_COLOR_AREA GIMP_COLOR_AREA_CLASS GIMP_COLOR_AREA_GET_CLASS GIMP_COLOR_BUTTON GIMP_COLOR_BUTTON_CLASS GIMP_COLOR_BUTTON_GET_CLASS GIMP_COLOR_CONFIG GIMP_COLOR_CONFIG_CLASS GIMP_COLOR_DISPLAY GIMP_COLOR_DISPLAY_CLASS GIMP_COLOR_DISPLAY_GET_CLASS GIMP_COLOR_DISPLAY_STACK GIMP_COLOR_DISPLAY_STACK_CLASS GIMP_COLOR_DISPLAY_STACK_GET_CLASS GIMP_COLOR_HEX_ENTRY GIMP_COLOR_HEX_ENTRY_CLASS GIMP_COLOR_HEX_ENTRY_GET_CLASS GIMP_COLOR_MANAGED GIMP_COLOR_MANAGED_GET_INTERFACE GIMP_COLOR_NOTEBOOK GIMP_COLOR_NOTEBOOK_CLASS GIMP_COLOR_NOTEBOOK_GET_CLASS GIMP_COLOR_PROFILE_COMBO_BOX GIMP_COLOR_PROFILE_COMBO_BOX_CLASS GIMP_COLOR_PROFILE_COMBO_BOX_GET_CLASS GIMP_COLOR_PROFILE_STORE GIMP_COLOR_PROFILE_STORE_CLASS GIMP_COLOR_PROFILE_STORE_GET_CLASS GIMP_COLOR_SCALE GIMP_COLOR_SCALES GIMP_COLOR_SCALE_CLASS GIMP_COLOR_SCALE_GET_CLASS GIMP_COLOR_SELECT GIMP_COLOR_SELECTION GIMP_COLOR_SELECTION_CLASS GIMP_COLOR_SELECTION_GET_CLASS GIMP_COLOR_SELECTOR GIMP_COLOR_SELECTOR_CLASS GIMP_COLOR_SELECTOR_GET_CLASS GIMP_CONFIG GIMP_CONFIG_GET_INTERFACE GIMP_CONFIG_INSTALL_PROP_BOOLEAN GIMP_CONFIG_INSTALL_PROP_BOXED GIMP_CONFIG_INSTALL_PROP_DOUBLE GIMP_CONFIG_INSTALL_PROP_ENUM GIMP_CONFIG_INSTALL_PROP_INT GIMP_CONFIG_INSTALL_PROP_MATRIX2 GIMP_CONFIG_INSTALL_PROP_MEMSIZE GIMP_CONFIG_INSTALL_PROP_OBJECT GIMP_CONFIG_INSTALL_PROP_PATH GIMP_CONFIG_INSTALL_PROP_POINTER GIMP_CONFIG_INSTALL_PROP_RESOLUTION GIMP_CONFIG_INSTALL_PROP_RGB GIMP_CONFIG_INSTALL_PROP_STRING GIMP_CONFIG_INSTALL_PROP_UINT GIMP_CONFIG_INSTALL_PROP_UNIT GIMP_CONTROLLER GIMP_CONTROLLER_CLASS GIMP_CONTROLLER_GET_CLASS GIMP_COORDINATES_CHAINBUTTON GIMP_DIALOG GIMP_DIALOG_CLASS GIMP_DIALOG_GET_CLASS GIMP_DRAWABLE_COMBO_BOX GIMP_DRAWABLE_PREVIEW GIMP_DRAWABLE_PREVIEW_CLASS GIMP_DRAWABLE_PREVIEW_GET_CLASS GIMP_ENUM_COMBO_BOX GIMP_ENUM_COMBO_BOX_CLASS GIMP_ENUM_COMBO_BOX_GET_CLASS GIMP_ENUM_LABEL GIMP_ENUM_LABEL_CLASS GIMP_ENUM_LABEL_GET_CLASS GIMP_ENUM_STORE GIMP_ENUM_STORE_CLASS GIMP_ENUM_STORE_GET_CLASS GIMP_FONT_SELECT_BUTTON GIMP_FONT_SELECT_BUTTON_CLASS GIMP_FONT_SELECT_BUTTON_GET_CLASS GIMP_FRAME GIMP_FRAME_CLASS GIMP_FRAME_GET_CLASS GIMP_GRADIENT_SELECT_BUTTON GIMP_GRADIENT_SELECT_BUTTON_CLASS GIMP_GRADIENT_SELECT_BUTTON_GET_CLASS GIMP_IMAGE_COMBO_BOX GIMP_INT_COMBO_BOX GIMP_INT_COMBO_BOX_CLASS GIMP_INT_COMBO_BOX_GET_CLASS GIMP_INT_STORE GIMP_INT_STORE_CLASS GIMP_INT_STORE_GET_CLASS GIMP_IS_ASPECT_PREVIEW GIMP_IS_ASPECT_PREVIEW_CLASS GIMP_IS_BROWSER GIMP_IS_BROWSER_CLASS GIMP_IS_BRUSH_SELECT_BUTTON GIMP_IS_BRUSH_SELECT_BUTTON_CLASS GIMP_IS_BUTTON GIMP_IS_BUTTON_CLASS GIMP_IS_CELL_RENDERER_COLOR GIMP_IS_CELL_RENDERER_COLOR_CLASS GIMP_IS_CELL_RENDERER_TOGGLE GIMP_IS_CELL_RENDERER_TOGGLE_CLASS GIMP_IS_CHAIN_BUTTON GIMP_IS_CHAIN_BUTTON_CLASS GIMP_IS_CHANNEL_COMBO_BOX GIMP_IS_COLOR_AREA GIMP_IS_COLOR_AREA_CLASS GIMP_IS_COLOR_BUTTON GIMP_IS_COLOR_BUTTON_CLASS GIMP_IS_COLOR_CONFIG GIMP_IS_COLOR_CONFIG_CLASS GIMP_IS_COLOR_DISPLAY GIMP_IS_COLOR_DISPLAY_CLASS GIMP_IS_COLOR_DISPLAY_STACK GIMP_IS_COLOR_DISPLAY_STACK_CLASS GIMP_IS_COLOR_HEX_ENTRY GIMP_IS_COLOR_HEX_ENTRY_CLASS GIMP_IS_COLOR_MANAGED GIMP_IS_COLOR_NOTEBOOK GIMP_IS_COLOR_NOTEBOOK_CLASS GIMP_IS_COLOR_PROFILE_COMBO_BOX GIMP_IS_COLOR_PROFILE_COMBO_BOX_CLASS GIMP_IS_COLOR_PROFILE_STORE GIMP_IS_COLOR_PROFILE_STORE_CLASS GIMP_IS_COLOR_SCALE GIMP_IS_COLOR_SCALES GIMP_IS_COLOR_SCALE_CLASS GIMP_IS_COLOR_SELECT GIMP_IS_COLOR_SELECTION GIMP_IS_COLOR_SELECTION_CLASS GIMP_IS_COLOR_SELECTOR GIMP_IS_COLOR_SELECTOR_CLASS GIMP_IS_CONFIG GIMP_IS_CONTROLLER GIMP_IS_CONTROLLER_CLASS GIMP_IS_DIALOG GIMP_IS_DIALOG_CLASS GIMP_IS_DRAWABLE_COMBO_BOX GIMP_IS_DRAWABLE_PREVIEW GIMP_IS_DRAWABLE_PREVIEW_CLASS GIMP_IS_ENUM_COMBO_BOX GIMP_IS_ENUM_COMBO_BOX_CLASS GIMP_IS_ENUM_LABEL GIMP_IS_ENUM_LABEL_CLASS GIMP_IS_ENUM_STORE GIMP_IS_ENUM_STORE_CLASS GIMP_IS_FONT_SELECT_BUTTON GIMP_IS_FONT_SELECT_BUTTON_CLASS GIMP_IS_FRAME GIMP_IS_FRAME_CLASS GIMP_IS_GRADIENT_SELECT_BUTTON GIMP_IS_GRADIENT_SELECT_BUTTON_CLASS GIMP_IS_IMAGE_COMBO_BOX GIMP_IS_INT_COMBO_BOX GIMP_IS_INT_COMBO_BOX_CLASS GIMP_IS_INT_STORE GIMP_IS_INT_STORE_CLASS GIMP_IS_LAYER_COMBO_BOX GIMP_IS_MEMSIZE_ENTRY GIMP_IS_MEMSIZE_ENTRY_CLASS GIMP_IS_MODULE GIMP_IS_MODULE_CLASS GIMP_IS_MODULE_DB GIMP_IS_MODULE_DB_CLASS GIMP_IS_NUMBER_PAIR_ENTRY GIMP_IS_NUMBER_PAIR_ENTRY_CLASS GIMP_IS_OFFSET_AREA GIMP_IS_OFFSET_AREA_CLASS GIMP_IS_PAGE_SELECTOR GIMP_IS_PAGE_SELECTOR_CLASS GIMP_IS_PALETTE_SELECT_BUTTON GIMP_IS_PALETTE_SELECT_BUTTON_CLASS GIMP_IS_PARAM_SPEC_CONFIG_PATH GIMP_IS_PARAM_SPEC_MATRIX2 GIMP_IS_PARAM_SPEC_MEMSIZE GIMP_IS_PARAM_SPEC_PARASITE GIMP_IS_PARAM_SPEC_RGB GIMP_IS_PARAM_SPEC_UNIT GIMP_IS_PATH_EDITOR GIMP_IS_PATH_EDITOR_CLASS GIMP_IS_PATTERN_SELECT_BUTTON GIMP_IS_PATTERN_SELECT_BUTTON_CLASS GIMP_IS_PICK_BUTTON GIMP_IS_PICK_BUTTON_CLASS GIMP_IS_PREVIEW GIMP_IS_PREVIEW_AREA GIMP_IS_PREVIEW_AREA_CLASS GIMP_IS_PREVIEW_CLASS GIMP_IS_PROC_BROWSER_DIALOG GIMP_IS_PROC_BROWSER_DIALOG_CLASS GIMP_IS_PROGRESS_BAR GIMP_IS_PROGRESS_BAR_CLASS GIMP_IS_RULER GIMP_IS_RULER_CLASS GIMP_IS_SCROLLED_PREVIEW GIMP_IS_SCROLLED_PREVIEW_CLASS GIMP_IS_SELECT_BUTTON GIMP_IS_SELECT_BUTTON_CLASS GIMP_IS_SIZE_ENTRY GIMP_IS_SIZE_ENTRY_CLASS GIMP_IS_STRING_COMBO_BOX GIMP_IS_STRING_COMBO_BOX_CLASS GIMP_IS_THUMBNAIL GIMP_IS_THUMBNAIL_CLASS GIMP_IS_UNIT_MENU GIMP_IS_UNIT_MENU_CLASS GIMP_IS_VECTORS_COMBO_BOX GIMP_IS_ZOOM_MODEL GIMP_IS_ZOOM_MODEL_CLASS GIMP_IS_ZOOM_PREVIEW GIMP_IS_ZOOM_PREVIEW_CLASS GIMP_LAYER_COMBO_BOX GIMP_MEMSIZE_ENTRY GIMP_MEMSIZE_ENTRY_CLASS GIMP_MEMSIZE_ENTRY_GET_CLASS GIMP_MODULE GIMP_MODULE_CLASS GIMP_MODULE_DB GIMP_MODULE_DB_CLASS GIMP_MODULE_DB_GET_CLASS GIMP_MODULE_GET_CLASS GIMP_NUMBER_PAIR_ENTRY GIMP_NUMBER_PAIR_ENTRY_CLASS GIMP_NUMBER_PAIR_ENTRY_GET_CLASS GIMP_OFFSET_AREA GIMP_OFFSET_AREA_CLASS GIMP_OFFSET_AREA_GET_CLASS GIMP_PAGE_SELECTOR GIMP_PAGE_SELECTOR_CLASS GIMP_PAGE_SELECTOR_GET_CLASS GIMP_PALETTE_SELECT_BUTTON GIMP_PALETTE_SELECT_BUTTON_CLASS GIMP_PALETTE_SELECT_BUTTON_GET_CLASS GIMP_PATH_EDITOR GIMP_PATH_EDITOR_CLASS GIMP_PATH_EDITOR_GET_CLASS GIMP_PATTERN_SELECT_BUTTON GIMP_PATTERN_SELECT_BUTTON_CLASS GIMP_PATTERN_SELECT_BUTTON_GET_CLASS GIMP_PICK_BUTTON GIMP_PICK_BUTTON_CLASS GIMP_PICK_BUTTON_GET_CLASS GIMP_PREVIEW GIMP_PREVIEW_AREA GIMP_PREVIEW_AREA_CLASS GIMP_PREVIEW_AREA_GET_CLASS GIMP_PREVIEW_CLASS GIMP_PREVIEW_GET_CLASS GIMP_PROC_BROWSER_DIALOG GIMP_PROC_BROWSER_DIALOG_CLASS GIMP_PROC_BROWSER_DIALOG_GET_CLASS GIMP_PROGRESS_BAR GIMP_PROGRESS_BAR_CLASS GIMP_PROGRESS_BAR_GET_CLASS GIMP_QUERY_BOX_VBOX GIMP_RANDOM_SEED_SPINBUTTON GIMP_RANDOM_SEED_SPINBUTTON_ADJ GIMP_RANDOM_SEED_TOGGLE GIMP_RGB_LUMINANCE GIMP_RULER GIMP_RULER_CLASS GIMP_RULER_GET_CLASS GIMP_SCALE_ENTRY_LABEL GIMP_SCALE_ENTRY_SCALE GIMP_SCALE_ENTRY_SCALE_ADJ GIMP_SCALE_ENTRY_SPINBUTTON GIMP_SCALE_ENTRY_SPINBUTTON_ADJ GIMP_SCROLLED_PREVIEW GIMP_SCROLLED_PREVIEW_CLASS GIMP_SCROLLED_PREVIEW_GET_CLASS GIMP_SELECT_BUTTON GIMP_SELECT_BUTTON_CLASS GIMP_SELECT_BUTTON_GET_CLASS GIMP_SIZE_ENTRY GIMP_SIZE_ENTRY_CLASS GIMP_SIZE_ENTRY_GET_CLASS GIMP_STRING_COMBO_BOX GIMP_STRING_COMBO_BOX_CLASS GIMP_STRING_COMBO_BOX_GET_CLASS GIMP_THUMBNAIL GIMP_THUMBNAIL_CLASS GIMP_THUMBNAIL_GET_CLASS GIMP_UNIT_MENU GIMP_UNIT_MENU_CLASS GIMP_UNIT_MENU_GET_CLASS GIMP_VALUE_HOLDS_CONFIG_PATH GIMP_VALUE_HOLDS_MATRIX2 GIMP_VALUE_HOLDS_MEMSIZE GIMP_VALUE_HOLDS_PARASITE GIMP_VALUE_HOLDS_RGB GIMP_VALUE_HOLDS_UNIT GIMP_VECTORS_COMBO_BOX GIMP_ZOOM_MODEL GIMP_ZOOM_MODEL_CLASS GIMP_ZOOM_MODEL_GET_CLASS GIMP_ZOOM_PREVIEW GIMP_ZOOM_PREVIEW_CLASS GIMP_ZOOM_PREVIEW_GET_CLASS MAIN MAX255 RINT ROUND SQR gimp_deg_to_rad gimp_get_data gimp_get_data_size gimp_rad_to_deg gimp_set_data
syn keyword gimpEnum GimpAddMaskType GimpAspectType GimpBlendMode GimpBrushApplicationMode GimpBrushGeneratedShape GimpBucketFillMode GimpChainPosition GimpChannelOps GimpChannelType GimpCheckSize GimpCheckType GimpCloneType GimpColorAreaType GimpColorManagementMode GimpColorRenderingIntent GimpColorSelectorChannel GimpConfigError GimpConfigPathType GimpControllerEventType GimpConvertDitherType GimpConvertPaletteType GimpConvolutionType GimpConvolveType GimpCpuAccelFlags GimpDesaturateMode GimpDodgeBurnType GimpExportCapabilities GimpExportReturn GimpFillType GimpForegroundExtractMode GimpGradientSegmentColor GimpGradientSegmentType GimpGradientType GimpGridStyle GimpHistogramChannel GimpHueRange GimpIconType GimpImageBaseType GimpImageType GimpIntStoreColumns GimpInterpolationType GimpLayerModeEffects GimpMaskApplyMode GimpMergeType GimpMessageHandlerType GimpModuleState GimpOffsetType GimpOrientationType GimpPDBArgType GimpPDBErrorHandler GimpPDBProcType GimpPDBStatusType GimpPageSelectorTarget GimpPaintApplicationMode GimpPixbufTransparency GimpPixelFetcherEdgeMode GimpProgressCommand GimpRGBCompositeMode GimpRepeatMode GimpRotationType GimpRunMode GimpSelectCriterion GimpSizeEntryUpdatePolicy GimpSizeType GimpStackTraceMode GimpTextDirection GimpTextJustification GimpThumbError GimpThumbFileType GimpThumbSize GimpThumbState GimpTransferMode GimpTransformDirection GimpTransformResize GimpUnit GimpVectorsStrokeType GimpZoomType
syn keyword gimpVariable gimp_major_version gimp_micro_version gimp_minor_version
syn keyword gimpUserFunction GimpDatafileLoaderFunc GimpHelpFunc GimpImageConstraintFunc GimpInitProc GimpIntSensitivityFunc GimpItemConstraintFunc GimpModuleQueryFunc GimpModuleRegisterFunc GimpProgressFunc GimpPutPixelFunc GimpQueryBooleanCallback GimpQueryDoubleCallback GimpQueryIntCallback GimpQueryProc GimpQuerySizeCallback GimpQueryStringCallback GimpQuitProc GimpRenderFunc GimpRgnFunc1 GimpRgnFunc2 GimpRgnFuncDest GimpRgnFuncSrc GimpRgnFuncSrcDest GimpRunBrushCallback GimpRunFontCallback GimpRunGradientCallback GimpRunPaletteCallback GimpRunPatternCallback GimpRunProc GimpSignalHandlerFunc
syn keyword gimpDefine GIMPVAR GIMP_API_VERSION GIMP_CHECK_DARK GIMP_CHECK_LIGHT GIMP_CHECK_SIZE GIMP_CHECK_SIZE_SM GIMP_COLOR_SELECTOR_BAR_SIZE GIMP_COLOR_SELECTOR_SIZE GIMP_CONFIG_ERROR GIMP_CONFIG_PARAM_AGGREGATE GIMP_CONFIG_PARAM_CONFIRM GIMP_CONFIG_PARAM_DEFAULTS GIMP_CONFIG_PARAM_FLAGS GIMP_CONFIG_PARAM_IGNORE GIMP_CONFIG_PARAM_RESTART GIMP_CONFIG_PARAM_SERIALIZE GIMP_HELP_ID GIMP_MAJOR_VERSION GIMP_MAX_IMAGE_SIZE GIMP_MAX_MEMSIZE GIMP_MAX_RESOLUTION GIMP_MICRO_VERSION GIMP_MINOR_VERSION GIMP_MIN_IMAGE_SIZE GIMP_MIN_RESOLUTION GIMP_MODULE_ABI_VERSION GIMP_PARAM_READABLE GIMP_PARAM_READWRITE GIMP_PARAM_STATIC_STRINGS GIMP_PARAM_WRITABLE GIMP_PARASITE_ATTACH_GRANDPARENT GIMP_PARASITE_ATTACH_PARENT GIMP_PARASITE_GRANDPARENT_PERSISTENT GIMP_PARASITE_GRANDPARENT_UNDOABLE GIMP_PARASITE_PARENT_PERSISTENT GIMP_PARASITE_PARENT_UNDOABLE GIMP_PARASITE_PERSISTENT GIMP_PARASITE_UNDOABLE GIMP_PIXPIPE_MAXDIM GIMP_RGB_LUMINANCE_BLUE GIMP_RGB_LUMINANCE_GREEN GIMP_RGB_LUMINANCE_RED GIMP_STOCK_ANCHOR GIMP_STOCK_BRUSH GIMP_STOCK_BUFFER GIMP_STOCK_CAP_BUTT GIMP_STOCK_CAP_ROUND GIMP_STOCK_CAP_SQUARE GIMP_STOCK_CENTER GIMP_STOCK_CHANNEL GIMP_STOCK_CHANNELS GIMP_STOCK_CHANNEL_ALPHA GIMP_STOCK_CHANNEL_BLUE GIMP_STOCK_CHANNEL_GRAY GIMP_STOCK_CHANNEL_GREEN GIMP_STOCK_CHANNEL_INDEXED GIMP_STOCK_CHANNEL_RED GIMP_STOCK_CHAR_PICKER GIMP_STOCK_CLOSE GIMP_STOCK_COLORMAP GIMP_STOCK_COLOR_PICKER_BLACK GIMP_STOCK_COLOR_PICKER_GRAY GIMP_STOCK_COLOR_PICKER_WHITE GIMP_STOCK_COLOR_PICK_FROM_SCREEN GIMP_STOCK_COLOR_TRIANGLE GIMP_STOCK_CONTROLLER GIMP_STOCK_CONTROLLER_KEYBOARD GIMP_STOCK_CONTROLLER_LINUX_INPUT GIMP_STOCK_CONTROLLER_MIDI GIMP_STOCK_CONTROLLER_WHEEL GIMP_STOCK_CONVERT_GRAYSCALE GIMP_STOCK_CONVERT_INDEXED GIMP_STOCK_CONVERT_RGB GIMP_STOCK_CURSOR GIMP_STOCK_CURVE_FREE GIMP_STOCK_CURVE_SMOOTH GIMP_STOCK_DEFAULT_COLORS GIMP_STOCK_DETACH GIMP_STOCK_DEVICE_STATUS GIMP_STOCK_DISPLAY_FILTER GIMP_STOCK_DISPLAY_FILTER_COLORBLIND GIMP_STOCK_DISPLAY_FILTER_CONTRAST GIMP_STOCK_DISPLAY_FILTER_GAMMA GIMP_STOCK_DISPLAY_FILTER_LCMS GIMP_STOCK_DISPLAY_FILTER_PROOF GIMP_STOCK_DUPLICATE GIMP_STOCK_EDIT GIMP_STOCK_ERROR GIMP_STOCK_FLIP_HORIZONTAL GIMP_STOCK_FLIP_VERTICAL GIMP_STOCK_FLOATING_SELECTION GIMP_STOCK_FONT GIMP_STOCK_FRAME GIMP_STOCK_GEGL GIMP_STOCK_GRADIENT GIMP_STOCK_GRADIENT_BILINEAR GIMP_STOCK_GRADIENT_CONICAL_ASYMMETRIC GIMP_STOCK_GRADIENT_CONICAL_SYMMETRIC GIMP_STOCK_GRADIENT_LINEAR GIMP_STOCK_GRADIENT_RADIAL GIMP_STOCK_GRADIENT_SHAPEBURST_ANGULAR GIMP_STOCK_GRADIENT_SHAPEBURST_DIMPLED GIMP_STOCK_GRADIENT_SHAPEBURST_SPHERICAL GIMP_STOCK_GRADIENT_SPIRAL_ANTICLOCKWISE GIMP_STOCK_GRADIENT_SPIRAL_CLOCKWISE GIMP_STOCK_GRADIENT_SQUARE GIMP_STOCK_GRAVITY_EAST GIMP_STOCK_GRAVITY_NORTH GIMP_STOCK_GRAVITY_NORTH_EAST GIMP_STOCK_GRAVITY_NORTH_WEST GIMP_STOCK_GRAVITY_SOUTH GIMP_STOCK_GRAVITY_SOUTH_EAST GIMP_STOCK_GRAVITY_SOUTH_WEST GIMP_STOCK_GRAVITY_WEST GIMP_STOCK_GRID GIMP_STOCK_HCENTER GIMP_STOCK_HCHAIN GIMP_STOCK_HCHAIN_BROKEN GIMP_STOCK_HISTOGRAM GIMP_STOCK_HISTOGRAM_LINEAR GIMP_STOCK_HISTOGRAM_LOGARITHMIC GIMP_STOCK_IMAGE GIMP_STOCK_IMAGES GIMP_STOCK_INFO GIMP_STOCK_INVERT GIMP_STOCK_JOIN_BEVEL GIMP_STOCK_JOIN_MITER GIMP_STOCK_JOIN_ROUND GIMP_STOCK_LANDSCAPE GIMP_STOCK_LAYER GIMP_STOCK_LAYERS GIMP_STOCK_LAYER_MASK GIMP_STOCK_LAYER_TO_IMAGESIZE GIMP_STOCK_LETTER_SPACING GIMP_STOCK_LINE_SPACING GIMP_STOCK_LINKED GIMP_STOCK_LIST GIMP_STOCK_MENU_LEFT GIMP_STOCK_MENU_RIGHT GIMP_STOCK_MERGE_DOWN GIMP_STOCK_MOVE_TO_SCREEN GIMP_STOCK_NAVIGATION GIMP_STOCK_PALETTE GIMP_STOCK_PASTE_AS_NEW GIMP_STOCK_PASTE_INTO GIMP_STOCK_PATH GIMP_STOCK_PATHS GIMP_STOCK_PATH_STROKE GIMP_STOCK_PATTERN GIMP_STOCK_PLUGIN GIMP_STOCK_PORTRAIT GIMP_STOCK_PRINT_RESOLUTION GIMP_STOCK_QUESTION GIMP_STOCK_QUICK_MASK_OFF GIMP_STOCK_QUICK_MASK_ON GIMP_STOCK_RESET GIMP_STOCK_RESHOW_FILTER GIMP_STOCK_RESIZE GIMP_STOCK_ROTATE_180 GIMP_STOCK_ROTATE_270 GIMP_STOCK_ROTATE_90 GIMP_STOCK_SAMPLE_POINT GIMP_STOCK_SCALE GIMP_STOCK_SELECTION GIMP_STOCK_SELECTION_ADD GIMP_STOCK_SELECTION_ALL GIMP_STOCK_SELECTION_BORDER GIMP_STOCK_SELECTION_GROW GIMP_STOCK_SELECTION_INTERSECT GIMP_STOCK_SELECTION_NONE GIMP_STOCK_SELECTION_REPLACE GIMP_STOCK_SELECTION_SHRINK GIMP_STOCK_SELECTION_STROKE GIMP_STOCK_SELECTION_SUBTRACT GIMP_STOCK_SELECTION_TO_CHANNEL GIMP_STOCK_SELECTION_TO_PATH GIMP_STOCK_SHAPE_CIRCLE GIMP_STOCK_SHAPE_DIAMOND GIMP_STOCK_SHAPE_SQUARE GIMP_STOCK_SWAP_COLORS GIMP_STOCK_TEMPLATE GIMP_STOCK_TEXTURE GIMP_STOCK_TEXT_DIR_LTR GIMP_STOCK_TEXT_DIR_RTL GIMP_STOCK_TEXT_LAYER GIMP_STOCK_TOOLS GIMP_STOCK_TOOL_AIRBRUSH GIMP_STOCK_TOOL_ALIGN GIMP_STOCK_TOOL_BLEND GIMP_STOCK_TOOL_BLUR GIMP_STOCK_TOOL_BRIGHTNESS_CONTRAST GIMP_STOCK_TOOL_BUCKET_FILL GIMP_STOCK_TOOL_BY_COLOR_SELECT GIMP_STOCK_TOOL_CLONE GIMP_STOCK_TOOL_COLORIZE GIMP_STOCK_TOOL_COLOR_BALANCE GIMP_STOCK_TOOL_COLOR_PICKER GIMP_STOCK_TOOL_CROP GIMP_STOCK_TOOL_CURVES GIMP_STOCK_TOOL_DESATURATE GIMP_STOCK_TOOL_DODGE GIMP_STOCK_TOOL_ELLIPSE_SELECT GIMP_STOCK_TOOL_ERASER GIMP_STOCK_TOOL_FLIP GIMP_STOCK_TOOL_FOREGROUND_SELECT GIMP_STOCK_TOOL_FREE_SELECT GIMP_STOCK_TOOL_FUZZY_SELECT GIMP_STOCK_TOOL_HEAL GIMP_STOCK_TOOL_HUE_SATURATION GIMP_STOCK_TOOL_INK GIMP_STOCK_TOOL_ISCISSORS GIMP_STOCK_TOOL_LEVELS GIMP_STOCK_TOOL_MEASURE GIMP_STOCK_TOOL_MOVE GIMP_STOCK_TOOL_OPTIONS GIMP_STOCK_TOOL_PAINTBRUSH GIMP_STOCK_TOOL_PATH GIMP_STOCK_TOOL_PENCIL GIMP_STOCK_TOOL_PERSPECTIVE GIMP_STOCK_TOOL_PERSPECTIVE_CLONE GIMP_STOCK_TOOL_POSTERIZE GIMP_STOCK_TOOL_RECT_SELECT GIMP_STOCK_TOOL_ROTATE GIMP_STOCK_TOOL_SCALE GIMP_STOCK_TOOL_SHEAR GIMP_STOCK_TOOL_SMUDGE GIMP_STOCK_TOOL_TEXT GIMP_STOCK_TOOL_THRESHOLD GIMP_STOCK_TOOL_ZOOM GIMP_STOCK_TRANSPARENCY GIMP_STOCK_UNDO_HISTORY GIMP_STOCK_USER_MANUAL GIMP_STOCK_VCENTER GIMP_STOCK_VCHAIN GIMP_STOCK_VCHAIN_BROKEN GIMP_STOCK_VIDEO GIMP_STOCK_VISIBLE GIMP_STOCK_WARNING GIMP_STOCK_WEB GIMP_STOCK_WILBER GIMP_STOCK_WILBER_EEK GIMP_STOCK_ZOOM_FOLLOW_WINDOW GIMP_THUMB_ERROR GIMP_TYPE_ADD_MASK_TYPE GIMP_TYPE_ASPECT_PREVIEW GIMP_TYPE_ASPECT_TYPE GIMP_TYPE_BLEND_MODE GIMP_TYPE_BROWSER GIMP_TYPE_BRUSH_APPLICATION_MODE GIMP_TYPE_BRUSH_GENERATED_SHAPE GIMP_TYPE_BRUSH_SELECT_BUTTON GIMP_TYPE_BUCKET_FILL_MODE GIMP_TYPE_BUTTON GIMP_TYPE_CELL_RENDERER_COLOR GIMP_TYPE_CELL_RENDERER_TOGGLE GIMP_TYPE_CHAIN_BUTTON GIMP_TYPE_CHAIN_POSITION GIMP_TYPE_CHANNEL_COMBO_BOX GIMP_TYPE_CHANNEL_OPS GIMP_TYPE_CHANNEL_TYPE GIMP_TYPE_CHECK_SIZE GIMP_TYPE_CHECK_TYPE GIMP_TYPE_CLONE_TYPE GIMP_TYPE_CMYK GIMP_TYPE_COLOR_AREA GIMP_TYPE_COLOR_AREA_TYPE GIMP_TYPE_COLOR_BUTTON GIMP_TYPE_COLOR_CONFIG GIMP_TYPE_COLOR_DISPLAY GIMP_TYPE_COLOR_DISPLAY_STACK GIMP_TYPE_COLOR_HEX_ENTRY GIMP_TYPE_COLOR_MANAGED GIMP_TYPE_COLOR_MANAGEMENT_MODE GIMP_TYPE_COLOR_NOTEBOOK GIMP_TYPE_COLOR_PROFILE_COMBO_BOX GIMP_TYPE_COLOR_PROFILE_STORE GIMP_TYPE_COLOR_RENDERING_INTENT GIMP_TYPE_COLOR_SCALE GIMP_TYPE_COLOR_SCALES GIMP_TYPE_COLOR_SELECT GIMP_TYPE_COLOR_SELECTION GIMP_TYPE_COLOR_SELECTOR GIMP_TYPE_COLOR_SELECTOR_CHANNEL GIMP_TYPE_CONFIG GIMP_TYPE_CONFIG_PATH GIMP_TYPE_CONTROLLER GIMP_TYPE_CONVERT_DITHER_TYPE GIMP_TYPE_CONVERT_PALETTE_TYPE GIMP_TYPE_CONVOLUTION_TYPE GIMP_TYPE_CONVOLVE_TYPE GIMP_TYPE_DESATURATE_MODE GIMP_TYPE_DIALOG GIMP_TYPE_DODGE_BURN_TYPE GIMP_TYPE_DRAWABLE_COMBO_BOX GIMP_TYPE_DRAWABLE_PREVIEW GIMP_TYPE_ENUM_COMBO_BOX GIMP_TYPE_ENUM_LABEL GIMP_TYPE_ENUM_STORE GIMP_TYPE_FILL_TYPE GIMP_TYPE_FONT_SELECT_BUTTON GIMP_TYPE_FOREGROUND_EXTRACT_MODE GIMP_TYPE_FRAME GIMP_TYPE_GRADIENT_SEGMENT_COLOR GIMP_TYPE_GRADIENT_SEGMENT_TYPE GIMP_TYPE_GRADIENT_SELECT_BUTTON GIMP_TYPE_GRADIENT_TYPE GIMP_TYPE_GRID_STYLE GIMP_TYPE_HINT_BOX GIMP_TYPE_HISTOGRAM_CHANNEL GIMP_TYPE_HSL GIMP_TYPE_HSV GIMP_TYPE_HUE_RANGE GIMP_TYPE_ICON_TYPE GIMP_TYPE_IMAGE_BASE_TYPE GIMP_TYPE_IMAGE_COMBO_BOX GIMP_TYPE_IMAGE_TYPE GIMP_TYPE_INTERPOLATION_TYPE GIMP_TYPE_INT_COMBO_BOX GIMP_TYPE_INT_STORE GIMP_TYPE_LAYER_COMBO_BOX GIMP_TYPE_LAYER_MODE_EFFECTS GIMP_TYPE_MASK_APPLY_MODE GIMP_TYPE_MATRIX2 GIMP_TYPE_MEMSIZE GIMP_TYPE_MEMSIZE_ENTRY GIMP_TYPE_MERGE_TYPE GIMP_TYPE_MESSAGE_HANDLER_TYPE GIMP_TYPE_MODULE GIMP_TYPE_MODULE_DB GIMP_TYPE_NUMBER_PAIR_ENTRY GIMP_TYPE_OFFSET_AREA GIMP_TYPE_OFFSET_TYPE GIMP_TYPE_ORIENTATION_TYPE GIMP_TYPE_PAGE_SELECTOR GIMP_TYPE_PAGE_SELECTOR_TARGET GIMP_TYPE_PAINT_APPLICATION_MODE GIMP_TYPE_PALETTE_SELECT_BUTTON GIMP_TYPE_PARAM_CONFIG_PATH GIMP_TYPE_PARAM_MATRIX2 GIMP_TYPE_PARAM_MEMSIZE GIMP_TYPE_PARAM_PARASITE GIMP_TYPE_PARAM_RGB GIMP_TYPE_PARAM_UNIT GIMP_TYPE_PARASITE GIMP_TYPE_PATH_EDITOR GIMP_TYPE_PATTERN_SELECT_BUTTON GIMP_TYPE_PDB_ARG_TYPE GIMP_TYPE_PDB_ERROR_HANDLER GIMP_TYPE_PDB_PROC_TYPE GIMP_TYPE_PDB_STATUS_TYPE GIMP_TYPE_PICK_BUTTON GIMP_TYPE_PREVIEW GIMP_TYPE_PREVIEW_AREA GIMP_TYPE_PROC_BROWSER_DIALOG GIMP_TYPE_PROGRESS_BAR GIMP_TYPE_PROGRESS_COMMAND GIMP_TYPE_REPEAT_MODE GIMP_TYPE_RGB GIMP_TYPE_ROTATION_TYPE GIMP_TYPE_RULER GIMP_TYPE_RUN_MODE GIMP_TYPE_SCROLLED_PREVIEW GIMP_TYPE_SELECT_BUTTON GIMP_TYPE_SELECT_CRITERION GIMP_TYPE_SIZE_ENTRY GIMP_TYPE_SIZE_ENTRY_UPDATE_POLICY GIMP_TYPE_SIZE_TYPE GIMP_TYPE_STACK_TRACE_MODE GIMP_TYPE_STRING_COMBO_BOX GIMP_TYPE_TEXT_DIRECTION GIMP_TYPE_TEXT_JUSTIFICATION GIMP_TYPE_THUMBNAIL GIMP_TYPE_THUMB_FILE_TYPE GIMP_TYPE_THUMB_SIZE GIMP_TYPE_THUMB_STATE GIMP_TYPE_TRANSFER_MODE GIMP_TYPE_TRANSFORM_DIRECTION GIMP_TYPE_TRANSFORM_RESIZE GIMP_TYPE_UNIT GIMP_TYPE_UNIT_MENU GIMP_TYPE_VECTORS_COMBO_BOX GIMP_TYPE_VECTORS_STROKE_TYPE GIMP_TYPE_ZOOM_MODEL GIMP_TYPE_ZOOM_PREVIEW GIMP_TYPE_ZOOM_TYPE GIMP_VERSION GTK_DISABLE_DEPRECATED
syn keyword gimpDeprecatedFunction gimp_brush_select_widget_close gimp_brush_select_widget_new gimp_brush_select_widget_set gimp_brushes_get_brush gimp_brushes_get_brush_data gimp_brushes_get_opacity gimp_brushes_get_paint_mode gimp_brushes_get_spacing gimp_brushes_set_brush gimp_brushes_set_opacity gimp_brushes_set_paint_mode gimp_brushes_set_spacing gimp_channel_menu_new gimp_color_display_new gimp_drawable_menu_new gimp_drawable_set_image gimp_file_entry_get_filename gimp_file_entry_get_type gimp_file_entry_new gimp_file_entry_set_filename gimp_flip gimp_font_select_widget_close gimp_font_select_widget_new gimp_font_select_widget_set gimp_get_path_by_tattoo gimp_gradient_select_widget_close gimp_gradient_select_widget_new gimp_gradient_select_widget_set gimp_gradients_get_gradient gimp_gradients_get_gradient_data gimp_gradients_sample_custom gimp_gradients_sample_uniform gimp_gradients_set_gradient gimp_image_free_shadow gimp_image_get_cmap gimp_image_menu_new gimp_image_set_cmap gimp_int_option_menu_new gimp_int_option_menu_set_history gimp_int_option_menu_set_sensitive gimp_layer_get_preserve_trans gimp_layer_menu_new gimp_layer_set_preserve_trans gimp_levels_auto gimp_memsize_to_string gimp_menu_item_update gimp_module_register_enum gimp_option_menu_new gimp_option_menu_new2 gimp_option_menu_set_history gimp_option_menu_set_sensitive gimp_palette_get_background gimp_palette_get_foreground gimp_palette_select_widget_close gimp_palette_select_widget_new gimp_palette_select_widget_set gimp_palette_set_background gimp_palette_set_default_colors gimp_palette_set_foreground gimp_palette_swap_colors gimp_palettes_get_palette gimp_palettes_get_palette_entry gimp_palettes_set_palette gimp_path_delete gimp_path_get_current gimp_path_get_locked gimp_path_get_point_at_dist gimp_path_get_points gimp_path_get_tattoo gimp_path_import gimp_path_list gimp_path_set_current gimp_path_set_locked gimp_path_set_points gimp_path_set_tattoo gimp_path_stroke_current gimp_path_to_selection gimp_pattern_select_widget_close gimp_pattern_select_widget_new gimp_pattern_select_widget_set gimp_patterns_get_pattern gimp_patterns_get_pattern_data gimp_patterns_set_pattern gimp_perspective gimp_pixmap_button_new gimp_pixmap_get_type gimp_pixmap_new gimp_pixmap_set gimp_progress_install gimp_rgb_intensity gimp_rgb_intensity_uchar gimp_rotate gimp_scale gimp_selection_clear gimp_shear gimp_text gimp_text_get_extents gimp_transform_2d gimp_user_directory gimp_user_directory_get_type
syn keyword gimpDeprecatedConstant GIMP_USER_DIRECTORY_DESKTOP GIMP_USER_DIRECTORY_DOCUMENTS GIMP_USER_DIRECTORY_DOWNLOAD GIMP_USER_DIRECTORY_MUSIC GIMP_USER_DIRECTORY_PICTURES GIMP_USER_DIRECTORY_PUBLIC_SHARE GIMP_USER_DIRECTORY_TEMPLATES GIMP_USER_DIRECTORY_VIDEOS
syn keyword gimpDeprecatedStruct GimpFileEntry GimpFileEntryClass GimpPixmap GimpPixmapClass
syn keyword gimpDeprecatedMacro GIMP_FILE_ENTRY GIMP_FILE_ENTRY_CLASS GIMP_FILE_ENTRY_GET_CLASS GIMP_IS_FILE_ENTRY GIMP_IS_FILE_ENTRY_CLASS GIMP_IS_PIXMAP GIMP_IS_PIXMAP_CLASS GIMP_PIXMAP GIMP_PIXMAP_CLASS GIMP_PIXMAP_GET_CLASS GIMP_RGB_INTENSITY
syn keyword gimpDeprecatedEnum GimpUserDirectory
syn keyword gimpDeprecatedUserFunction GimpConstraintFunc GimpIntOptionMenuSensitivityCallback GimpMenuCallback GimpOptionMenuSensitivityCallback GimpProgressEndCallback GimpProgressStartCallback GimpProgressTextCallback GimpProgressValueCallback
syn keyword gimpDeprecatedDefine GIMP_MODULE_PARAM_SERIALIZE GIMP_RGB_INTENSITY_BLUE GIMP_RGB_INTENSITY_GREEN GIMP_RGB_INTENSITY_RED GIMP_STOCK_INDEXED_PALETTE GIMP_STOCK_QMASK_OFF GIMP_STOCK_QMASK_ON GIMP_TYPE_FILE_ENTRY GIMP_TYPE_PIXMAP GIMP_TYPE_USER_DIRECTORY

" Default highlighting
if version >= 508 || !exists("did_gimp_syntax_inits")
  if version < 508
    let did_gimp_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink gimpFunction Function
  HiLink gimpTypedef Type
  HiLink gimpConstant Constant
  HiLink gimpStruct Type
  HiLink gimpUnion Type
  HiLink gimpMacro Macro
  HiLink gimpEnum Type
  HiLink gimpVariable Identifier
  HiLink gimpUserFunction Type
  HiLink gimpDefine Constant
  if exists("gimp_deprecated_errors")
    HiLink gimpDeprecatedFunction Error
    HiLink gimpDeprecatedConstant Error
    HiLink gimpDeprecatedStruct Error
    HiLink gimpDeprecatedMacro Error
    HiLink gimpDeprecatedEnum Error
    HiLink gimpDeprecatedUserFunction Error
    HiLink gimpDeprecatedDefine Error
  elseif exists("gimp_enable_deprecated")
    HiLink gimpDeprecatedFunction Function
    HiLink gimpDeprecatedConstant Constant
    HiLink gimpDeprecatedStruct Type
    HiLink gimpDeprecatedMacro Macro
    HiLink gimpDeprecatedEnum Type
    HiLink gimpDeprecatedUserFunction Type
    HiLink gimpDeprecatedDefine Constant
  endif

  delcommand HiLink
endif

